@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: group_member
 .. role:: red
@@ -79,44 +77,44 @@ from twisted.python.failure import Failure
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import utime
-from lib import packetid
-from lib import jsn
-from lib import strng
-from lib import serialization
+from bitdust.lib import utime
+from bitdust.lib import packetid
+from bitdust.lib import jsn
+from bitdust.lib import strng
+from bitdust.lib import serialization
 
-from main import events
-from main import config
+from bitdust.main import events
+from bitdust.main import config
 
-from crypt import my_keys
-from crypt import signed
+from bitdust.crypt import my_keys
+from bitdust.crypt import signed
 
-from dht import dht_relations
+from bitdust.dht import dht_relations
 
-from contacts import identitycache
+from bitdust.contacts import identitycache
 
-from p2p import commands
-from p2p import p2p_service
-from p2p import lookup
-from p2p import propagate
-from p2p import p2p_service_seeker
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import lookup
+from bitdust.p2p import propagate
+from bitdust.p2p import p2p_service_seeker
 
-from transport import packet_out
+from bitdust.transport import packet_out
 
-from stream import message
+from bitdust.stream import message
 
-from storage import archive_reader
+from bitdust.storage import archive_reader
 
-from access import groups
+from bitdust.access import groups
 
-from userid import identity
-from userid import global_id
-from userid import id_url
-from userid import my_id
+from bitdust.userid import identity
+from bitdust.userid import global_id
+from bitdust.userid import id_url
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -129,6 +127,7 @@ _ActiveGroupMembersByIDURL = {}
 
 #------------------------------------------------------------------------------
 
+
 def register_group_member(A):
     global _ActiveGroupMembers
     global _ActiveGroupMembersByIDURL
@@ -160,8 +159,10 @@ def unregister_group_member(A):
             lg.warn('group_member() instance not found for customer %r' % A.group_creator_idurl)
     return _ActiveGroupMembers.pop(A.group_key_id, None)
 
+
 #------------------------------------------------------------------------------
 
+
 def list_active_group_members():
     global _ActiveGroupMembers
     return list(_ActiveGroupMembers.keys())
@@ -185,8 +186,10 @@ def find_active_group_members(group_creator_idurl):
             result.append(A)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def restart_active_group_member(group_key_id, use_dht_cache=False):
     if _Debug:
         lg.args(_DebugLevel, group_key_id=group_key_id, use_dht_cache=use_dht_cache)
@@ -229,8 +232,10 @@ def restart_active_group_member(group_key_id, use_dht_cache=False):
     reactor.callLater(0, _do_start_new_group_member)  # @UndefinedVariable
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def rotate_active_group_memeber(old_group_key_id, new_group_key_id):
     global _ActiveGroupMembers
     A_old = get_active_group_member(old_group_key_id)
@@ -238,7 +243,7 @@ def rotate_active_group_memeber(old_group_key_id, new_group_key_id):
         return False
     A_new = get_active_group_member(new_group_key_id)
     if A_new and A_new in _ActiveGroupMembers:
-        lg.err('it seems group %r already rotated, but older copy also exists at the moment: %r' % (A_new, A_old, ))
+        lg.err('it seems group %r already rotated, but older copy also exists at the moment: %r' % (A_new, A_old))
         return False
     del A_new  # just my paranoia
     unregister_group_member(A_old)
@@ -247,10 +252,11 @@ def rotate_active_group_memeber(old_group_key_id, new_group_key_id):
     restart_active_group_member(new_group_key_id)
     return True
 
+
 #------------------------------------------------------------------------------
 
-def start_group_members():
 
+def start_group_members():
     def _start():
         started = 0
         for group_key_id, group_info in groups.active_groups().items():
@@ -270,7 +276,12 @@ def start_group_members():
             if not existing_group_member:
                 existing_group_member = GroupMember(group_key_id)
                 existing_group_member.automat('init')
-            if existing_group_member.state in ['DHT_READ?', 'BROKERS?', 'QUEUE?', 'IN_SYNC!', ]:
+            if existing_group_member.state in [
+                'DHT_READ?',
+                'BROKERS?',
+                'QUEUE?',
+                'IN_SYNC!',
+            ]:
                 continue
             existing_group_member.automat('join')
             started += 1
@@ -313,24 +324,15 @@ def shutdown_group_members():
         stopped += 1
     return stopped
 
+
 #------------------------------------------------------------------------------
 
+
 class GroupMember(automat.Automat):
     """
     This class implements all the functionality of ``group_member()`` state machine.
     """
-
-    def __init__(
-        self,
-        group_key_id,
-        member_idurl=None,
-        use_dht_cache=True,
-        debug_level=_DebugLevel,
-        log_events=_Debug,
-        log_transitions=_Debug,
-        publish_events=False,
-        **kwargs
-    ):
+    def __init__(self, group_key_id, member_idurl=None, use_dht_cache=True, debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, publish_events=False, **kwargs):
         """
         Builds `group_member()` state machine.
         """
@@ -355,13 +357,10 @@ class GroupMember(automat.Automat):
         self.recorded_messages = []
         self.group_brokers_updated = False
         super(GroupMember, self).__init__(
-            name="group_member_%s$%s" % (self.group_queue_alias, self.group_creator_id, ),
-            state="AT_STARTUP",
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            publish_events=publish_events,
-            **kwargs
+            name='group_member_%s$%s' % (
+                self.group_queue_alias,
+                self.group_creator_id,
+            ), state='AT_STARTUP', debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, publish_events=publish_events, **kwargs
         )
 
     def __repr__(self):
@@ -380,19 +379,22 @@ class GroupMember(automat.Automat):
 
     def to_json(self):
         j = super().to_json()
-        j.update({
-            'active': groups.is_group_active(self.group_key_id),
-            'member_id': self.member_id,
-            'group_key_id': self.group_key_id,
-            'alias': self.group_glob_id['key_alias'],
-            'label': my_keys.get_label(self.group_key_id) or '',
-            'creator': self.group_creator_id,
-            'active_broker_id': self.active_broker_id,
-            'active_queue_id': self.active_queue_id,
-            'connected_brokers': {p: id_url.idurl_to_id(b) for p, b in self.connected_brokers.items()},
-            'last_sequence_id': self.last_sequence_id,
-            'archive_folder_path': groups.get_archive_folder_path(self.group_key_id),
-        })
+        j.update(
+            {
+                'active': groups.is_group_active(self.group_key_id),
+                'member_id': self.member_id,
+                'group_key_id': self.group_key_id,
+                'alias': self.group_glob_id['key_alias'],
+                'label': my_keys.get_label(self.group_key_id) or '',
+                'creator': self.group_creator_id,
+                'active_broker_id': self.active_broker_id,
+                'active_queue_id': self.active_queue_id,
+                'connected_brokers': {p: id_url.idurl_to_id(b)
+                                      for p, b in self.connected_brokers.items()},
+                'last_sequence_id': self.last_sequence_id,
+                'archive_folder_path': groups.get_archive_folder_path(self.group_key_id),
+            }
+        )
         return j
 
     def init(self):
@@ -429,7 +431,7 @@ class GroupMember(automat.Automat):
                 old_state=oldstate,
                 new_state=newstate,
             ))
-        if newstate not in ['DISCONNECTED', 'IN_SYNC!', 'CLOSED', ] and oldstate in ['DISCONNECTED', 'IN_SYNC!', ]:
+        if newstate not in ['DISCONNECTED', 'IN_SYNC!', 'CLOSED'] and oldstate in ['DISCONNECTED', 'IN_SYNC!']:
             lg.info('group connecting : %s' % self.group_key_id)
             events.send('group-connecting', data=dict(
                 group_key_id=self.group_key_id,
@@ -452,7 +454,7 @@ class GroupMember(automat.Automat):
         if self.state == 'AT_STARTUP':
             if event == 'init':
                 self.state = 'DISCONNECTED'
-                self.SyncedUp=False
+                self.SyncedUp = False
                 self.doInit(*args, **kwargs)
         #---DISCONNECTED---
         elif self.state == 'DISCONNECTED':
@@ -460,7 +462,7 @@ class GroupMember(automat.Automat):
                 self.state = 'CLOSED'
                 self.doDeactivate(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'join' or ( event == 'brokers-changed' and self.isActive(*args, **kwargs) ) or ( event == 'instant' and self.isActive(*args, **kwargs) and self.isDeadBroker(*args, **kwargs) ):
+            elif event == 'join' or (event == 'brokers-changed' and self.isActive(*args, **kwargs)) or (event == 'instant' and self.isActive(*args, **kwargs) and self.isDeadBroker(*args, **kwargs)):
                 self.state = 'DHT_READ?'
                 self.doActivate(*args, **kwargs)
                 self.doDHTReadBrokers(event, *args, **kwargs)
@@ -468,7 +470,7 @@ class GroupMember(automat.Automat):
         elif self.state == 'DHT_READ?':
             if event == 'dht-read-failed':
                 self.state = 'DISCONNECTED'
-                self.SyncedUp=False
+                self.SyncedUp = False
                 self.doDisconnected(event, *args, **kwargs)
             elif event == 'shutdown' or event == 'leave':
                 self.state = 'CLOSED'
@@ -478,7 +480,7 @@ class GroupMember(automat.Automat):
             elif event == 'message-in':
                 self.doRecord(*args, **kwargs)
             elif event == 'queue-in-sync':
-                self.SyncedUp=True
+                self.SyncedUp = True
             elif event == 'brokers-changed' or event == 'brokers-read' or event == 'brokers-found' or event == 'brokers-not-found':
                 self.state = 'BROKERS?'
                 self.doConnectSingleBroker(event, *args, **kwargs)
@@ -492,7 +494,7 @@ class GroupMember(automat.Automat):
             elif event == 'message-in':
                 self.doRecord(*args, **kwargs)
             elif event == 'queue-in-sync':
-                self.SyncedUp=True
+                self.SyncedUp = True
             elif event == 'brokers-all-connected':
                 self.state = 'QUEUE?'
                 self.doRememberBrokers(*args, **kwargs)
@@ -508,7 +510,7 @@ class GroupMember(automat.Automat):
         elif self.state == 'QUEUE?':
             if event == 'queue-read-failed':
                 self.state = 'DISCONNECTED'
-                self.SyncedUp=False
+                self.SyncedUp = False
                 self.doMarkDeadBroker(event, *args, **kwargs)
                 self.doDisconnected(event, *args, **kwargs)
             elif event == 'message-in':
@@ -521,14 +523,14 @@ class GroupMember(automat.Automat):
                 self.doDestroyMe(*args, **kwargs)
             elif event == 'queue-is-ahead':
                 self.doReadArchive(*args, **kwargs)
-            elif event == 'queue-in-sync' or ( event == 'instant' and self.SyncedUp ):
+            elif event == 'queue-in-sync' or (event == 'instant' and self.SyncedUp):
                 self.state = 'IN_SYNC!'
-                self.SyncedUp=True
+                self.SyncedUp = True
                 self.doPushPendingMessages(*args, **kwargs)
                 self.doConnected(*args, **kwargs)
             elif event == 'reconnect' or event == 'brokers-changed' or event == 'push-message-failed' or event == 'replace-active-broker':
                 self.state = 'DHT_READ?'
-                self.SyncedUp=False
+                self.SyncedUp = False
                 self.doMarkDeadBroker(event, *args, **kwargs)
                 self.doDHTReadBrokers(event, *args, **kwargs)
         #---IN_SYNC!---
@@ -544,7 +546,7 @@ class GroupMember(automat.Automat):
                 self.doNotifyMessageAccepted(*args, **kwargs)
             elif event == 'reconnect' or event == 'brokers-changed' or event == 'push-message-failed' or event == 'replace-active-broker':
                 self.state = 'DHT_READ?'
-                self.SyncedUp=False
+                self.SyncedUp = False
                 self.doMarkDeadBroker(event, *args, **kwargs)
                 self.doDHTReadBrokers(event, *args, **kwargs)
             elif event == 'message-in':
@@ -580,7 +582,9 @@ class GroupMember(automat.Automat):
             consumer_callback_id=self.name,
             callback=self._do_read_queue_messages,
             direction='incoming',
-            message_types=['queue_message', ],
+            message_types=[
+                'queue_message',
+            ],
         )
         events.add_subscriber(self._on_group_brokers_updated, 'group-brokers-updated')
 
@@ -614,7 +618,7 @@ class GroupMember(automat.Automat):
                 self.dht_read_use_cache = True
                 self.automat('brokers-read', known_brokers=cooperated_brokers)
                 return
-        if event in ['reconnect', 'push-message-failed', 'replace-active-broker', 'broker-position-mismatch', 'top-broker-connect-failed', ]:
+        if event in ['reconnect', 'push-message-failed', 'replace-active-broker', 'broker-position-mismatch', 'top-broker-connect-failed']:
             self.dht_read_use_cache = False
         if _Debug:
             lg.args(_DebugLevel, e=event, use_cache=self.dht_read_use_cache)
@@ -625,8 +629,7 @@ class GroupMember(automat.Automat):
         )
         # TODO: add more validations of dht_result
         result.addCallback(self._on_read_customer_message_brokers)
-        if _Debug:
-            result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member.doDHTReadBrokers')
+        result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member.doDHTReadBrokers')
         result.addErrback(lambda err: self.automat('dht-read-failed', err))
 
     def doConnectSingleBroker(self, event, *args, **kwargs):
@@ -667,7 +670,11 @@ class GroupMember(automat.Automat):
             timeout=15,
             channel='ping_broker',
             keep_alive=False,
-        ).addBoth(self._on_brokers_ping_result, cooperated_brokers=cooperated_brokers, archive_folder_path=archive_folder_path)
+        ).addBoth(
+            self._on_brokers_ping_result,
+            cooperated_brokers=cooperated_brokers,
+            archive_folder_path=archive_folder_path,
+        )
 
     def doRememberBrokers(self, *args, **kwargs):
         """
@@ -697,8 +704,7 @@ class GroupMember(automat.Automat):
             skip_handshake=True,
             fire_callbacks=False,
         )
-        if _Debug:
-            result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member.doReadQueue')
+        result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member.doReadQueue')
         result.addErrback(self._on_read_queue_failed)
 
     def doReadArchive(self, *args, **kwargs):
@@ -794,12 +800,14 @@ class GroupMember(automat.Automat):
         """
         self.dht_read_use_cache = True
         if self.group_brokers_updated:
+            # yapf: disable
             events.send('group-brokers-updated', data=dict(
                 group_creator_id=self.group_creator_id,
                 group_key_id=self.group_key_id,
                 member_id=self.member_id,
                 connected_brokers=self.connected_brokers,
             ))
+            # yapf: enable
             self.group_brokers_updated = False
 
     def doDisconnected(self, *args, **kwargs):
@@ -872,27 +880,15 @@ class GroupMember(automat.Automat):
         last_pos = groups.REQUIRED_BROKERS_COUNT - 1
         if self.dead_broker_id:
             if not self.active_broker_id or self.active_broker_id == self.dead_broker_id:
-                return {
-                    'broker_idurl': None,
-                    'broker_pos': last_pos,
-                }
+                return {'broker_idurl': None, 'broker_pos': last_pos}
         if available_brokers:
             if last_pos in available_brokers:
-                return {
-                    'broker_idurl': available_brokers[last_pos],
-                    'broker_pos': last_pos,
-                }
+                return {'broker_idurl': available_brokers[last_pos], 'broker_pos': last_pos}
         if dht_brokers:
             for dht_broker in dht_brokers:
                 if dht_broker['position'] == last_pos and dht_broker['broker_idurl']:
-                    return {
-                        'broker_idurl': dht_broker['broker_idurl'],
-                        'broker_pos': last_pos,
-                    }
-        return {
-            'broker_idurl': None,
-            'broker_pos': last_pos,
-        }
+                    return {'broker_idurl': dht_broker['broker_idurl'], 'broker_pos': last_pos}
+        return {'broker_idurl': None, 'broker_pos': last_pos}
 
     def _do_connect_target_broker(self, broker_pos, broker_idurl):
         if broker_idurl:
@@ -911,8 +907,7 @@ class GroupMember(automat.Automat):
             attempts=1,
         )
         result.addCallback(self._on_broker_connected, broker_pos)
-        if _Debug:
-            result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_request_service_one_broker')
+        result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_request_service_one_broker')
         result.addErrback(self._on_broker_connect_failed, broker_pos)
 
     def _do_lookup_one_broker(self, broker_pos, skip_brokers):
@@ -951,8 +946,7 @@ class GroupMember(automat.Automat):
                     attempts=1,
                 )
                 result.addCallback(self._on_broker_hired, broker_pos)
-                if _Debug:
-                    result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_lookup_one_broker')
+                result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_lookup_one_broker')
                 result.addErrback(self._on_broker_connect_failed, broker_pos)
                 return result
         result = p2p_service_seeker.connect_random_node(
@@ -964,8 +958,7 @@ class GroupMember(automat.Automat):
             attempts=2,
         )
         result.addCallback(self._on_broker_hired, broker_pos)
-        if _Debug:
-            result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_lookup_one_broker')
+        result.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_lookup_one_broker')
         result.addErrback(self._on_broker_lookup_failed, broker_pos)
         return result
 
@@ -1014,18 +1007,17 @@ class GroupMember(automat.Automat):
             found_broker_ids.add(incoming_broker_id)
             if incoming_group_key_id != self.group_key_id:
                 if _Debug:
-                    lg.dbg(_DebugLevel, 'skip message based on packet_id for %r : %r' % (self.group_key_id, incoming_group_key_id, ))
+                    lg.dbg(_DebugLevel, 'skip message based on packet_id for %r : %r' % (self.group_key_id, incoming_group_key_id))
                 continue
             if chunk_last_sequence_id > latest_known_sequence_id:
                 latest_known_sequence_id = chunk_last_sequence_id
             for one_message in list_messages:
                 if one_message['sequence_id'] > latest_known_sequence_id:
-                    lg.warn('invalid item sequence_id %d   vs.  last_sequence_id %d known' % (
-                        one_message['sequence_id'], latest_known_sequence_id))
+                    lg.warn('invalid item sequence_id %d   vs.  last_sequence_id %d known' % (one_message['sequence_id'], latest_known_sequence_id))
                     continue
                 group_message_object = message.GroupMessage.deserialize(one_message['payload'])
                 if group_message_object is None:
-                    lg.err("GroupMessage deserialize failed, can not extract message from payload of %d bytes" % len(one_message['payload']))
+                    lg.err('GroupMessage deserialize failed, can not extract message from payload of %d bytes' % len(one_message['payload']))
                     continue
                 try:
                     decrypted_message = group_message_object.decrypt()
@@ -1048,21 +1040,19 @@ class GroupMember(automat.Automat):
                     packets_to_ack[packet_id] = owner_idurl
         for packet_id, owner_idurl in packets_to_ack.items():
             p2p_service.SendAckNoRequest(owner_idurl, packet_id)
-            received_queue_id, _, _ = packet_id.rpartition('_') 
+            received_queue_id, _, _ = packet_id.rpartition('_')
             _, received_broker_id = global_id.SplitGlobalQueueID(received_queue_id, split_queue_alias=False)
             if self.active_broker_id and received_broker_id != self.active_broker_id:
                 if not to_be_reconnected:
                     to_be_reconnected = True
-                    lg.warn('received message from broker %r which is different from my active broker %r' % (
-                        received_broker_id, self.active_broker_id, ))
+                    lg.warn('received message from broker %r which is different from my active broker %r' % (received_broker_id, self.active_broker_id))
         if received_group_messages and len(found_broker_ids) > 0 and self.active_broker_id not in found_broker_ids:
             to_be_reconnected = True
-            lg.warn('active broker is %r but incoming message received from another broker %r in %r' % (
-                self.active_broker_id, list(found_broker_ids), self, ))
+            lg.warn('active broker is %r but incoming message received from another broker %r in %r' % (self.active_broker_id, list(found_broker_ids), self))
         packets_to_ack.clear()
         if to_be_reconnected:
             cooperated_brokers = json_message.get('cooperated_brokers', {}) or {}
-            cooperated_brokers = {int(k): id_url.field(v) for k,v in cooperated_brokers.items()}
+            cooperated_brokers = {int(k): id_url.field(v) for k, v in cooperated_brokers.items()}
             if _Debug:
                 lg.args(_DebugLevel, cooperated_brokers=cooperated_brokers)
         if not received_group_messages:
@@ -1071,7 +1061,7 @@ class GroupMember(automat.Automat):
                     lg.dbg(_DebugLevel, 'no messages for %r found in the incoming stream' % self.active_queue_id)
                 return True
             if latest_known_sequence_id < self.last_sequence_id:
-                lg.warn('found queue latest sequence %d is behind of my current position %d' % (latest_known_sequence_id, self.last_sequence_id, ))
+                lg.warn('found queue latest sequence %d is behind of my current position %d' % (latest_known_sequence_id, self.last_sequence_id))
                 self.automat('queue-in-sync')
                 if to_be_reconnected:
                     if _Debug:
@@ -1079,9 +1069,8 @@ class GroupMember(automat.Automat):
                     reactor.callLater(0.01, self.automat, 'reconnect', cooperated_brokers=cooperated_brokers)  # @UndefinedVariable
                 return True
             if latest_known_sequence_id > self.last_sequence_id:
-                lg.warn('nothing received, but found queue latest sequence %d is ahead of my current position %d, need to read messages from archive' % (
-                    latest_known_sequence_id, self.last_sequence_id, ))
-                self.automat('queue-is-ahead', latest_known_sequence_id=latest_known_sequence_id, received_messages=received_group_messages, )
+                lg.warn('nothing received, but found queue latest sequence %d is ahead of my current position %d, need to read messages from archive' % (latest_known_sequence_id, self.last_sequence_id))
+                self.automat('queue-is-ahead', latest_known_sequence_id=latest_known_sequence_id, received_messages=received_group_messages)
                 if to_be_reconnected:
                     if _Debug:
                         lg.dbg(_DebugLevel, 'going to reconnect %r' % self)
@@ -1124,18 +1113,16 @@ class GroupMember(automat.Automat):
                 newly_processed += 1
                 groups.set_last_sequence_id(self.group_key_id, self.last_sequence_id)
                 groups.save_group_info(self.group_key_id)
-                lg.info('new message consumed in %r, last_sequence_id incremented to %d' % (self.group_key_id, self.last_sequence_id, ))
+                lg.info('new message consumed in %r, last_sequence_id incremented to %d' % (self.group_key_id, self.last_sequence_id))
                 self.automat('message-in', **inp_message)
         if len(self.buffered_messages) > MAX_BUFFERED_MESSAGES:
-            raise Exception('message sequence is broken by message broker %s, currently %d buffered messages' % (self.active_broker_id, len(self.buffered_messages), ))
+            raise Exception('message sequence is broken by message broker %s, currently %d buffered messages' % (self.active_broker_id, len(self.buffered_messages)))
         if _Debug:
-            lg.dbg(_DebugLevel, 'my_last_sequence_id=%d  newly_processed=%d  buffered_messages=%d' % (
-                self.last_sequence_id, newly_processed, len(self.buffered_messages), ))
+            lg.dbg(_DebugLevel, 'my_last_sequence_id=%d  newly_processed=%d  buffered_messages=%d' % (self.last_sequence_id, newly_processed, len(self.buffered_messages)))
         if not newly_processed or newly_processed != len(received_group_messages):
             if latest_known_sequence_id > self.last_sequence_id:
-                lg.warn('found queue latest sequence %d is ahead of my current position %d, need to read messages from archive' % (
-                    latest_known_sequence_id, self.last_sequence_id, ))
-                self.automat('queue-is-ahead', latest_known_sequence_id=latest_known_sequence_id, received_messages=received_group_messages, )
+                lg.warn('found queue latest sequence %d is ahead of my current position %d, need to read messages from archive' % (latest_known_sequence_id, self.last_sequence_id))
+                self.automat('queue-is-ahead', latest_known_sequence_id=latest_known_sequence_id, received_messages=received_group_messages)
                 return True
         if _Debug:
             lg.dbg(_DebugLevel, 'processed all messages, queue in sync, last_sequence_id=%d' % self.last_sequence_id)
@@ -1161,8 +1148,7 @@ class GroupMember(automat.Automat):
             }
         else:
             if self.outgoing_messages[outgoing_counter]['attempts'] > CRITICAL_PUSH_MESSAGE_FAILS:
-                lg.err('failed sending message to broker %r after %d attempts' % (
-                    self.active_broker_id, self.outgoing_messages[outgoing_counter]['attempts'], ))
+                lg.err('failed sending message to broker %r after %d attempts' % (self.active_broker_id, self.outgoing_messages[outgoing_counter]['attempts']))
                 self.outgoing_messages[outgoing_counter]['attempts'] = 0
                 self.outgoing_messages[outgoing_counter]['last_attempt'] = None
                 self.automat('push-message-failed')
@@ -1176,8 +1162,7 @@ class GroupMember(automat.Automat):
             json_payload = self.outgoing_messages[outgoing_counter]['payload']
             if self.outgoing_messages[outgoing_counter]['attempts'] >= 1:
                 require_handshake = True
-            lg.warn('re-trying sending message to broker %r   counter=%d attempts=%d packet_id=%s' % (
-                self.active_broker_id, outgoing_counter, self.outgoing_messages[outgoing_counter]['attempts'], packet_id, ))
+            lg.warn('re-trying sending message to broker %r   counter=%d attempts=%d packet_id=%s' % (self.active_broker_id, outgoing_counter, self.outgoing_messages[outgoing_counter]['attempts'], packet_id))
         raw_payload = serialization.DictToBytes(
             json_payload,
             pack_types=True,
@@ -1210,20 +1195,19 @@ class GroupMember(automat.Automat):
             fire_callbacks=False,
             require_handshake=require_handshake,
         )
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_send_message_to_broker')
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='group_member._do_send_message_to_broker')
         d.addCallback(self._on_message_to_broker_sent, outgoing_counter, packet_id)
         d.addErrback(self._on_message_to_broker_failed, outgoing_counter, packet_id)
 
     def _do_prepare_service_request_params(self, possible_broker_idurl, desired_broker_position=-1, action='queue-connect'):
         if _Debug:
-            lg.args(_DebugLevel, broker=possible_broker_idurl, pos=desired_broker_position, action=action, owner=self.group_creator_id, )
+            lg.args(_DebugLevel, broker=possible_broker_idurl, pos=desired_broker_position, action=action, owner=self.group_creator_id)
         group_key_info = {}
         # if not my_keys.is_key_registered(self.group_key_id):
         #     lg.warn('group key %r was not registered, checking all registered keys' % self.group_key_id)
         #     my_keys.check_rename_my_keys(prefix=self.group_key_id.split('@')[0])
         if not my_keys.is_key_registered(self.group_key_id):
-            lg.err('closing group_member %r because key %r is not registered' % (self, self.group_key_id, ))
+            lg.err('closing group_member %r because key %r is not registered' % (self, self.group_key_id))
             lg.exc('group key %r is not registered' % self.group_key_id)
             self.automat('shutdown')
             return
@@ -1254,8 +1238,7 @@ class GroupMember(automat.Automat):
         if desired_broker_position >= 0:
             service_request_params['position'] = desired_broker_position
         if _Debug:
-            lg.args(_DebugLevel, action=action, last_sequence_id=service_request_params['last_sequence_id'],
-                    archive_folder_path=service_request_params['archive_folder_path'])
+            lg.args(_DebugLevel, action=action, last_sequence_id=service_request_params['last_sequence_id'], archive_folder_path=service_request_params['archive_folder_path'])
         return service_request_params
 
     def _do_remember_brokers(self, *args, **kwargs):
@@ -1292,12 +1275,10 @@ class GroupMember(automat.Automat):
         if archive_folder_path:
             current_path = groups.get_archive_folder_path(self.group_key_id)
             if current_path and current_path != archive_folder_path:
-                lg.warn('for %r overwriting existing archive_folder_path %r with new value %r' % (
-                    self.group_key_id, current_path, archive_folder_path, ))
+                lg.warn('for %r overwriting existing archive_folder_path %r with new value %r' % (self.group_key_id, current_path, archive_folder_path))
             else:
                 if not current_path:
-                    lg.info('recognized archive folder path for %r from broker response: %r' % (
-                        self.group_key_id, archive_folder_path, ))
+                    lg.info('recognized archive folder path for %r from broker response: %r' % (self.group_key_id, archive_folder_path))
             groups.set_archive_folder_path(self.group_key_id, archive_folder_path)
         groups.save_group_info(self.group_key_id)
         if brokers_changed:
@@ -1322,7 +1303,7 @@ class GroupMember(automat.Automat):
             # skip leading "accepted:" marker
             cooperated_brokers = jsn.loads(strng.to_text(response_info[0].Payload)[9:])
             archive_folder_path = strng.to_text(cooperated_brokers.pop('archive_folder_path', None))
-            cooperated_brokers = {int(k): id_url.field(v) for k,v in cooperated_brokers.items()}
+            cooperated_brokers = {int(k): id_url.field(v) for k, v in cooperated_brokers.items()}
         except:
             lg.exc()
             self.automat('broker-connect-failed')
@@ -1353,18 +1334,18 @@ class GroupMember(automat.Automat):
                     if resp_payload.startswith('mismatch:'):
                         mismatch_info = jsn.loads(resp_payload[9:])
                         if 'dht_brokers' in mismatch_info:
-                            mismatch_info['dht_brokers'] = {int(k): id_url.field(v) for k,v in mismatch_info['dht_brokers'].items()}
+                            mismatch_info['dht_brokers'] = {int(k): id_url.field(v) for k, v in mismatch_info['dht_brokers'].items()}
                         if 'cooperated_brokers' in mismatch_info:
-                            mismatch_info['cooperated_brokers'] = {int(k): id_url.field(v) for k,v in mismatch_info['cooperated_brokers'].items()}
+                            mismatch_info['cooperated_brokers'] = {int(k): id_url.field(v) for k, v in mismatch_info['cooperated_brokers'].items()}
             except:
                 lg.exc()
                 self.automat('broker-connect-failed', err)
                 return
             if mismatch_info:
-                lg.warn('broker request mismatch at position %d: %r' % (broker_pos, mismatch_info, ))
+                lg.warn('broker request mismatch at position %d: %r' % (broker_pos, mismatch_info))
                 self.automat('brokers-mismatch', **mismatch_info)
                 return
-        lg.err('failed connecting to broker at position %d : %r' % (broker_pos, err, ))
+        lg.err('failed connecting to broker at position %d : %r' % (broker_pos, err))
         self.automat('broker-connect-failed', err)
 
     def _on_broker_hired(self, response_info, broker_pos, *args, **kwargs):
@@ -1374,7 +1355,7 @@ class GroupMember(automat.Automat):
             # skip leading "accepted:" marker
             cooperated_brokers = jsn.loads(strng.to_text(response_info[0].Payload)[9:])
             archive_folder_path = strng.to_text(cooperated_brokers.pop('archive_folder_path', None))
-            cooperated_brokers = {int(k): id_url.field(v) for k,v in cooperated_brokers.items()}
+            cooperated_brokers = {int(k): id_url.field(v) for k, v in cooperated_brokers.items()}
         except:
             lg.exc()
             self.automat('broker-lookup-failed')
@@ -1398,9 +1379,9 @@ class GroupMember(automat.Automat):
                     if resp_payload.startswith('mismatch:'):
                         mismatch_info = jsn.loads(resp_payload[9:])
                         if 'dht_brokers' in mismatch_info:
-                            mismatch_info['dht_brokers'] = {int(k): id_url.field(v) for k,v in mismatch_info['dht_brokers'].items()}
+                            mismatch_info['dht_brokers'] = {int(k): id_url.field(v) for k, v in mismatch_info['dht_brokers'].items()}
                         if 'cooperated_brokers' in mismatch_info:
-                            mismatch_info['cooperated_brokers'] = {int(k): id_url.field(v) for k,v in mismatch_info['cooperated_brokers'].items()}
+                            mismatch_info['cooperated_brokers'] = {int(k): id_url.field(v) for k, v in mismatch_info['cooperated_brokers'].items()}
             except:
                 lg.exc()
                 self.automat('broker-lookup-failed', err)
@@ -1489,19 +1470,21 @@ class GroupMember(automat.Automat):
                 sequence_id=archive_message['sequence_id'],
             ))
         for received_message in received_messages:
-            received_group_messages.append(dict(
-                json_message=received_message['json_message'],
-                direction='incoming',
-                group_key_id=self.group_key_id,
-                producer_id=received_message['producer_id'],
-                sequence_id=received_message['sequence_id'],
-            ))
+            received_group_messages.append(
+                dict(
+                    json_message=received_message['json_message'],
+                    direction='incoming',
+                    group_key_id=self.group_key_id,
+                    producer_id=received_message['producer_id'],
+                    sequence_id=received_message['sequence_id'],
+                )
+            )
             if received_message['sequence_id'] > latest_known_sequence_id:
                 latest_known_sequence_id = received_message['sequence_id']
         self._do_process_group_messages(received_group_messages, latest_known_sequence_id)
 
     def _on_read_archive_failed(self, err, received_messages, latest_known_sequence_id):
-        lg.warn('received %d recent messages but read archived messages failed with: %r' % (len(received_messages), err, ))
+        lg.warn('received %d recent messages but read archived messages failed with: %r' % (len(received_messages), err))
         self.last_sequence_id = latest_known_sequence_id
         groups.set_last_sequence_id(self.group_key_id, latest_known_sequence_id)
         groups.save_group_info(self.group_key_id)
