@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: coins_miner.
 
@@ -72,20 +70,20 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from userid import my_id
+from bitdust.userid import my_id
 
-from lib import utime
+from bitdust.lib import utime
 
-from p2p import commands
-from p2p import p2p_service
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
 
-from transport import callback
+from bitdust.transport import callback
 
-from coins import coins_io
+from bitdust.coins import coins_io
 
 #------------------------------------------------------------------------------
 
@@ -108,6 +106,7 @@ def A(event=None, *args, **kwargs):
         _CoinsMiner.automat(event, *args, **kwargs)
     return _CoinsMiner
 
+
 #------------------------------------------------------------------------------
 
 
@@ -135,7 +134,7 @@ class CoinsMiner(automat.Automat):
         self.max_accountants_connected = 5  # TODO: read from settings
         self.input_data = []
         self.max_mining_counts = 10**8  # TODO: read from settings
-        self.max_mining_seconds = 60 * 3  # TODO: read from settings
+        self.max_mining_seconds = 60*3  # TODO: read from settings
         self.simplification = 2
         self.starter_length = 10
         self.starter_limit = 9999
@@ -207,7 +206,7 @@ class CoinsMiner(automat.Automat):
                 self.doContinueMining(*args, **kwargs)
             elif event == 'new-data-received':
                 self.doPushInputData(*args, **kwargs)
-            elif event == 'cancel' or ( event == 'coin-rejected' and not self.isDecideOK(*args, **kwargs) ):
+            elif event == 'cancel' or (event == 'coin-rejected' and not self.isDecideOK(*args, **kwargs)):
                 self.state = 'READY'
                 self.doSendFail(*args, **kwargs)
                 self.doPullInputData(*args, **kwargs)
@@ -225,7 +224,7 @@ class CoinsMiner(automat.Automat):
             elif event == 'shutdown':
                 self.state = 'CLOSED'
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'stop' or event == 'cancel' or event == 'timer-2min' or ( event == 'lookup-failed' and not self.isAnyAccountants(*args, **kwargs) ):
+            elif event == 'stop' or event == 'cancel' or event == 'timer-2min' or (event == 'lookup-failed' and not self.isAnyAccountants(*args, **kwargs)):
                 self.state = 'STOPPED'
         #---CLOSED---
         elif self.state == 'CLOSED':
@@ -289,7 +288,7 @@ class CoinsMiner(automat.Automat):
         if self.offline_mode or len(self.connected_accountants) >= self.min_accountants_connected:
             self.automat('accountant-connected', '')
             return
-        from coins import accountants_finder
+        from bitdust.coins import accountants_finder
         accountants_finder.A('start', (self.automat, 'read'))
 
     def doPushInputData(self, *args, **kwargs):
@@ -328,7 +327,9 @@ class CoinsMiner(automat.Automat):
         if self.offline_mode:
             self.automat('coin-confirmed')
             return
-        coins = [args[0], ]
+        coins = [
+            args[0],
+        ]
         if _Debug:
             lg.out(_DebugLevel, 'coins_miner.doSendCoinToAccountants: %s' % coins)
         for idurl in self.connected_accountants:
@@ -409,9 +410,10 @@ class CoinsMiner(automat.Automat):
         return False
 
     def _build_starter(self, length):
-        return (''.join(
-            [random.choice(string.uppercase + string.lowercase + string.digits)  # @UndefinedVariable
-                for _ in range(length)])) + '_'
+        return (''.join([
+            random.choice(string.uppercase + string.lowercase + string.digits)  # @UndefinedVariable
+            for _ in range(length)
+        ])) + '_'
 
     def _build_hash(self, payload):
         return hashlib.sha1(payload).hexdigest()
@@ -430,7 +432,7 @@ class CoinsMiner(automat.Automat):
         while True:
             ok = False
             for simpl in range(simplification):
-                if hexdigest.startswith(str(simpl) * difficulty):
+                if hexdigest.startswith(str(simpl)*difficulty):
                     ok = True
                     break
             if ok:
@@ -475,11 +477,12 @@ class CoinsMiner(automat.Automat):
             complexity += 1
             if _Debug:
                 lg.out(_DebugLevel, 'coins_miner.found golden coin, step up complexity: %s' % complexity)
-        return threads.deferToThread(self._mine, coin_json, complexity,
-                                     self.simplification, self.starter_length, self.starter_limit)
+        return threads.deferToThread(self._mine, coin_json, complexity, self.simplification, self.starter_length, self.starter_limit)
+
 
 #------------------------------------------------------------------------------
 
+
 def start_offline_job(coin):
     result = Deferred()
     one_miner = CoinsMiner('coins_miner', 'AT_STARTUP', _DebugLevel, _Debug)
@@ -495,8 +498,10 @@ def start_offline_job(coin):
 
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def _test():
     lg.set_debug_level(20)
     acoin = coins_io.storage_contract_open('http://abc.com/id.xml', 3600, 100)
@@ -504,5 +509,5 @@ def _test():
     reactor.run()  # @UndefinedVariable
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     _test()
