@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: customer_contract_executor
 .. role:: red
@@ -62,13 +60,13 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import nameurl
+from bitdust.lib import nameurl
 
-from userid import my_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -76,6 +74,7 @@ _ActiveCustomerContracts = dict()  # provides CustomerContractExecutor object by
 
 #------------------------------------------------------------------------------
 
+
 def all_contracts():
     global _ActiveCustomerContracts
     return _ActiveCustomerContracts
@@ -115,8 +114,10 @@ def recheck_contract(supplier_idurl):
         contract_executor = init_contract(supplier_idurl)
     contract_executor.automat('recheck')
 
+
 #------------------------------------------------------------------------------
 
+
 class CustomerContractExecutor(automat.Automat):
     """
     This class implements all the functionality of the ``customer_contract_executor()`` state machine.
@@ -238,7 +239,7 @@ class CustomerContractExecutor(automat.Automat):
         """
         Action method.
         """
-        from coins import contract_chain_node
+        from bitdust.coins import contract_chain_node
         contract_chain_node.get_coins_by_chain(
             chain='supplier_customer',
             provider_idurl=self.supplier_idurl,
