@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: supplier_contract_executor
 .. role:: red
@@ -64,21 +62,21 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import nameurl
+from bitdust.lib import nameurl
 
-from storage import accounting
+from bitdust.storage import accounting
 
-from userid import my_id
+from bitdust.userid import my_id
 
-from p2p import commands
-from p2p import p2p_service
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
 
-from coins import coins_io
-from coins import contract_chain_node
+from bitdust.coins import coins_io
+from bitdust.coins import contract_chain_node
 
 #------------------------------------------------------------------------------
 
@@ -86,6 +84,7 @@ _ActiveSupplierContracts = dict()  # provides SupplierContractExecutor object by
 
 #------------------------------------------------------------------------------
 
+
 def all_contracts():
     global _ActiveSupplierContracts
     return _ActiveSupplierContracts
@@ -125,8 +124,10 @@ def recheck_contract(customer_idurl):
         contract_executor = init_contract(customer_idurl)
     contract_executor.automat('recheck')
 
+
 #------------------------------------------------------------------------------
 
+
 class SupplierContractExecutor(automat.Automat):
     """
     This class implements all the functionality of the ``supplier_contract_executor()`` state machine.
@@ -147,7 +148,7 @@ class SupplierContractExecutor(automat.Automat):
         Method to initialize additional variables and flags
         at creation phase of supplier_contract_executor() machine.
         """
-        self.current_duration = 60 * 60  # TODO: read from settings
+        self.current_duration = 60*60  # TODO: read from settings
 
     def A(self, event, *args, **kwargs):
         """
@@ -237,7 +238,7 @@ class SupplierContractExecutor(automat.Automat):
         """
         if not coins:
             return False
-        # TODO: 
+        # TODO:
         return True
 
     def isChainClosed(self, coins):
@@ -246,7 +247,7 @@ class SupplierContractExecutor(automat.Automat):
         """
         if not coins:
             return False
-        # TODO: 
+        # TODO:
         return True
 
     def isMyCoinExist(self, coins):
@@ -255,7 +256,7 @@ class SupplierContractExecutor(automat.Automat):
         """
         if not coins:
             return False
-        # TODO: 
+        # TODO:
         return True
 
     def doRequestCoins(self, *args, **kwargs):
@@ -286,11 +287,13 @@ class SupplierContractExecutor(automat.Automat):
         coin_json_sined = coins_io.add_signature(coin_json, 'creator')
         p2p_service.SendCoin(
             self.customer_idurl,
-            [coin_json_sined, ],
+            [
+                coin_json_sined,
+            ],
             callbacks={
                 commands.Ack(): self._on_signature_ack,
                 commands.Fail(): self._on_signature_fail,
-            }
+            },
         )
 
     def doSendFirstCoin(self, *args, **kwargs):
@@ -298,9 +301,9 @@ class SupplierContractExecutor(automat.Automat):
         Action method.
         """
         coin_json = args[0]
-        contract_chain_node.send_to_miner(
-            [coin_json, ],
-        ).addCallbacks(
+        contract_chain_node.send_to_miner([
+            coin_json,
+        ], ).addCallbacks(
             self._on_coin_mined,
             self._on_coin_failed,
         )
