@@ -22,7 +22,6 @@
 #
 #
 #
-
 """
 .. module:: identitycache.
 
@@ -58,18 +57,18 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import net_misc
-from lib import nameurl
-from lib import strng
+from bitdust.lib import net_misc
+from bitdust.lib import nameurl
+from bitdust.lib import strng
 
-from userid import identity
-from userid import id_url
+from bitdust.userid import identity
+from bitdust.userid import id_url
 
-from contacts import identitydb
+from bitdust.contacts import identitydb
 
-from p2p import p2p_stats
+from bitdust.p2p import p2p_stats
 
 #------------------------------------------------------------------------------
 
@@ -90,8 +89,10 @@ def shutdown():
     if _Debug:
         lg.out(_DebugLevel, 'identitycache.shutdown')
 
+
 #------------------------------------------------------------------------------
 
+
 def caching():
     global _CachingTasks
     return _CachingTasks
@@ -106,8 +107,10 @@ def add_callback(idurl, ignore_errors=False):
     caching()[idurl].append(defer_obj)
     return defer_obj
 
+
 #------------------------------------------------------------------------------
 
+
 def get_one(idurl):
     """
     An alias for `FromCache()` method.
@@ -115,14 +118,14 @@ def get_one(idurl):
     return FromCache(id_url.to_original(idurl))
 
 
-def start_one(idurl, timeout=10, try_other_sources=True):
+def start_one(idurl, timeout=15, try_other_sources=True):
     """
     An alias for `immediatelyCaching()` method.
     """
     return immediatelyCaching(id_url.to_original(idurl), timeout=timeout, try_other_sources=try_other_sources)
 
 
-def start_multiple(idurl_list, timeout=10, try_other_sources=True):
+def start_multiple(idurl_list, timeout=15, try_other_sources=True):
     """
     Executes in parallel multiple `immediatelyCaching()` calls on the list of IDURL items.
     Returns `DeferredList` object.
@@ -134,8 +137,10 @@ def start_multiple(idurl_list, timeout=10, try_other_sources=True):
             dl.append(immediatelyCaching(idurl, timeout=timeout, try_other_sources=try_other_sources))
     return DeferredList(dl, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
+
 def Clear(excludeList=None):
     """
     Clear all cached identities.
@@ -286,8 +291,7 @@ def RemapContactAddress(address):
     if idurl is not None and HasLocalIP(idurl):
         newaddress = (GetLocalIP(idurl), address[1])
         if _Debug:
-            lg.out(_DebugLevel, 'identitycache.RemapContactAddress for %s [%s] -> [%s]' % (
-                nameurl.GetName(idurl), str(address), str(newaddress)))
+            lg.out(_DebugLevel, 'identitycache.RemapContactAddress for %s [%s] -> [%s]' % (nameurl.GetName(idurl), str(address), str(newaddress)))
         return newaddress
     return address
 
@@ -302,8 +306,7 @@ def OverrideIdentity(idurl, xml_src):
         if idurl.original() in _OverriddenIdentities:
             if idurl.to_bin() not in _OverriddenIdentities:
                 _OverriddenIdentities[idurl.to_bin()] = _OverriddenIdentities.pop(idurl.original())
-                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (
-                    idurl.original(), idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (idurl.original(), idurl.to_bin()))
     idurl = id_url.to_bin(idurl)
     xml_src = strng.to_text(xml_src.strip())
     if idurl in _OverriddenIdentities:
@@ -340,8 +343,7 @@ def StopOverridingIdentity(idurl):
         if idurl.original() in _OverriddenIdentities:
             if idurl.to_bin() not in _OverriddenIdentities:
                 _OverriddenIdentities[idurl.to_bin()] = _OverriddenIdentities.pop(idurl.original())
-                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (
-                    idurl.original(), idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (idurl.original(), idurl.to_bin()))
     idurl = id_url.to_bin(idurl)
     result = _OverriddenIdentities.pop(idurl, None)
     if _Debug:
@@ -359,8 +361,7 @@ def IsOverridden(idurl):
         if idurl.original() in _OverriddenIdentities:
             if idurl.to_bin() not in _OverriddenIdentities:
                 _OverriddenIdentities[idurl.to_bin()] = _OverriddenIdentities.pop(idurl.original())
-                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (
-                    idurl.original(), idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (idurl.original(), idurl.to_bin()))
     idurl = id_url.to_bin(idurl)
     return idurl in _OverriddenIdentities
 
@@ -372,11 +373,11 @@ def ReadOverriddenIdentityXMLSource(idurl):
         if idurl.original() in _OverriddenIdentities:
             if idurl.to_bin() not in _OverriddenIdentities:
                 _OverriddenIdentities[idurl.to_bin()] = _OverriddenIdentities.pop(idurl.original())
-                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (
-                    idurl.original(), idurl.to_bin()))
+                lg.info('detected and processed idurl rotate for overridden identity : %r -> %r' % (idurl.original(), idurl.to_bin()))
     idurl = id_url.to_bin(idurl)
     return _OverriddenIdentities.get(idurl, None)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -394,12 +395,12 @@ def getPageFail(x, idurl):
     This is called when identity request is failed.
     """
     if _Debug:
-        lg.out(_DebugLevel, "identitycache.getPageFail NETERROR in request to " + idurl)
+        lg.out(_DebugLevel, 'identitycache.getPageFail NETERROR in request to ' + idurl)
     p2p_stats.count_identity_cache(idurl, 0)
     return x
 
 
-def pageRequestTwisted(idurl, timeout=0):
+def pageRequestTwisted(idurl, timeout=15):
     """
     Request an HTML page - this can be an user identity.
     """
@@ -409,7 +410,7 @@ def pageRequestTwisted(idurl, timeout=0):
     return d
 
 
-def scheduleForCaching(idurl, timeout=0):
+def scheduleForCaching(idurl, timeout=15):
     """
     Even if we have a copy in cache we are to try and read another one.
     """
@@ -417,8 +418,10 @@ def scheduleForCaching(idurl, timeout=0):
         lg.out(_DebugLevel, 'identitycache.scheduleForCaching %r' % idurl)
     return pageRequestTwisted(idurl, timeout)
 
+
 #------------------------------------------------------------------------------
 
+
 def last_time_cached(idurl):
     global _LastTimeCached
     idurl = id_url.to_original(idurl)
@@ -437,7 +440,7 @@ def on_caching_task_failed(err, idurl, ignore_errors):
     return err
 
 
-def immediatelyCaching(idurl, timeout=10, try_other_sources=True, ignore_errors=False):
+def immediatelyCaching(idurl, timeout=15, try_other_sources=True, ignore_errors=False):
     """
     A smart method to cache some identity and get results in callbacks.
     """
@@ -494,7 +497,7 @@ def immediatelyCaching(idurl, timeout=10, try_other_sources=True, ignore_errors=
 
         d = net_misc.getPageTwisted(url=next_idurl, timeout=timeout)
         d.addCallback(_success, idurl)
-        d.addErrback(_next_source, idurl, sources, pos+1)
+        d.addErrback(_next_source, idurl, sources, pos + 1)
         return None
 
     def _fail(err, idurl):
@@ -506,7 +509,7 @@ def immediatelyCaching(idurl, timeout=10, try_other_sources=True, ignore_errors=
         if not try_other_sources:
             p2p_stats.count_identity_cache(idurl, 0)
             _LastTimeCached.pop(idurl, None)
-            lg.warn('[cache failed] %s : %s' % (idurl, err.getErrorMessage(), ))
+            lg.warn('[cache failed] %s : %s' % (idurl, err.getErrorMessage()))
             defer_results = caching().pop(idurl, [])
             for result in defer_results:
                 if result and not result.called:
@@ -539,13 +542,13 @@ def immediatelyCaching(idurl, timeout=10, try_other_sources=True, ignore_errors=
             lg.args(_DebugLevel, idurl=idurl, latest_idurl=latest_idurl, latest_ident=latest_ident, sources=sources)
 
         if sources:
-            lg.warn('[cache failed] %s : %s  but will try %d more sources' % (idurl, err.getErrorMessage(), len(sources), ))
+            lg.warn('[cache failed] %s : %s  but will try %d more sources' % (idurl, err.getErrorMessage(), len(sources)))
             _next_source(None, idurl, sources, 0)
             return None
 
         p2p_stats.count_identity_cache(idurl, 0)
         _LastTimeCached.pop(idurl, None)
-        lg.warn('[cache failed] and also no other sources found %s : %s' % (idurl, err.getErrorMessage(), ))
+        lg.warn('[cache failed] and also no other sources found %s : %s' % (idurl, err.getErrorMessage()))
         defer_results = caching().pop(idurl, [])
         if _Debug:
             lg.args(_DebugLevel, known=len(id_url.known().keys()), defer_results=len(defer_results))
@@ -575,8 +578,10 @@ def immediatelyCaching(idurl, timeout=10, try_other_sources=True, ignore_errors=
         lg.out(_DebugLevel, 'identitycache.immediatelyCaching started new task for %r' % idurl)
     return _start_one(idurl, ignore_errors=ignore_errors)
 
+
 #------------------------------------------------------------------------------
 
+
 def SetLocalIPs(local_ips):
     """
     This method is to build an index for local IP's.
@@ -604,8 +609,10 @@ def SearchLocalIP(ip):
     """
     return identitydb.search_local_ip(ip)
 
+
 #------------------------------------------------------------------------------
 
+
 def _test():
     import logging
     logging.basicConfig(level=logging.DEBUG)
@@ -616,7 +623,7 @@ def _test():
     # twisted_log.startLogging(sys.stdout)
     lg.set_debug_level(20)
 
-    from main import settings
+    from bitdust.main import settings
     settings.init()
     settings.update_proxy_settings()
 
@@ -631,8 +638,8 @@ def _test():
     shutdown()
     settings.shutdown()
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     _test()
