@@ -22,7 +22,6 @@
 #
 #
 #
-
 """
 .. module:: my_keys.
 
@@ -52,28 +51,28 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from lib import misc
-from lib import strng
-from lib import jsn
-from lib import utime
+from bitdust.lib import misc
+from bitdust.lib import strng
+from bitdust.lib import jsn
+from bitdust.lib import utime
 
-from system import local_fs
+from bitdust.system import local_fs
 
-from main import settings
-from main import events
-from main import listeners
+from bitdust.main import settings
+from bitdust.main import events
+from bitdust.main import listeners
 
-from crypt import key
-from crypt import rsa_key
-from crypt import hashes
+from bitdust.crypt import key
+from bitdust.crypt import rsa_key
+from bitdust.crypt import hashes
 
-from userid import global_id
-from userid import id_url
-from userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import id_url
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -84,6 +83,7 @@ _LocalKeysIndex = {}
 
 #------------------------------------------------------------------------------
 
+
 def init():
     if _Debug:
         lg.out(_DebugLevel, 'my_keys.init')
@@ -99,8 +99,10 @@ def shutdown():
     local_keys_index().clear()
     _LatestLocalKeyID = 0
 
+
 #------------------------------------------------------------------------------
 
+
 def key_obj(key_id=None):
     """
     Alias.
@@ -145,8 +147,10 @@ def local_keys_index():
     global _LocalKeysIndex
     return _LocalKeysIndex
 
+
 #------------------------------------------------------------------------------
 
+
 def is_key_registered(key_id, include_master=True):
     """
     Returns True if this key is known.
@@ -180,8 +184,10 @@ def is_key_private(key_id, include_master=True):
             return True
     return not key_obj(key_id).isPublic()
 
+
 #------------------------------------------------------------------------------
 
+
 def make_key_id(alias, creator_idurl=None, creator_glob_id=None):
     """
     Every key has a creator, and we include his IDURL in the final key_id string.
@@ -272,8 +278,10 @@ def get_creator_idurl(key_id, as_field=True):
     _, _, creator_glob_id = key_id.partition('$')
     return global_id.glob2idurl(creator_glob_id, as_field=as_field)
 
+
 #------------------------------------------------------------------------------
 
+
 def scan_local_keys(keys_folder=None):
     global _LatestLocalKeyID
     if not keys_folder:
@@ -316,14 +324,14 @@ def scan_local_keys(keys_folder=None):
             continue
         _LatestLocalKeyID += 1
         new_local_key_id = _LatestLocalKeyID
-        lg.warn('about to register key %r with local_key_id=%r' % (key_id, new_local_key_id, ))
+        lg.warn('about to register key %r with local_key_id=%r' % (key_id, new_local_key_id))
         known_keys()[key_id].local_key_id = new_local_key_id
         save_key(key_id, keys_folder=keys_folder)
         registered_count += 1
     unregistered_keys = []
     save_latest_local_key_id(keys_folder=keys_folder)
     if _Debug:
-        lg.out(_DebugLevel, '    %d keys found and %d registered' % (count, registered_count, ))
+        lg.out(_DebugLevel, '    %d keys found and %d registered' % (count, registered_count))
 
 
 def read_key_file(key_id, keys_folder=None):
@@ -385,21 +393,26 @@ def load_key(key_id, keys_folder=None):
             local_keys()[key_object.local_key_id] = key_id
             local_keys_index()[key_object.toPublicString()] = key_object.local_key_id
             if _Debug:
-                lg.out(_DebugLevel, 'my_keys.load_key %r  label=%r  active=%r  is_private=%r  local_key_id=%r  from %s' % (
-                    key_id, key_object.label, key_object.active, not key_object.isPublic(), key_object.local_key_id, keys_folder, ))
+                lg.out(_DebugLevel, 'my_keys.load_key %r  label=%r  active=%r  is_private=%r  local_key_id=%r  from %s' % (key_id, key_object.label, key_object.active, not key_object.isPublic(), key_object.local_key_id, keys_folder))
         else:
             lg.warn('for key %r local_key_id was not set' % key_id)
-    events.send('key-loaded', data=dict(key_id=key_id, label=key_object.label, key_size=key_object.size(), ))
-    listeners.push_snapshot('key', snap_id=key_id, data=make_key_info(
-        key_object=key_object,
+    events.send('key-loaded', data=dict(
         key_id=key_id,
-        event='key-loaded',
-        include_private=False,
-        include_local_id=True,
-        include_signature=True,
-        include_label=True,
-        include_state=True,
+        label=key_object.label,
+        key_size=key_object.size(),
     ))
+    listeners.push_snapshot(
+        'key', snap_id=key_id, data=make_key_info(
+            key_object=key_object,
+            key_id=key_id,
+            event='key-loaded',
+            include_private=False,
+            include_local_id=True,
+            include_signature=True,
+            include_label=True,
+            include_state=True,
+        )
+    )
     return True
 
 
@@ -421,12 +434,12 @@ def save_key(key_id, keys_folder=None):
         key_dict = key_object.toDict(include_private=True)
         key_string = jsn.dumps(key_dict, indent=1, separators=(',', ':'))
     if not bpio.WriteTextFile(key_filepath, key_string):
-        lg.warn('failed saving key %r to %r' % (key_id, key_filepath, ))
+        lg.warn('failed saving key %r to %r' % (key_id, key_filepath))
         return False
     local_keys()[key_object.local_key_id] = key_id
     local_keys_index()[key_object.toPublicString()] = key_object.local_key_id
     if _Debug:
-        lg.out(_DebugLevel, 'my_keys.save_key stored key %r with local_key_id=%r in %r' % (key_id, key_object.local_key_id, key_filepath, ))
+        lg.out(_DebugLevel, 'my_keys.save_key stored key %r with local_key_id=%r in %r' % (key_id, key_object.local_key_id, key_filepath))
     return True
 
 
@@ -454,8 +467,10 @@ def save_latest_local_key_id(keys_folder=None):
         return False
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def generate_key(key_id, label='', active=True, key_size=4096, keys_folder=None):
     global _LatestLocalKeyID
     key_id = latest_key_id(key_id)
@@ -463,7 +478,7 @@ def generate_key(key_id, label='', active=True, key_size=4096, keys_folder=None)
         lg.warn('key %r already registered' % key_id)
         return None
     if not label:
-        label = 'key%s' % utime.make_timestamp() 
+        label = 'key%s' % utime.make_timestamp()
     if _Debug:
         lg.out(_DebugLevel, 'my_keys.generate_key %r of %d bits, label=%r' % (key_id, key_size, label))
     _LatestLocalKeyID += 1
@@ -479,17 +494,23 @@ def generate_key(key_id, label='', active=True, key_size=4096, keys_folder=None)
     if not keys_folder:
         keys_folder = settings.KeyStoreDir()
     save_key(key_id, keys_folder=keys_folder)
-    events.send('key-generated', data=dict(key_id=key_id, label=label, key_size=key_size, ))
-    listeners.push_snapshot('key', snap_id=key_id, data=make_key_info(
-        key_object=key_object,
+    events.send('key-generated', data=dict(
         key_id=key_id,
-        event='key-generated',
-        include_private=False,
-        include_local_id=True,
-        include_signature=True,
-        include_label=True,
-        include_state=True,
+        label=label,
+        key_size=key_size,
     ))
+    listeners.push_snapshot(
+        'key', snap_id=key_id, data=make_key_info(
+            key_object=key_object,
+            key_id=key_id,
+            event='key-generated',
+            include_private=False,
+            include_local_id=True,
+            include_signature=True,
+            include_label=True,
+            include_state=True,
+        )
+    )
     return key_object
 
 
@@ -506,8 +527,7 @@ def register_key(key_id, key_object_or_string, label='', active=True, keys_folde
     if strng.is_string(key_object_or_string):
         key_object_or_string = strng.to_bin(key_object_or_string)
         if _Debug:
-            lg.out(_DebugLevel, 'my_keys.register_key %r from %d bytes openssh_input_string' % (
-                key_id, len(key_object_or_string)))
+            lg.out(_DebugLevel, 'my_keys.register_key %r from %d bytes openssh_input_string' % (key_id, len(key_object_or_string)))
         key_object = unserialize_key_to_object(key_object_or_string)
         if not key_object:
             lg.warn('invalid openssh string, unserialize_key_to_object() failed')
@@ -524,7 +544,10 @@ def register_key(key_id, key_object_or_string, label='', active=True, keys_folde
             known_key_id = latest_key_id(known_key_id)
             if known_key_id != key_id:
                 raise Exception('must not register same key with local_key_id=%r twice with different key_id: %r ~ %r' % (
-                    known_local_key_id, known_key_id, key_id, ))
+                    known_local_key_id,
+                    known_key_id,
+                    key_id,
+                ))
     new_local_key_id = known_local_key_id
     if new_local_key_id is None:
         _LatestLocalKeyID += 1
@@ -537,17 +560,23 @@ def register_key(key_id, key_object_or_string, label='', active=True, keys_folde
     if _Debug:
         lg.out(_DebugLevel, '    key %r registered' % key_id)
     save_key(key_id, keys_folder=keys_folder)
-    events.send('key-registered', data=dict(key_id=key_id, label=label, key_size=key_object.size(), ))
-    listeners.push_snapshot('key', snap_id=key_id, data=make_key_info(
-        key_object=key_object,
+    events.send('key-registered', data=dict(
         key_id=key_id,
-        event='key-registered',
-        include_private=False,
-        include_local_id=True,
-        include_signature=True,
-        include_label=True,
-        include_state=True,
+        label=label,
+        key_size=key_object.size(),
     ))
+    listeners.push_snapshot(
+        'key', snap_id=key_id, data=make_key_info(
+            key_object=key_object,
+            key_id=key_id,
+            event='key-registered',
+            include_private=False,
+            include_local_id=True,
+            include_signature=True,
+            include_label=True,
+            include_state=True,
+        )
+    )
     return key_object
 
 
@@ -576,16 +605,18 @@ def erase_key(key_id, keys_folder=None):
     if _Debug:
         lg.out(_DebugLevel, '    key %s removed, file %s deleted' % (key_id, key_filepath))
     events.send('key-erased', data=dict(key_id=key_id, is_private=is_private))
-    listeners.push_snapshot('key', snap_id=key_id, deleted=True, data=make_key_info(
-        key_object=None,
-        key_id=key_id,
-        event='key-erased',
-        include_private=False,
-        include_local_id=True,
-        include_signature=True,
-        include_label=True,
-        include_state=True,
-    ))
+    listeners.push_snapshot(
+        'key', snap_id=key_id, deleted=True, data=make_key_info(
+            key_object=None,
+            key_id=key_id,
+            event='key-erased',
+            include_private=False,
+            include_local_id=True,
+            include_signature=True,
+            include_label=True,
+            include_state=True,
+        )
+    )
     return True
 
 
@@ -637,7 +668,7 @@ def rename_key(current_key_id, new_key_id, keys_folder=None):
     save_key(new_key_id, keys_folder=keys_folder)
     gc.collect()
     if _Debug:
-        lg.out(_DebugLevel, 'my_keys.rename_key   key %s renamed to %s' % (current_key_id, new_key_id, ))
+        lg.out(_DebugLevel, 'my_keys.rename_key   key %s renamed to %s' % (current_key_id, new_key_id))
     events.send('key-renamed', data=dict(old_key_id=current_key_id, new_key_id=new_key_id, is_private=is_private))
     return True
 
@@ -663,25 +694,36 @@ def sign_key(key_id, keys_folder=None, ignore_shared_keys=False, save=True):
         include_private=not key_object.isPublic(),
         generate_signature=True,
     )
-    key_object.signed = (signed_key_info['signature'], signed_key_info['signature_pubkey'], )
+    key_object.signed = (
+        signed_key_info['signature'],
+        signed_key_info['signature_pubkey'],
+    )
     known_keys()[key_id] = key_object
     if save:
         save_key(key_id, keys_folder=keys_folder)
-    events.send('key-signed', data=dict(key_id=key_id, label=key_object.label, key_size=key_object.size(), ))
-    listeners.push_snapshot('key', snap_id=key_id, data=make_key_info(
-        key_object=key_object,
+    events.send('key-signed', data=dict(
         key_id=key_id,
-        event='key-signed',
-        include_private=False,
-        include_local_id=True,
-        include_signature=True,
-        include_label=True,
-        include_state=True,
+        label=key_object.label,
+        key_size=key_object.size(),
     ))
+    listeners.push_snapshot(
+        'key', snap_id=key_id, data=make_key_info(
+            key_object=key_object,
+            key_id=key_id,
+            event='key-signed',
+            include_private=False,
+            include_local_id=True,
+            include_signature=True,
+            include_label=True,
+            include_state=True,
+        )
+    )
     return key_object
 
+
 #------------------------------------------------------------------------------
 
+
 def sign(key_id, inp):
     """
     Sign some ``inp`` string with given key.
@@ -719,8 +761,10 @@ def verify(key_id, hashcode, signature):
     result = key_object.verify(signature, hashcode)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def encrypt(key_id, inp):
     """
     Encrypt ``inp`` string using given private key ID.
@@ -750,7 +794,7 @@ def encrypt(key_id, inp):
             raise Exception('key load failed: %s' % key_id)
     key_object = known_keys()[key_id]
     if _Debug:
-        lg.out(_DebugLevel, 'my_keys.encrypt  payload of %d bytes with key %s' % (len(inp), key_id, ))
+        lg.out(_DebugLevel, 'my_keys.encrypt  payload of %d bytes with key %s' % (len(inp), key_id))
     result = key_object.encrypt(inp)
     return result
 
@@ -784,12 +828,14 @@ def decrypt(key_id, inp):
             raise Exception('key load failed: %s' % key_id)
     key_object = known_keys()[key_id]
     if _Debug:
-        lg.out(_DebugLevel, 'my_keys.decrypt  payload of %d bytes with registered key %s' % (len(inp), key_id, ))
+        lg.out(_DebugLevel, 'my_keys.decrypt  payload of %d bytes with registered key %s' % (len(inp), key_id))
     result = key_object.decrypt(inp)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def serialize_key(key_id):
     key_id = latest_key_id(key_id)
     if not is_key_registered(key_id):
@@ -810,8 +856,10 @@ def unserialize_key_to_object(raw_string):
         return None
     return key_object
 
+
 #------------------------------------------------------------------------------
 
+
 def get_public_key_raw(key_id):
     kobj = key_obj(key_id)
     return kobj.toPublicString()
@@ -852,8 +900,10 @@ def get_local_key(local_key_id):
         return my_id.getGlobalID('master')
     return local_keys().get(local_key_id)
 
+
 #------------------------------------------------------------------------------
 
+
 def is_active(key_id):
     """
     Returns True if given key has "active" state. If key is not set to "active" state, certain parts of the software should not use it.
@@ -870,8 +920,10 @@ def set_active(key_id, active=True):
         return
     key_obj(key_id).active = active
 
+
 #------------------------------------------------------------------------------
 
+
 def make_master_key_info(include_private=False):
     r = {
         'key_id': my_id.getGlobalID(key_alias='master'),
@@ -879,8 +931,7 @@ def make_master_key_info(include_private=False):
         'label': my_id.getGlobalID(key_alias='master'),
         'active': True,
         'creator': my_id.getIDURL(),
-        'is_public': key.MyPrivateKeyObject().isPublic(),
-        # 'fingerprint': str(key.MyPrivateKeyObject().fingerprint()),
+        'is_public': key.MyPrivateKeyObject().isPublic(),  # 'fingerprint': str(key.MyPrivateKeyObject().fingerprint()),
         # 'type': str(key.MyPrivateKeyObject().type()),
         # 'ssh_type': str(key.MyPrivateKeyObject().sshType()),
         'public': strng.to_text(key.MyPrivateKeyObject().toPublicString()),
@@ -896,9 +947,7 @@ def make_master_key_info(include_private=False):
     return r
 
 
-def make_key_info(key_object, key_id=None, key_alias=None, creator_idurl=None,
-                  include_private=False, generate_signature=False, include_signature=False,
-                  include_local_id=False, include_label=True, include_state=False, event=None):
+def make_key_info(key_object, key_id=None, key_alias=None, creator_idurl=None, include_private=False, generate_signature=False, include_signature=False, include_local_id=False, include_label=True, include_state=False, event=None):
     if key_id:
         key_id = latest_key_id(key_id)
         key_alias, creator_idurl = split_key_id(key_id)
@@ -989,18 +1038,27 @@ def read_key_info(key_json):
         key_object.label = strng.to_text(key_json.get('label', ''))
         key_object.active = key_json.get('active', True)
         if 'signature' in key_json and 'signature_pubkey' in key_json:
-            key_object.signed = (key_json['signature'], key_json['signature_pubkey'], )
+            key_object.signed = (
+                key_json['signature'],
+                key_json['signature_pubkey'],
+            )
     except:
         lg.exc()
         raise Exception('failed reading key info')
     return latest_key_id(key_id), key_object
 
+
 #------------------------------------------------------------------------------
 
+
 def sign_key_info(key_info):
     key_info['signature_pubkey'] = key.MyPublicKey()
     hash_items = []
-    for field in ['alias', 'public', 'signature_pubkey', ]:
+    for field in [
+        'alias',
+        'public',
+        'signature_pubkey',
+    ]:
         hash_items.append(strng.to_text(key_info[field]))
     hash_text = '-'.join(hash_items)
     if _Debug:
@@ -1015,7 +1073,11 @@ def verify_key_info_signature(key_info):
         lg.warn('signature was not found in the key info')
         return False
     hash_items = []
-    for field in ['alias', 'public', 'signature_pubkey', ]:
+    for field in [
+        'alias',
+        'public',
+        'signature_pubkey',
+    ]:
         hash_items.append(strng.to_text(key_info[field]))
     hash_text = '-'.join(hash_items)
     if _Debug:
@@ -1025,8 +1087,10 @@ def verify_key_info_signature(key_info):
     result = key.VerifySignature(key_info['signature_pubkey'], hash_bin, signature_bin)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def check_rename_my_keys(prefix=None):
     """
     Make sure all my keys have correct names according to known latest identities I have cached.
@@ -1049,8 +1113,10 @@ def check_rename_my_keys(prefix=None):
     for current_key_id, new_key_id in keys_to_be_renamed.items():
         rename_key(current_key_id, new_key_id)
 
+
 #------------------------------------------------------------------------------
 
+
 def populate_keys():
     for key_id, key_object in known_keys().items():
         listeners.push_snapshot('key', snap_id=key_id, data=make_key_info(
@@ -1064,6 +1130,7 @@ def populate_keys():
             include_state=True,
         ))
 
+
 #------------------------------------------------------------------------------
 
 if __name__ == '__main__':
