@@ -22,7 +22,6 @@
 #
 #
 #
-
 """
 .. module:: rsa_key.
 
@@ -32,7 +31,6 @@
 #------------------------------------------------------------------------------
 
 from __future__ import absolute_import
-import os
 
 #------------------------------------------------------------------------------
 
@@ -53,19 +51,19 @@ except:
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import strng
+from bitdust.lib import strng
 
-from system import local_fs
+from bitdust.system import local_fs
 
-from crypt import hashes
-from crypt import number
+from bitdust.crypt import hashes
+from bitdust.crypt import number
 
 #------------------------------------------------------------------------------
 
-class RSAKey(object):
 
+class RSAKey(object):
     def __init__(self):
         self.keyObject = None
         self.local_key_id = None
@@ -123,7 +121,10 @@ class RSAKey(object):
             self.active = key_dict.get('active', True)
             self.local_key_id = key_dict.get('local_key_id', None)
             if 'signature' in key_dict and 'signature_pubkey' in key_dict:
-                self.signed = (key_dict['signature'], key_dict['signature_pubkey'], )
+                self.signed = (
+                    key_dict['signature'],
+                    key_dict['signature_pubkey'],
+                )
         del key_src
         # gc.collect()
         return result
@@ -228,9 +229,12 @@ class RSAKey(object):
         try:
             pkcs1_15.new(self.keyObject).verify(h, signature_bytes)
             result = True
-        except (ValueError, TypeError, ):
+        except (
+            ValueError,
+            TypeError,
+        ):
             # do not raise any exception... just return False
-            lg.exc('signature=%r message=%r' % (signature, message, ))
+            lg.exc('signature=%r message=%r' % (signature, message))
         if _Debug:
             if _CryptoLog:
                 lg.args(_DebugLevel, result=result, signature=signature)
@@ -252,4 +256,3 @@ class RSAKey(object):
 
     def isSigned(self):
         return self.signed is not None
-
