@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: signed.
 
@@ -60,27 +59,28 @@ from twisted.internet import threads
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
+from bitdust.system import bpio
 
-from p2p import commands
+from bitdust.p2p import commands
 
-from lib import packetid
-from lib import nameurl
-from lib import utime
-from lib import strng
-from lib import serialization
+from bitdust.lib import packetid
+from bitdust.lib import nameurl
+from bitdust.lib import utime
+from bitdust.lib import strng
+from bitdust.lib import serialization
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from crypt import key
+from bitdust.crypt import key
 
-from userid import my_id
-from userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import id_url
 
 #------------------------------------------------------------------------------
 
+
 class Packet(object):
     """
     Init with: Command, OwnerID, CreatorID, PacketID, Payload, RemoteID The
@@ -95,8 +95,18 @@ class Packet(object):
     messages. This is outside work, here is most important things to
     make all network working.
     """
-
-    def __init__(self, Command, OwnerID, CreatorID, PacketID, Payload, RemoteID, KeyID=None, Date=None, Signature=None, ):
+    def __init__(
+        self,
+        Command,
+        OwnerID,
+        CreatorID,
+        PacketID,
+        Payload,
+        RemoteID,
+        KeyID=None,
+        Date=None,
+        Signature=None,
+    ):
         """
         Init all fields and sign the packet.
         """
@@ -110,7 +120,7 @@ class Packet(object):
         # on the local machine.  Can be used for filenames, and to prevent duplicates.
         self.PacketID = strng.to_text(PacketID)
         # create a string to remember current world time
-        self.Date = strng.to_text(Date or utime.sec1970_to_datetime_utc().strftime("%Y/%m/%d %I:%M:%S %p"))
+        self.Date = strng.to_text(Date or utime.sec1970_to_datetime_utc().strftime('%Y/%m/%d %I:%M:%S %p'))
         # datetime.datetime.now().strftime("%Y/%m/%d %I:%M:%S %p")
         # main body of binary data
         self.Payload = strng.to_bin(Payload)
@@ -133,10 +143,7 @@ class Packet(object):
         args = '%s(%s)' % (str(self.Command), str(self.PacketID))
         if _Debug:
             if lg.is_debug(_DebugLevel):
-                args += ' %s|%s for %s' % (
-                    nameurl.GetName(self.OwnerID),
-                    nameurl.GetName(self.CreatorID),
-                    nameurl.GetName(self.RemoteID))
+                args += ' %s|%s for %s' % (nameurl.GetName(self.OwnerID), nameurl.GetName(self.CreatorID), nameurl.GetName(self.RemoteID))
         return 'signed{%s}' % args
 
     def Sign(self):
@@ -177,7 +184,7 @@ class Packet(object):
 #         if _Debug:
 #             if _LogSignVerify:
 #                 try:
-#                     from main import settings
+#                     from bitdust.main import settings
 #                     open(os.path.join(settings.LogsDir(), 'crypt.log'), 'wb').write(b'\nGenerateHashBase:\n' + stufftosum + b'\n\n')
 #                 except:
 #                     lg.exc()
@@ -199,17 +206,17 @@ class Packet(object):
         #     signature = key.Sign(_hash_base)
         # else:
         #     signature = my_keys.sign(self.KeyID, _hash_base)
-#         if _Debug:
-#             if _LogSignVerify:
-#                 try:
-#                     from main import settings
-#                     try:
-#                         from Cryptodome.Util import number
-#                     except:
-#                         from Crypto.Util import number  # @UnresolvedImport @Reimport
-#                     open(os.path.join(settings.LogsDir(), 'crypt.log'), 'wb').write(b'\GenerateSignature:\n' + strng.to_bin(number.long_to_bytes(signature)) + b'\n\n')
-#                 except:
-#                     lg.exc()
+        #         if _Debug:
+        #             if _LogSignVerify:
+        #                 try:
+        #                     from bitdust.main import settings
+        #                     try:
+        #                         from Cryptodome.Util import number
+        #                     except:
+        #                         from Crypto.Util import number  # @UnresolvedImport @Reimport
+        #                     open(os.path.join(settings.LogsDir(), 'crypt.log'), 'wb').write(b'\GenerateSignature:\n' + strng.to_bin(number.long_to_bytes(signature)) + b'\n\n')
+        #                 except:
+        #                     lg.exc()
         return signature
 
     def SignatureChecksOut(self, raise_signature_invalid=False):
@@ -230,13 +237,14 @@ class Packet(object):
             # CreatorIdentity = OwnerIdentity
             if raise_signature_invalid:
                 raise Exception('can not verify signed packet, unknown identity %r' % self.CreatorID)
-            lg.err("could not get Identity for %r so returning False" % self.CreatorID)
+            lg.err('could not get Identity for %r so returning False' % self.CreatorID)
             return False
 
+
 #         if _Debug:
 #             if _LogSignVerify:
 #                 try:
-#                     from main import settings
+#                     from bitdust.main import settings
 #                     try:
 #                         from Cryptodome.Util import number
 #                     except:
@@ -247,13 +255,13 @@ class Packet(object):
 
         Result = key.Verify(CreatorIdentity, self.GenerateHash(), self.Signature)
 
-#         if _Debug:
-#             if _LogSignVerify:
-#                 try:
-#                     from main import settings
-#                     open(os.path.join(settings.LogsDir(), 'crypt.log'), 'wb').write(b'\Result:' + strng.to_bin(str(Result)) + b'\n\n')
-#                 except:
-#                     lg.exc()
+        #         if _Debug:
+        #             if _LogSignVerify:
+        #                 try:
+        #                     from bitdust.main import settings
+        #                     open(os.path.join(settings.LogsDir(), 'crypt.log'), 'wb').write(b'\Result:' + strng.to_bin(str(Result)) + b'\n\n')
+        #                 except:
+        #                     lg.exc()
 
         return Result
 
@@ -275,10 +283,10 @@ class Packet(object):
         """
         if not self.Ready():
             if _Debug:
-                lg.out(_DebugLevel, "signed.Valid packet is not ready yet " + str(self))
+                lg.out(_DebugLevel, 'signed.Valid packet is not ready yet ' + str(self))
             return False
         if not commands.IsCommand(self.Command):
-            lg.warn("signed.Valid bad Command " + str(self.Command))
+            lg.warn('signed.Valid bad Command ' + str(self.Command))
             return False
         if not self.SignatureChecksOut(raise_signature_invalid=raise_signature_invalid):
             if raise_signature_invalid:
@@ -288,9 +296,8 @@ class Packet(object):
                 owner_xml = contactsdb.get_contact_identity(self.OwnerID)
                 if owner_xml:
                     owner_xml = owner_xml.serialize(as_text=True)
-                raise Exception('signature is not valid for %r:\n\n%r\n\ncreator:\n\n%r\n\nowner:\n\n%r' % (
-                    self, self.Serialize(), creator_xml, owner_xml))
-            lg.warn("signed.Valid Signature IS NOT VALID!!!")
+                raise Exception('signature is not valid for %r:\n\n%r\n\ncreator:\n\n%r\n\nowner:\n\n%r' % (self, self.Serialize(), creator_xml, owner_xml))
+            lg.warn('signed.Valid Signature IS NOT VALID!!!')
             return False
         return True
 
@@ -333,7 +340,7 @@ class Packet(object):
             'r': self.RemoteID.original(),
             'k': self.KeyID,
             's': self.Signature,
-        }        
+        }
         src = serialization.DictToBytes(dct, encoding='latin1')
         # if _Debug:
         #     lg.out(_DebugLevel, 'signed.Serialize %d bytes %s(%s) %s/%s/%s KeyID=%s\n%r' % (
@@ -352,7 +359,6 @@ class PacketZeroSigned(Packet):
     """
     I was playing with hacking packets and do some debug also.
     """
-
     def GenerateSignature(self):
         return '0'
 
@@ -399,7 +405,8 @@ def Unserialize(data):
         )
     except:
         if _Debug:
-            lg.args(_DebugLevel,
+            lg.args(
+                _DebugLevel,
                 Command=Command,
                 OwnerID=OwnerID,
                 CreatorID=CreatorID,
@@ -442,17 +449,17 @@ def MakePacketDeferred(Command, OwnerID, CreatorID, PacketID, Payload, RemoteID)
     """
     return threads.deferToThread(MakePacket, Command, OwnerID, CreatorID, PacketID, Payload, RemoteID)
 
-#------------------------------------------------------------------------------
 
+#------------------------------------------------------------------------------
 
 if __name__ == '__main__':
     bpio.init()
     lg.set_debug_level(18)
-    from main import settings
+    from bitdust.main import settings
     settings.init()
     key.InitMyKey()
-    from userid import identity
-    from contacts import identitycache
+    from bitdust.userid import identity
+    from bitdust.contacts import identitycache
     if len(sys.argv) > 2:
         creator_ident = identity.identity(xmlsrc=bpio.ReadTextFile(sys.argv[2]))
         identitycache.UpdateAfterChecking(idurl=creator_ident.getIDURL(), xml_src=creator_ident.serialize())
