@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: fire_hire
 
@@ -119,27 +118,27 @@ except:
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import global_state
-from automats import automat
+from bitdust.automats import global_state
+from bitdust.automats import automat
 
-from lib import misc
-from lib import diskspace
-from lib import strng
+from bitdust.lib import misc
+from bitdust.lib import diskspace
+from bitdust.lib import strng
 
-from main import config
-from main import settings
-from main import events
+from bitdust.main import config
+from bitdust.main import settings
+from bitdust.main import events
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from services import driver
+from bitdust.services import driver
 
-from raid import eccmap
+from bitdust.raid import eccmap
 
-from userid import my_id
-from userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import id_url
 
 #-------------------------------------------------------------------------
 
@@ -176,14 +175,15 @@ def IsAllHired():
     if contactsdb.num_suppliers() != settings.getSuppliersNumberDesired():
         # I must have exactly that amount of suppliers already
         if _Debug:
-            lg.args(_DebugLevel, desiried_suppliers=settings.getSuppliersNumberDesired(), current_suppliers=contactsdb.num_suppliers(), )
+            lg.args(_DebugLevel, desiried_suppliers=settings.getSuppliersNumberDesired(), current_suppliers=contactsdb.num_suppliers())
         return False
     if id_url.is_some_empty(contactsdb.suppliers()):
         # I must know all of my suppliers
         if _Debug:
             lg.args(_DebugLevel, my_suppliers=contactsdb.suppliers())
         return False
-    return True 
+    return True
+
 
 #------------------------------------------------------------------------------
 
@@ -217,6 +217,7 @@ def Destroy():
     del _FireHire
     _FireHire = None
 
+
 #------------------------------------------------------------------------------
 
 
@@ -267,17 +268,17 @@ class FireHire(automat.Automat):
         if self.state == 'AT_STARTUP':
             if event == 'init':
                 self.state = 'READY'
-                self.NeedRestart=False
+                self.NeedRestart = False
         #---READY---
         elif self.state == 'READY':
-            if ( event == 'restart' or ( event == 'instant' and self.NeedRestart ) ) and self.isConfigChanged(*args, **kwargs) and self.isExistSomeSuppliers(*args, **kwargs):
+            if (event == 'restart' or (event == 'instant' and self.NeedRestart)) and self.isConfigChanged(*args, **kwargs) and self.isExistSomeSuppliers(*args, **kwargs):
                 self.state = 'SUPPLIERS?'
-                self.NeedRestart=False
+                self.NeedRestart = False
                 self.doSaveConfig(*args, **kwargs)
                 self.doConnectSuppliers(*args, **kwargs)
-            elif ( event == 'restart' or ( event == 'instant' and self.NeedRestart ) ) and not ( self.isConfigChanged(*args, **kwargs) and self.isExistSomeSuppliers(*args, **kwargs) ):
+            elif (event == 'restart' or (event == 'instant' and self.NeedRestart)) and not (self.isConfigChanged(*args, **kwargs) and self.isExistSomeSuppliers(*args, **kwargs)):
                 self.state = 'DECISION?'
-                self.NeedRestart=False
+                self.NeedRestart = False
                 self.doDecideToDismiss(*args, **kwargs)
         #---DECISION?---
         elif self.state == 'DECISION?':
@@ -287,7 +288,7 @@ class FireHire(automat.Automat):
                 self.doRemoveSuppliers(*args, **kwargs)
                 self.doDisconnectSuppliers(*args, **kwargs)
             elif event == 'restart':
-                self.NeedRestart=True
+                self.NeedRestart = True
             elif event == 'made-decision' and not self.isMoreNeeded(*args, **kwargs) and not self.isSomeoneToDismiss(*args, **kwargs):
                 self.state = 'READY'
                 self.doNotifyFinished(*args, **kwargs)
@@ -298,7 +299,7 @@ class FireHire(automat.Automat):
         #---HIRE_ONE---
         elif self.state == 'HIRE_ONE':
             if event == 'restart':
-                self.NeedRestart=True
+                self.NeedRestart = True
             elif event == 'supplier-connected' and not self.isStillNeeded(*args, **kwargs) and self.isSomeoneToDismiss(*args, **kwargs):
                 self.state = 'FIRE_MANY'
                 self.doSubstituteSupplier(*args, **kwargs)
@@ -329,7 +330,7 @@ class FireHire(automat.Automat):
             elif event == 'supplier-state-changed' and not self.isAllDismissed(*args, **kwargs):
                 self.doCloseConnector(*args, **kwargs)
             elif event == 'restart':
-                self.NeedRestart=True
+                self.NeedRestart = True
             elif event == 'supplier-state-changed' and self.isAllDismissed(*args, **kwargs):
                 self.state = 'READY'
                 self.doCloseConnector(*args, **kwargs)
@@ -338,8 +339,8 @@ class FireHire(automat.Automat):
         #---SUPPLIERS?---
         elif self.state == 'SUPPLIERS?':
             if event == 'restart':
-                self.NeedRestart=True
-            elif ( event == 'supplier-state-changed' and self.isAllReady(*args, **kwargs) ) or event == 'timer-15sec':
+                self.NeedRestart = True
+            elif (event == 'supplier-state-changed' and self.isAllReady(*args, **kwargs)) or event == 'timer-15sec':
                 self.state = 'DECISION?'
                 self.doDecideToDismiss(*args, **kwargs)
         return None
@@ -364,9 +365,7 @@ class FireHire(automat.Automat):
         s.difference_update(set(id_url.to_bin_list(dismissed)))
         result = len(s) < settings.getSuppliersNumberDesired()
         if _Debug:
-            lg.out(_DebugLevel, 'fire_hire.isMoreNeeded %d %d %d %d, result=%s' % (
-                contactsdb.num_suppliers(), len(dismissed), len(s),
-                settings.getSuppliersNumberDesired(), result))
+            lg.out(_DebugLevel, 'fire_hire.isMoreNeeded %d %d %d %d, result=%s' % (contactsdb.num_suppliers(), len(dismissed), len(s), settings.getSuppliersNumberDesired(), result))
         return result
 
     def isAllReady(self, *args, **kwargs):
@@ -374,8 +373,7 @@ class FireHire(automat.Automat):
         Condition method.
         """
         if _Debug:
-            lg.out(_DebugLevel, 'fire_hire.isAllReady %d %d' % (
-                len(self.connect_list), contactsdb.num_suppliers()))
+            lg.out(_DebugLevel, 'fire_hire.isAllReady %d %d' % (len(self.connect_list), contactsdb.num_suppliers()))
         return len(self.connect_list) == 0  # contactsdb.num_suppliers()
 
     def isAllDismissed(self, *args, **kwargs):
@@ -425,8 +423,7 @@ class FireHire(automat.Automat):
         """
         if None in self.configs:
             return True
-        curconfigs = (settings.getSuppliersNumberDesired(),
-                      diskspace.GetBytesFromString(settings.getNeededString()))
+        curconfigs = (settings.getSuppliersNumberDesired(), diskspace.GetBytesFromString(settings.getNeededString()))
         return self.configs[0] != curconfigs[0] or self.configs[1] != curconfigs[1]
 
     def isExistSomeSuppliers(self, *args, **kwargs):
@@ -449,8 +446,8 @@ class FireHire(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
-        from p2p import online_status
+        from bitdust.customer import supplier_connector
+        from bitdust.p2p import online_status
         self.connect_list = []
         my_current_family = contactsdb.suppliers()
         for pos, supplier_idurl in enumerate(my_current_family):
@@ -485,10 +482,10 @@ class FireHire(automat.Automat):
         Action method.
         """
         global _SuppliersToFire
-        from p2p import p2p_connector
-        from p2p import network_connector
-        from customer import supplier_connector
-        from p2p import online_status
+        from bitdust.p2p import p2p_connector
+        from bitdust.p2p import network_connector
+        from bitdust.customer import supplier_connector
+        from bitdust.p2p import online_status
         # take any actions only if I am connected to the network
         if not p2p_connector.A() or not network_connector.A():
             if _Debug:
@@ -519,8 +516,7 @@ class FireHire(automat.Automat):
             for supplier_index in range(number_desired, contactsdb.num_suppliers()):
                 idurl = contactsdb.supplier(supplier_index)
                 if idurl:
-                    lg.info('found REDUNDANT supplier %s at position %d' % (
-                        idurl, supplier_index, ))
+                    lg.info('found REDUNDANT supplier %s at position %d' % (idurl, supplier_index))
                     redundant_suppliers.add(idurl)
         if redundant_suppliers:
             result = list(redundant_suppliers)
@@ -554,7 +550,10 @@ class FireHire(automat.Automat):
                 potentialy_fired.add(supplier_idurl)
             elif sc.state == 'CONNECTED':
                 connected_suppliers.add(supplier_idurl)
-            elif sc.state in [ 'DISCONNECTED', 'REFUSE', ]:
+            elif sc.state in [
+                'DISCONNECTED',
+                'REFUSE',
+            ]:
                 disconnected_suppliers.add(supplier_idurl)
 #             elif sc.state in ['QUEUE?', 'REQUEST', ]:
 #                 requested_suppliers.add(supplier_idurl)
@@ -579,14 +578,12 @@ class FireHire(automat.Automat):
             self.automat('made-decision', [])
             return
         if len(offline_suppliers) + len(online_suppliers) != number_desired:
-            lg.warn('SKIP, offline + online != total count: %s %s %s' % (
-                offline_suppliers, online_suppliers, number_desired))
+            lg.warn('SKIP, offline + online != total count: %s %s %s' % (offline_suppliers, online_suppliers, number_desired))
             self.automat('made-decision', [])
             return
         max_offline_suppliers_count = eccmap.GetCorrectableErrors(number_desired)
         if len(offline_suppliers) > max_offline_suppliers_count:
-            lg.warn('SKIP, too many OFFLINE suppliers at the moment : %d > %d' % (
-                len(offline_suppliers), max_offline_suppliers_count, ))
+            lg.warn('SKIP, too many OFFLINE suppliers at the moment : %d > %d' % (len(offline_suppliers), max_offline_suppliers_count))
             self.automat('made-decision', [])
             return
         critical_offline_suppliers_count = eccmap.GetFireHireErrors(number_desired)
@@ -595,8 +592,7 @@ class FireHire(automat.Automat):
                 # TODO: check that issue
                 # too aggressive replacing suppliers who still have the data is very dangerous !!!
                 one_dead_supplier = offline_suppliers.pop()
-                lg.warn('found "CRITICALLY_OFFLINE" supplier %s, max offline limit is %d' % (
-                    one_dead_supplier, critical_offline_suppliers_count, ))
+                lg.warn('found "CRITICALLY_OFFLINE" supplier %s, max offline limit is %d' % (one_dead_supplier, critical_offline_suppliers_count))
                 potentialy_fired.add(one_dead_supplier)
         if not potentialy_fired:
             if _Debug:
@@ -606,7 +602,12 @@ class FireHire(automat.Automat):
         # only replace suppliers one by one at the moment
         result = list(potentialy_fired)
         lg.info('will replace supplier %s' % result[0])
-        self.automat('made-decision', [result[0], ])
+        self.automat(
+            'made-decision',
+            [
+                result[0],
+            ],
+        )
 
     def doRememberSuppliers(self, *args, **kwargs):
         """
@@ -619,9 +620,8 @@ class FireHire(automat.Automat):
         Action method.
         """
         if _Debug:
-            lg.out(_DebugLevel, 'fire_hire.doFindNewSupplier desired_suppliers=%d current_suppliers=%r' % (
-                settings.getSuppliersNumberDesired(), contactsdb.suppliers()))
-        from p2p import network_connector
+            lg.out(_DebugLevel, 'fire_hire.doFindNewSupplier desired_suppliers=%d current_suppliers=%r' % (settings.getSuppliersNumberDesired(), contactsdb.suppliers()))
+        from bitdust.p2p import network_connector
         if network_connector.A().state != 'CONNECTED':
             if _Debug:
                 lg.out(_DebugLevel, '        network_connector is not CONNECTED at the moment, SKIP')
@@ -637,15 +637,14 @@ class FireHire(automat.Automat):
                 position_for_new_supplier = pos
                 break
             if id_url.is_in(supplier_idurl, self.dismiss_list, as_field=False):
-                lg.info('going to find new supplier on existing position %d to replace supplier %s' % (
-                    pos, supplier_idurl, ))
+                lg.info('going to find new supplier on existing position %d to replace supplier %s' % (pos, supplier_idurl))
                 position_for_new_supplier = pos
                 break
         if position_for_new_supplier is None:
             lg.err('did not found position for new supplier')
             self.automat('search-failed')
             return
-        from customer import supplier_finder
+        from bitdust.customer import supplier_finder
         for idurl_txt in strng.to_text(config.conf().getData('services/employer/candidates')).split(','):
             if idurl_txt.strip():
                 supplier_finder.AddSupplierToHire(idurl_txt)
@@ -696,11 +695,9 @@ class FireHire(automat.Automat):
             time.strftime('%d-%m-%Y %H:%M:%S'),
             my_id.getIDURL(),
         )
-        # from main import control
-        # control.on_suppliers_changed(current_suppliers)
         if family_position < 0:
-            lg.info('added new supplier, family position unknown: %s desired_suppliers=%d current_suppliers=%d' % (
-                new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+            lg.info('added new supplier, family position unknown: %s desired_suppliers=%d current_suppliers=%d' % (new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+            # yapf: disable
             events.send('supplier-modified', data=dict(
                 new_idurl=new_idurl,
                 old_idurl=None,
@@ -708,10 +705,11 @@ class FireHire(automat.Automat):
                 ecc_map=eccmap.Current().name,
                 family_snapshot=id_url.to_bin_list(contactsdb.suppliers()),
             ))
+            # yapf: enable
         else:
             if old_idurl:
-                lg.info('hired new supplier and substitute existing supplier on position %d : %s->%s desired_suppliers=%d current_suppliers=%d' % (
-                    family_position, old_idurl, new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+                lg.info('hired new supplier and substitute existing supplier on position %d : %s->%s desired_suppliers=%d current_suppliers=%d' % (family_position, old_idurl, new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+                # yapf: disable
                 events.send('supplier-modified', data=dict(
                     new_idurl=new_idurl,
                     old_idurl=old_idurl,
@@ -719,9 +717,10 @@ class FireHire(automat.Automat):
                     ecc_map=eccmap.Current().name,
                     family_snapshot=id_url.to_bin_list(contactsdb.suppliers()),
                 ))
+                # yapf: enable
             else:
-                lg.info('hired new supplier on empty position %d : %s desired_suppliers=%d current_suppliers=%d' % (
-                    family_position, new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+                lg.info('hired new supplier on empty position %d : %s desired_suppliers=%d current_suppliers=%d' % (family_position, new_idurl, desired_suppliers, len(contactsdb.suppliers())))
+                # yapf: disable
                 events.send('supplier-modified', data=dict(
                     new_idurl=new_idurl,
                     old_idurl=None,
@@ -729,6 +728,7 @@ class FireHire(automat.Automat):
                     ecc_map=eccmap.Current().name,
                     family_snapshot=id_url.to_bin_list(contactsdb.suppliers()),
                 ))
+                # yapf: enable
         self.restart_interval = 1.0
         if _Debug:
             lg.out(_DebugLevel, '    my current suppliers: %r' % contactsdb.suppliers())
@@ -740,8 +740,7 @@ class FireHire(automat.Automat):
         current_suppliers = contactsdb.suppliers()
         desired_suppliers = settings.getSuppliersNumberDesired()
         if len(current_suppliers) < desired_suppliers:
-            lg.warn('must have more suppliers %d<%d' % (
-                len(current_suppliers), desired_suppliers))
+            lg.warn('must have more suppliers %d<%d' % (len(current_suppliers), desired_suppliers))
         removed_suppliers = []
         for supplier_idurl in self.dismiss_list:
             if id_url.is_not_in(supplier_idurl, current_suppliers, as_field=False):
@@ -749,7 +748,10 @@ class FireHire(automat.Automat):
                 continue
             pos = current_suppliers.index(id_url.field(supplier_idurl))
             current_suppliers[pos] = ''
-            removed_suppliers.append((pos, supplier_idurl,))
+            removed_suppliers.append((
+                pos,
+                supplier_idurl,
+            ))
             misc.writeSupplierData(
                 supplier_idurl,
                 'disconnected',
@@ -759,14 +761,13 @@ class FireHire(automat.Automat):
         current_suppliers = current_suppliers[:desired_suppliers]
         contactsdb.update_suppliers(current_suppliers)
         contactsdb.save_suppliers()
-        # from main import control
-        # control.on_suppliers_changed(current_suppliers)
         for position, supplier_idurl in removed_suppliers:
             events.send('supplier-modified', data=dict(
-                new_idurl=None, old_idurl=supplier_idurl, position=position,
+                new_idurl=None,
+                old_idurl=supplier_idurl,
+                position=position,
             ))
-        lg.info('removed some suppliers : %d  desired_suppliers=%d current_suppliers=%d' % (
-            len(self.dismiss_list), desired_suppliers, len(contactsdb.suppliers())))
+        lg.info('removed some suppliers : %d  desired_suppliers=%d current_suppliers=%d' % (len(self.dismiss_list), desired_suppliers, len(contactsdb.suppliers())))
         if _Debug:
             lg.out(_DebugLevel, '    my current suppliers: %r' % contactsdb.suppliers())
 
@@ -774,8 +775,8 @@ class FireHire(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
-        from p2p import online_status
+        from bitdust.customer import supplier_connector
+        from bitdust.p2p import online_status
         if _Debug:
             lg.out(_DebugLevel, 'fire_hire.doDisconnectSuppliers %r' % self.dismiss_list)
         self.dismiss_results = []
@@ -796,7 +797,7 @@ class FireHire(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
+        from bitdust.customer import supplier_connector
         supplier_idurl, _ = args[0]
         supplier_idurl = id_url.field(supplier_idurl)
         if _Debug:
@@ -813,7 +814,7 @@ class FireHire(automat.Automat):
         """
         Action method.
         """
-        from customer import supplier_connector
+        from bitdust.customer import supplier_connector
         for supplier_idurl in self.dismiss_list:
             sc = supplier_connector.by_idurl(supplier_idurl)
             if id_url.is_in(supplier_idurl, self.dismiss_list, as_field=False):
@@ -834,29 +835,30 @@ class FireHire(automat.Automat):
         self.hire_list = []
         if not self.restart_task:
             self.restart_task = reactor.callLater(  # @UndefinedVariable
-                self.restart_interval, self._scheduled_restart)
+                self.restart_interval,
+                self._scheduled_restart,
+            )
             if _Debug:
                 lg.out(_DebugLevel, 'fire_hire.doScheduleNextRestart after %r sec.' % self.restart_interval)
-            from p2p import network_connector
+            from bitdust.p2p import network_connector
             if network_connector.A().state != 'CONNECTED':
-                self.restart_interval = 60 * 5
+                self.restart_interval = 60*5
             else:
                 self.restart_interval *= 1.1
         else:
             if _Debug:
-                lg.out(_DebugLevel, 'fire_hire.doScheduleNextRestart already scheduled - %r sec. left' % (
-                    time.time() - self.restart_task.getTime()))
+                lg.out(_DebugLevel, 'fire_hire.doScheduleNextRestart already scheduled - %r sec. left' % (time.time() - self.restart_task.getTime()))
 
     def doNotifySuppliersChanged(self, *args, **kwargs):
         self.hire_list = []
         if driver.is_on('service_backups'):
-            from storage import backup_monitor
+            from bitdust.storage import backup_monitor
             backup_monitor.A('suppliers-changed')
 
     def doNotifyFinished(self, *args, **kwargs):
         self.hire_list = []
         if driver.is_on('service_backups'):
-            from storage import backup_monitor
+            from bitdust.storage import backup_monitor
             backup_monitor.A('fire-hire-finished')
 
     def _scheduled_restart(self):
@@ -864,11 +866,10 @@ class FireHire(automat.Automat):
         self.automat('restart')
 
     def _on_supplier_connector_state_changed(self, idurl, newstate, **kwargs):
-        from customer import supplier_connector
+        from bitdust.customer import supplier_connector
         idurl = id_url.field(idurl)
         if _Debug:
-            lg.out(_DebugLevel, 'fire_hire._on_supplier_connector_state_changed %s to %s, own state is %s ' % (
-                idurl, newstate, self.state))
+            lg.out(_DebugLevel, 'fire_hire._on_supplier_connector_state_changed %s to %s, own state is %s ' % (idurl, newstate, self.state))
         if supplier_connector.by_idurl(idurl):
             supplier_connector.by_idurl(idurl).remove_callback('fire_hire', self._on_supplier_connector_state_changed)
         if self.state == 'SUPPLIERS?':
@@ -883,14 +884,19 @@ class FireHire(automat.Automat):
                 lg.warn('did not found %r in dismiss_results' % idurl)
         else:
             return
-        self.automat('supplier-state-changed', (idurl, newstate, ))
+        self.automat('supplier-state-changed', (
+            idurl,
+            newstate,
+        ))
 
     def _on_supplier_online_status_state_changed(self, oldstate, newstate, event_string, *args, **kwargs):
         if oldstate != newstate:
             if _Debug:
-                lg.out(_DebugLevel, 'fire_hire._on_supplier_online_status_state_changed  %s -> %s, own state is %s' % (
-                    oldstate, newstate, self.state))
-        if oldstate != newstate and newstate in ['CONNECTED', 'OFFLINE', ]:
+                lg.out(_DebugLevel, 'fire_hire._on_supplier_online_status_state_changed  %s -> %s, own state is %s' % (oldstate, newstate, self.state))
+        if oldstate != newstate and newstate in [
+            'CONNECTED',
+            'OFFLINE',
+        ]:
             self.automat('restart')
 
 
