@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: supplier.
 
@@ -54,7 +52,7 @@ from __future__ import absolute_import
 #------------------------------------------------------------------------------
 
 _Debug = False
-_DebugLevel = 10
+_DebugLevel = 16
 
 #------------------------------------------------------------------------------
 
@@ -65,32 +63,30 @@ from twisted.internet import reactor  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from system import bpio
+from bitdust.system import bpio
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from lib import strng
-from lib import nameurl
-from lib import diskspace
+from bitdust.lib import strng
+from bitdust.lib import nameurl
+from bitdust.lib import diskspace
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from stream import p2p_queue
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import online_status
 
-from p2p import commands
-from p2p import p2p_service
-from p2p import online_status
+from bitdust.raid import eccmap
 
-from raid import eccmap
-
-from userid import id_url
-from userid import global_id
-from userid import my_id
+from bitdust.userid import id_url
+from bitdust.userid import global_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -98,6 +94,7 @@ _SuppliersConnectors = {}
 
 #------------------------------------------------------------------------------
 
+
 def connectors(customer_idurl=None, as_dict=False):
     global _SuppliersConnectors
     if as_dict:
@@ -110,8 +107,7 @@ def connectors(customer_idurl=None, as_dict=False):
     return _SuppliersConnectors[customer_idurl]
 
 
-def create(supplier_idurl, customer_idurl=None, needed_bytes=None,
-           key_id=None, queue_subscribe=True):
+def create(supplier_idurl, customer_idurl=None, needed_bytes=None, key_id=None, queue_subscribe=True):
     if customer_idurl is None:
         customer_idurl = my_id.getIDURL()
     customer_idurl = id_url.field(customer_idurl)
@@ -158,57 +154,10 @@ def total_connectors():
         count += len(suppliers_list)
     return count
 
-#------------------------------------------------------------------------------
-
-# def on_supplier_file_modified(event_info):
-#     if _Debug:
-#         lg.args(_DebugLevel, e=event_info)
-#     return True
-# 
-# 
-# def start_consumer(customer_id, supplier_id):
-#     supplier_queue_id = global_id.MakeGlobalQueueID(
-#         queue_alias='supplier-file-modified',
-#         owner_id=customer_id,
-#         supplier_id=supplier_id,
-#     )
-#     if not p2p_queue.is_queue_exist(supplier_queue_id):
-#         try:
-#             p2p_queue.open_queue(supplier_queue_id)
-#         except Exception as exc:
-#             lg.warn('failed to open queue %s : %s' % (supplier_queue_id, str(exc)))
-#     if not p2p_queue.is_queue_exist(supplier_queue_id):
-#         lg.err('queue %s not exist' % supplier_queue_id)
-#         return False
-#     if not p2p_queue.is_consumer_exists(customer_id):
-#         p2p_queue.add_consumer(customer_id)
-#     if not p2p_queue.is_callback_method_registered(consumer_id=customer_id, callback_method=on_supplier_file_modified):
-#         p2p_queue.add_callback_method(consumer_id=customer_id, callback_method=on_supplier_file_modified)
-#     if not p2p_queue.is_consumer_subscribed(customer_id, supplier_queue_id):
-#         p2p_queue.subscribe_consumer(customer_id, supplier_queue_id)
-#     if _Debug:
-#         lg.args(_DebugLevel, q=supplier_queue_id)
-#     return True
-# 
-# 
-# def stop_consumer(customer_id, supplier_id):
-#     supplier_queue_id = global_id.MakeGlobalQueueID(
-#         queue_alias='supplier-file-modified',
-#         owner_id=customer_id,
-#         supplier_id=supplier_id,
-#     )
-#     if p2p_queue.is_consumer_subscribed(customer_id, supplier_queue_id):
-#         p2p_queue.unsubscribe_consumer(customer_id, supplier_queue_id, remove_empty=True)
-#     if p2p_queue.is_callback_method_registered(consumer_id=customer_id, callback_method=on_supplier_file_modified):
-#         p2p_queue.remove_callback_method(consumer_id=customer_id, callback_method=on_supplier_file_modified)
-#     if p2p_queue.is_queue_exist(supplier_queue_id):
-#         p2p_queue.close_queue(supplier_queue_id, remove_empty_consumers=True, remove_empty_producers=True)
-#     if _Debug:
-#         lg.args(_DebugLevel, q=supplier_queue_id)
-#     return True
 
 #------------------------------------------------------------------------------
 
+
 class SupplierConnector(automat.Automat):
     """
     This class implements all the functionality of the ``supplier_connector()``
@@ -220,8 +169,7 @@ class SupplierConnector(automat.Automat):
         'timer-10sec': (10.0, ['REFUSE', 'QUEUE?']),
     }
 
-    def __init__(self, supplier_idurl, customer_idurl, needed_bytes,
-                 key_id=None, queue_subscribe=True):
+    def __init__(self, supplier_idurl, customer_idurl, needed_bytes, key_id=None, queue_subscribe=True):
         self.supplier_idurl = supplier_idurl
         self.supplier_id = self.supplier_idurl.to_id()
         self.customer_idurl = customer_idurl
@@ -299,7 +247,7 @@ class SupplierConnector(automat.Automat):
                     needed_bytes=self.needed_bytes,
                     key_id=self.key_id,
                 ))
-        if newstate in ['DISCONNECTED', 'NO_SERVICE', ]:
+        if newstate in ['DISCONNECTED', 'NO_SERVICE']:
             self._supplier_connected_event_sent = False
 
     def set_callback(self, name, cb):
@@ -313,11 +261,11 @@ class SupplierConnector(automat.Automat):
                 if cb in self.callbacks[name]:
                     self.callbacks[name].remove(cb)
                 else:
-                    lg.warn('callback %r not registered in %r with name %s' % (cb, self, name, ))
+                    lg.warn('callback %r not registered in %r with name %s' % (cb, self, name))
             else:
                 self.callbacks.pop(name)
         else:
-            lg.warn('callback with name %s not registered in %r' % (name, self, ))
+            lg.warn('callback with name %s not registered in %r' % (name, self))
 
     def do_calculate_needed_bytes(self):
         if self.needed_bytes is None:
@@ -330,7 +278,7 @@ class SupplierConnector(automat.Automat):
                 if known_ecc_map:
                     num_suppliers = eccmap.GetEccMapSuppliersNumber(known_ecc_map)
             if num_suppliers > 0:
-                self.needed_bytes = int(math.ceil(2.0 * total_bytes_needed / float(num_suppliers)))
+                self.needed_bytes = int(math.ceil(2.0*total_bytes_needed/float(num_suppliers)))
             else:
                 raise Exception('not possible to determine needed_bytes value to be requested from that supplier')
                 # self.needed_bytes = int(math.ceil(2.0 * settings.MinimumNeededBytes() / float(settings.DefaultDesiredSuppliers())))
@@ -340,7 +288,7 @@ class SupplierConnector(automat.Automat):
         if self.state == 'NO_SERVICE':
             if event == 'connect':
                 self.state = 'REQUEST'
-                self.GoDisconnect=False
+                self.GoDisconnect = False
                 self.doPingRequestService(*args, **kwargs)
             elif event == 'shutdown':
                 self.state = 'CLOSED'
@@ -358,7 +306,7 @@ class SupplierConnector(automat.Automat):
                 self.doCancelService(*args, **kwargs)
             elif event == 'fail' or event == 'connect':
                 self.state = 'REQUEST'
-                self.GoDisconnect=False
+                self.GoDisconnect = False
                 self.doPingRequestService(*args, **kwargs)
             elif event == 'shutdown':
                 self.state = 'CLOSED'
@@ -376,7 +324,7 @@ class SupplierConnector(automat.Automat):
                 self.doCancelService(*args, **kwargs)
             elif event == 'connect':
                 self.state = 'REQUEST'
-                self.GoDisconnect=False
+                self.GoDisconnect = False
                 self.doPingRequestService(*args, **kwargs)
             elif event == 'fail':
                 self.state = 'NO_SERVICE'
@@ -387,11 +335,11 @@ class SupplierConnector(automat.Automat):
         #---REQUEST---
         elif self.state == 'REQUEST':
             if event == 'disconnect':
-                self.GoDisconnect=True
+                self.GoDisconnect = True
             elif event == 'shutdown':
                 self.state = 'CLOSED'
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'fail' or ( event == 'ack' and not self.isServiceAccepted(*args, **kwargs) and not self.GoDisconnect ):
+            elif event == 'fail' or (event == 'ack' and not self.isServiceAccepted(*args, **kwargs) and not self.GoDisconnect):
                 self.state = 'NO_SERVICE'
                 self.doReportNoService(*args, **kwargs)
             elif event == 'ack' and not self.GoDisconnect and self.isServiceAccepted(*args, **kwargs):
@@ -410,22 +358,22 @@ class SupplierConnector(automat.Automat):
                 self.state = 'CLOSED'
                 self.doCleanRequest(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif event == 'timer-10sec' or event == 'fail' or ( event == 'ack' and self.isServiceCancelled(*args, **kwargs) ):
+            elif event == 'timer-10sec' or event == 'fail' or (event == 'ack' and self.isServiceCancelled(*args, **kwargs)):
                 self.state = 'NO_SERVICE'
                 self.doCleanRequest(*args, **kwargs)
                 self.doReportNoService(*args, **kwargs)
         #---QUEUE?---
         elif self.state == 'QUEUE?':
             if event == 'disconnect':
-                self.GoDisconnect=True
+                self.GoDisconnect = True
             elif event == 'shutdown':
                 self.state = 'CLOSED'
                 self.doDestroyMe(*args, **kwargs)
-            elif self.GoDisconnect and ( event == 'queue-ack' or event == 'queue-fail' or event == 'queue-skip' or event == 'timer-10sec' ):
+            elif self.GoDisconnect and (event == 'queue-ack' or event == 'queue-fail' or event == 'queue-skip' or event == 'timer-10sec'):
                 self.state = 'REFUSE'
                 self.doCancelServiceQueue(*args, **kwargs)
                 self.doCancelService(*args, **kwargs)
-            elif not self.GoDisconnect and ( event == 'queue-ack' or event == 'queue-fail' or event == 'queue-skip' or event == 'timer-10sec' ):
+            elif not self.GoDisconnect and (event == 'queue-ack' or event == 'queue-fail' or event == 'queue-skip' or event == 'timer-10sec'):
                 self.state = 'CONNECTED'
                 self.doReportConnect(*args, **kwargs)
         return None
@@ -473,8 +421,7 @@ class SupplierConnector(automat.Automat):
             family_position=family_position,
             family_snapshot=family_snapshot,
         ))
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='supplier_connector.doPingRequestService')
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='supplier_connector.doPingRequestService')
         d.addErrback(lambda err: self.automat('fail', err))
 
     def doCancelService(self, *args, **kwargs):
@@ -512,26 +459,34 @@ class SupplierConnector(automat.Automat):
         if not self.queue_subscribe:
             reactor.callLater(0, self.automat, 'queue-skip')  # @UndefinedVariable
             return
+        queue_id = global_id.MakeGlobalQueueID(
+            queue_alias='supplier-file-modified',
+            owner_id=self.customer_id,
+            supplier_id=self.supplier_id,
+        )
         service_info = {
-            'items': [{
-                'scope': 'consumer',
-                'action': 'start',
-                'consumer_id': self.customer_id,
-            }, {
-                'scope': 'consumer',
-                'action': 'add_callback',
-                'consumer_id': self.customer_id,
-                'method': self.customer_idurl,
-            }, {
-                'scope': 'consumer',
-                'action': 'subscribe',
-                'consumer_id': self.customer_id,
-                'queue_id': global_id.MakeGlobalQueueID(
-                    queue_alias='supplier-file-modified',
-                    owner_id=self.customer_id,
-                    supplier_id=self.supplier_id,
-                ),
-            }, ],
+            'items': [
+                {
+                    'scope': 'consumer',
+                    'action': 'start',
+                    'consumer_id': self.customer_id,
+                },
+                {
+                    'scope': 'consumer',
+                    'action': 'add_callback',
+                    'consumer_id': self.customer_id,
+                    'method': self.customer_idurl,
+                    'queues': [
+                        'supplier-file-modified',
+                    ],
+                },
+                {
+                    'scope': 'consumer',
+                    'action': 'subscribe',
+                    'consumer_id': self.customer_id,
+                    'queue_id': queue_id,
+                },
+            ],
         }
         request = p2p_service.SendRequestService(
             remote_idurl=self.supplier_idurl,
@@ -549,25 +504,29 @@ class SupplierConnector(automat.Automat):
         Action method.
         """
         service_info = {
-            'items': [{
-                'scope': 'consumer',
-                'action': 'unsubscribe',
-                'consumer_id': self.customer_id,
-                'queue_id': global_id.MakeGlobalQueueID(
-                    queue_alias='supplier-file-modified',
-                    owner_id=self.customer_id,
-                    supplier_id=self.supplier_id,
-                ),
-            }, {
-                'scope': 'consumer',
-                'action': 'remove_callback',
-                'consumer_id': self.customer_id,
-                'method': self.customer_id,
-            }, {
-                'scope': 'consumer',
-                'action': 'stop',
-                'consumer_id': self.customer_id,
-            }, ],
+            'items': [
+                {
+                    'scope': 'consumer',
+                    'action': 'unsubscribe',
+                    'consumer_id': self.customer_id,
+                    'queue_id': global_id.MakeGlobalQueueID(
+                        queue_alias='supplier-file-modified',
+                        owner_id=self.customer_id,
+                        supplier_id=self.supplier_id,
+                    ),
+                },
+                {
+                    'scope': 'consumer',
+                    'action': 'remove_callback',
+                    'consumer_id': self.customer_id,
+                    'method': self.customer_id,
+                },
+                {
+                    'scope': 'consumer',
+                    'action': 'stop',
+                    'consumer_id': self.customer_id,
+                },
+            ],
         }
         p2p_service.SendCancelService(
             remote_idurl=self.supplier_idurl,
@@ -674,17 +633,18 @@ class SupplierConnector(automat.Automat):
         self.automat('queue-fail', response or None)
 
     def _on_online_status_state_changed(self, oldstate, newstate, event_string, *args, **kwargs):
-        if oldstate != newstate and newstate in ['CONNECTED', 'OFFLINE', ]:
+        if oldstate != newstate and newstate in [
+            'CONNECTED',
+            'OFFLINE',
+        ]:
             if not (oldstate == 'PING?' and newstate == 'OFFLINE'):
                 if _Debug:
-                    lg.out(_DebugLevel, 'supplier_connector._on_online_status_state_changed %s : %s->%s, reconnecting now' % (
-                        self.supplier_idurl, oldstate, newstate))
+                    lg.out(_DebugLevel, 'supplier_connector._on_online_status_state_changed %s : %s->%s, reconnecting now' % (self.supplier_idurl, oldstate, newstate))
                 reactor.callLater(0, self.automat, 'connect')  # @UndefinedVariable
 
     def _do_request_supplier_service(self, ecc_map, family_position, family_snapshot):
         if _Debug:
-            lg.args(_DebugLevel, supplier_idurl=self.supplier_idurl, ecc_map=ecc_map,
-                    family_position=family_position, family_snapshot=family_snapshot)
+            lg.args(_DebugLevel, supplier_idurl=self.supplier_idurl, ecc_map=ecc_map, family_position=family_position, family_snapshot=family_snapshot)
         if not self.supplier_idurl:
             lg.warn('supplier idurl is empty, SKIP sending supplier_service request')
             return
