@@ -20,7 +20,6 @@
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
 #
-
 """
 ..
 
@@ -61,41 +60,40 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import local_fs
+from bitdust.system import bpio
+from bitdust.system import local_fs
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from lib import strng
-from lib import utime
-from lib import jsn
+from bitdust.lib import strng
+from bitdust.lib import utime
+from bitdust.lib import jsn
 
-from userid import id_url
+from bitdust.userid import id_url
 
-from dht import known_nodes
+from bitdust.dht import known_nodes
 
 #------------------------------------------------------------------------------
 
-from dht.entangled.kademlia import constants  # @UnresolvedImport
-from dht.entangled.kademlia.datastore import SQLiteVersionedJsonDataStore  # @UnresolvedImport
-from dht.entangled.kademlia.node import rpcmethod, MultiLayerNode  # @UnresolvedImport
-from dht.entangled.kademlia.protocol import KademliaMultiLayerProtocol, encoding, msgformat  # @UnresolvedImport
-from dht.entangled.kademlia.routingtable import TreeRoutingTable  # @UnresolvedImport
-from dht.entangled.kademlia.contact import Contact  # @UnresolvedImport
-
+from bitdust_forks.entangled.kademlia import constants  # @UnresolvedImport
+from bitdust_forks.entangled.kademlia.datastore import SQLiteVersionedJsonDataStore  # @UnresolvedImport
+from bitdust_forks.entangled.kademlia.node import rpcmethod, MultiLayerNode  # @UnresolvedImport
+from bitdust_forks.entangled.kademlia.protocol import KademliaMultiLayerProtocol, encoding, msgformat  # @UnresolvedImport
+from bitdust_forks.entangled.kademlia.routingtable import TreeRoutingTable  # @UnresolvedImport
+from bitdust_forks.entangled.kademlia.contact import Contact  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-KEY_EXPIRE_MIN_SECONDS = 60 * 2
+KEY_EXPIRE_MIN_SECONDS = 60*2
 KEY_EXPIRE_MAX_SECONDS = constants.dataExpireSecondsDefaut
 RECEIVING_FREQUENCY_SEC = 0.01
 SENDING_FREQUENCY_SEC = 0.02  # must be always slower than receiving frequency!
 RECEIVING_QUEUE_LENGTH_CRITICAL = 100
 SENDING_QUEUE_LENGTH_CRITICAL = 50
-DEFAULT_CACHE_TTL = 60 * 60 * 3
+DEFAULT_CACHE_TTL = 60*60*3
 
 #------------------------------------------------------------------------------
 
@@ -108,6 +106,7 @@ _Cache = {}
 
 #------------------------------------------------------------------------------
 
+
 def init(udp_port, dht_dir_path=None, open_layers=[]):
     global _MyNode
     if _MyNode is not None:
@@ -139,8 +138,7 @@ def init(udp_port, dht_dir_path=None, open_layers=[]):
         os.makedirs(cache_dir_path)
     load_cache(cache_dir_path)
     if _Debug:
-        lg.dbg(_DebugLevel, 'dht_dir_path=%r list_layers=%r network_info=%r' % (
-            dht_dir_path, list_layers, nw_info))
+        lg.dbg(_DebugLevel, 'dht_dir_path=%r list_layers=%r network_info=%r' % (dht_dir_path, list_layers, nw_info))
     layerStores = {}
     for layer_filename in list_layers:
         if not layer_filename.startswith('db_'):
@@ -177,8 +175,7 @@ def init(udp_port, dht_dir_path=None, open_layers=[]):
     for layer_id in open_layers:
         open_layer(layer_id=layer_id, dht_dir_path=dht_dir_path, connect_now=False)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.init UDP port is %d, DB file path is %s, my DHT ID is %s' % (
-            udp_port, dht_dir_path, _MyNode.layers[0]))
+        lg.out(_DebugLevel, 'dht_service.init UDP port is %d, DB file path is %s, my DHT ID is %s' % (udp_port, dht_dir_path, _MyNode.layers[0]))
 
 
 def shutdown():
@@ -194,6 +191,7 @@ def shutdown():
     else:
         lg.warn('DHTNode not exist')
 
+
 #------------------------------------------------------------------------------
 
 
@@ -238,7 +236,7 @@ def connect(seed_nodes=[], layer_id=0, attach=False):
             lg.out(_DebugLevel, 'dht_service.connect opened a new listener : %r' % node().listener)
 
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.connect STARTING with %d known nodes in layer %d:' % (len(seed_nodes), layer_id, ))
+        lg.out(_DebugLevel, 'dht_service.connect STARTING with %d known nodes in layer %d:' % (len(seed_nodes), layer_id))
         for onenode in seed_nodes:
             lg.out(_DebugLevel, '    %s:%s' % onenode)
 
@@ -246,13 +244,13 @@ def connect(seed_nodes=[], layer_id=0, attach=False):
         if _Debug:
             lg.out(_DebugLevel, 'dht_service.connect  SKIP : no seed nodes provided')
         reactor.callLater(0, result.callback, True)  # @UndefinedVariable
-        events.send('dht-layer-connected', data=dict(layer_id=layer_id, ))
+        events.send('dht-layer-connected', data=dict(layer_id=layer_id))
         return result
 
     def _on_connected(ok):
         if _Debug:
             lg.args(_DebugLevel, ok=ok, layer_id=layer_id)
-        events.send('dht-layer-connected', data=dict(layer_id=layer_id, ))
+        events.send('dht-layer-connected', data=dict(layer_id=layer_id))
         return ok
 
     result.addCallback(_on_connected)
@@ -261,7 +259,7 @@ def connect(seed_nodes=[], layer_id=0, attach=False):
         ok = live_contacts and len(live_contacts) > 0 and live_contacts[0]
         if isinstance(live_contacts, dict):
             lg.err('Unexpected result from joinNetwork: %s' % pprint.pformat(live_contacts))
-        else: 
+        else:
             if ok:
                 if _Debug:
                     lg.out(_DebugLevel, 'dht_service.connect DHT JOIN SUCCESS   layer_id=%d attach=%r' % (_layer_id, attach))
@@ -292,7 +290,7 @@ def connect(seed_nodes=[], layer_id=0, attach=False):
         d.addErrback(_on_join_failed)
         if not node().expire_task.running:
             # reactor.callLater(random.randint(0, 60), node().expire_task.start, int(KEY_EXPIRE_MIN_SECONDS / 2), now=True)  # @UndefinedVariable
-            node().expire_task.start(int(KEY_EXPIRE_MIN_SECONDS / 2), now=True)  # @UndefinedVariable
+            node().expire_task.start(int(KEY_EXPIRE_MIN_SECONDS/2), now=True)  # @UndefinedVariable
         return resolved_seed_nodes
 
     def _on_hosts_resolve_failed(x):
@@ -339,8 +337,10 @@ def reconnect():
         lg.out(_DebugLevel, 'dht_service.reconnect')
     return node().reconnect()
 
+
 #------------------------------------------------------------------------------
 
+
 def is_layer_active(layer_id):
     if not node():
         return False
@@ -370,7 +370,7 @@ def open_layer(layer_id, seed_nodes=[], dht_dir_path=None, connect_now=False, at
         result.callback(True)
         return result
     result = connect(seed_nodes=seed_nodes, layer_id=layer_id, attach=attach)
-    lg.info('DHT layer %d opened and connecting to the seed nodes: %r' % (layer_id, seed_nodes, ))
+    lg.info('DHT layer %d opened and connecting to the seed nodes: %r' % (layer_id, seed_nodes))
     return result
 
 
@@ -381,8 +381,10 @@ def close_layer(layer_id):
     lg.info('destroying DHT layer %d' % layer_id)
     return node().destroyLayer(layer_id)
 
+
 #------------------------------------------------------------------------------
 
+
 def count(name):
     global _Counters
     if name not in _Counters:
@@ -402,14 +404,19 @@ def drop_counters():
     _Counters.clear()
     return ret
 
+
 #------------------------------------------------------------------------------
 
+
 def on_host_resolved(ip, port, host, result_list, total_hosts, result_defer):
     if not strng.is_string(ip) or port is None:
         result_list.append(None)
         lg.warn('%r failed to resolve' % host)
     else:
-        result_list.append((ip, port, ))
+        result_list.append((
+            ip,
+            port,
+        ))
     if len(result_list) != total_hosts:
         return None
     return result_defer.callback([_f for _f in result_list if _f])
@@ -435,8 +442,10 @@ def resolve_hosts(nodes_list):
         d.addErrback(on_host_failed, node_tuple[0], result_list, len(nodes_list), result_defer)
     return result_defer
 
+
 #------------------------------------------------------------------------------
 
+
 def random_key():
     return key_to_hash(strng.to_text(random.getrandbits(255)).encode())
 
@@ -447,8 +456,10 @@ def key_to_hash(key):
     h.update(key)
     return h.hexdigest()
 
+
 #------------------------------------------------------------------------------
 
+
 def make_key(key, prefix, index=0, version=None):
     global _ProtocolVersion
     if not version:
@@ -466,11 +477,13 @@ def split_key(key_str):
         version=version,
     )
 
+
 #------------------------------------------------------------------------------
 
+
 def on_success(result, method, key, *args, **kwargs):
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.on_success   %s(%r)    result is %s' % (method, key, type(result), ))
+        lg.out(_DebugLevel, 'dht_service.on_success   %s(%r)    result is %s' % (method, key, type(result)))
     return result
 
 
@@ -492,15 +505,17 @@ def on_error(x, method, key):
         lg.out(_DebugLevel, 'dht_service.on_error   %s(%s)   returned an ERROR:\n%r' % (method, key, errmsg))
     return x
 
+
 #------------------------------------------------------------------------------
 
+
 def get_value(key, layer_id=0, parallel_calls=None):
     if not node():
         return fail(Exception('DHT service is off'))
     count('get_value_%s' % key)
     key_hash = key_to_hash(key)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.get_value key=[%r] key_hash=%s' % (key, key_hash, ))
+        lg.out(_DebugLevel, 'dht_service.get_value key=[%r] key_hash=%s' % (key, key_hash))
     d = node().iterativeFindValue(
         key=key_hash,
         rpc='findValue',
@@ -519,7 +534,7 @@ def set_value(key, value, age=0, expire=KEY_EXPIRE_MAX_SECONDS, collect_results=
     sz_bytes = len(value)
     key_hash = key_to_hash(key)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.set_value key=[%s] key_hash=%s with %d bytes for %d seconds' % (key, key_hash, sz_bytes, expire, ))
+        lg.out(_DebugLevel, 'dht_service.set_value key=[%s] key_hash=%s with %d bytes for %d seconds' % (key, key_hash, sz_bytes, expire))
     if expire < KEY_EXPIRE_MIN_SECONDS:
         expire = KEY_EXPIRE_MIN_SECONDS
     if expire > KEY_EXPIRE_MAX_SECONDS:
@@ -544,14 +559,16 @@ def delete_key(key, layer_id=0, parallel_calls=None):
     count('delete_key_%s' % key)
     key_hash = key_to_hash(key)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.delete_key [%s] key_hash=%s' % (key, key_hash, ))
+        lg.out(_DebugLevel, 'dht_service.delete_key [%s] key_hash=%s' % (key, key_hash))
     d = node().iterativeDelete(key_hash, layerID=layer_id, parallel_calls=parallel_calls)
     d.addCallback(on_success, 'delete_value', key)
     d.addErrback(on_error, 'delete_key', key)
     return d
 
+
 #------------------------------------------------------------------------------
 
+
 def on_read_json_response(response, key, result_defer=None):
     if _Debug:
         lg.out(_DebugLevel + 6, 'dht_service.on_read_json_response [%r] : %s' % (key, type(response)))
@@ -603,7 +620,7 @@ def on_read_json_response(response, key, result_defer=None):
 
 def get_json_value(key, layer_id=0, update_cache=True):
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.get_json_value key=[%r] layer_id=%d update_cache=%s' % (key, layer_id, update_cache, ))
+        lg.out(_DebugLevel, 'dht_service.get_json_value key=[%r] layer_id=%d update_cache=%s' % (key, layer_id, update_cache))
     ret = Deferred()
     d = get_value(key, layer_id=layer_id)
     d.addCallback(on_read_json_response, key, ret)
@@ -624,8 +641,10 @@ def set_json_value(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SECONDS, collect
         lg.out(_DebugLevel, 'dht_service.set_json_value key=[%r] layer_id=%d with %d bytes' % (key, layer_id, len(repr(value))))
     return set_value(key=key, value=value, age=age, expire=expire, collect_results=collect_results, layer_id=layer_id)
 
+
 #------------------------------------------------------------------------------
 
+
 def validate_rules(value, key, rules, result_defer=None, raise_for_result=False, populate_meta_fields=False):
     """
     Will be executed on both sides: sender and receiver for each (key,value) get / set request on DHT.
@@ -671,25 +690,34 @@ def validate_rules(value, key, rules, result_defer=None, raise_for_result=False,
 
         for field, field_rules in rules.items():
             if _Debug:
-                lg.out(_DebugLevel, '    %r : %r' % (field, field_rules, ))
+                lg.out(_DebugLevel, '    %r : %r' % (field, field_rules))
             for rule in field_rules:
                 if 'op' not in rule:
                     lg.warn('incorrect validation rule found: %r' % rule)
                     continue
                 if rule['op'] == 'equal' and rule.get('arg') != strng.to_text(value.get(field)):
                     passed = False
-                    errors.append((field, rule, ))
+                    errors.append((
+                        field,
+                        rule,
+                    ))
                     break
                 if rule['op'] == 'exist' and field not in value:
                     passed = False
-                    errors.append((field, rule, ))
+                    errors.append((
+                        field,
+                        rule,
+                    ))
                     break
             if not passed:
                 break
     except Exception as exc:
         lg.exc()
         passed = False
-        errors = [('unknown', exc, )]
+        errors = [(
+            'unknown',
+            exc,
+        )]
     if not passed:
         lg.exc(exc_value=Exception('DHT record validation failed, errors: %s' % errors))
         if result_defer:
@@ -713,7 +741,7 @@ def validate_before_store(key, value, originalPublisherID, age, expireSeconds, *
         lg.exc()
         raise ValueError('input data is not a json value: %r' % value)
     if _Debug:
-        lg.out(_DebugLevel + 8, 'dht_service.validate_before_store key=[%s] with %d bytes value' % (key, len(value), ))
+        lg.out(_DebugLevel + 8, 'dht_service.validate_before_store key=[%s] with %d bytes value' % (key, len(value)))
     new_record_type = json_new_value.get('type')
     if not new_record_type:
         if _Debug:
@@ -736,7 +764,7 @@ def validate_before_store(key, value, originalPublisherID, age, expireSeconds, *
         if _Debug:
             lg.out(_DebugLevel, '        new json data type did not match to existing record type, store operation FAILED')
         raise ValueError('new json data type do not match to existing record type: %r' % json_prev_value)
-    # TODO: need to include "key" field into DHT record and validate it as well 
+    # TODO: need to include "key" field into DHT record and validate it as well
     # new_record_key = json_new_value.get('key')
     # if not new_record_key:
     #     if _Debug:
@@ -816,8 +844,7 @@ def validate_data_written(store_results, key, json_data, result_defer):
         results_collected = True
         nodes = store_results[0]
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.validate_data_written key=[%s]  %s  collected=%s  nodes=%r' % (
-            key, type(store_results), results_collected, nodes, ))
+        lg.out(_DebugLevel, 'dht_service.validate_data_written key=[%s]  %s  collected=%s  nodes=%r' % (key, type(store_results), results_collected, nodes))
     if results_collected:
         for result in store_results[1]:
             try:
@@ -870,9 +897,7 @@ def validate_after_receive(value, key, rules, result_defer, raise_for_result, po
     """
     if _Debug:
         lg.out(_DebugLevel, 'dht_service.validate_after_receive for key [%s]' % key)
-    response = validate_rules(value, key, rules, result_defer=result_defer,
-                              raise_for_result=raise_for_result,
-                              populate_meta_fields=populate_meta_fields)
+    response = validate_rules(value, key, rules, result_defer=result_defer, raise_for_result=raise_for_result, populate_meta_fields=populate_meta_fields)
     if not isinstance(response, dict):
         if populate_meta_fields:
             ret = {
@@ -888,16 +913,17 @@ def validate_after_receive(value, key, rules, result_defer, raise_for_result, po
             response['type'] = rules['type'][0]['arg']
     return response
 
+
 #------------------------------------------------------------------------------
 
+
 def get_valid_data(key, rules={}, raise_for_result=False, return_details=False, layer_id=0, use_cache_ttl=None, update_cache=True):
     ret = Deferred()
     if use_cache_ttl is not None:
         d = get_cached_json_value(key, layer_id=layer_id, cache_ttl=use_cache_ttl)
     else:
         d = get_json_value(key, layer_id=layer_id, update_cache=update_cache)
-    d.addCallback(validate_after_receive, key=key, rules=rules, result_defer=ret,
-                  raise_for_result=raise_for_result, populate_meta_fields=return_details)
+    d.addCallback(validate_after_receive, key=key, rules=rules, result_defer=ret, raise_for_result=raise_for_result, populate_meta_fields=return_details)
     d.addErrback(ret.errback)
     return ret
 
@@ -912,8 +938,10 @@ def set_valid_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SECONDS, rules={
     d.addErrback(ret.errback)
     return ret
 
+
 #------------------------------------------------------------------------------
 
+
 def write_verify_republish_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SECONDS, rules={}, layer_id=0):
     try:
         raw_value = jsn.dumps(json_data, indent=0, sort_keys=True, separators=(',', ':'))
@@ -925,8 +953,7 @@ def write_verify_republish_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SEC
     _write_response = None
     _join = Deferred()
     _join.addCallback(_do_verify)
-    if _Debug:
-        _join.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='write_verify_republish_data')
+    _join.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='write_verify_republish_data')
 
     def _some_nodes_found(nodes):
         global _write_response
@@ -961,7 +988,7 @@ def write_verify_republish_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SEC
             lg.out(_DebugLevel, 'dht_service._write_ok : %r' % write_result)
         _write_response = write_result
         if _found_nodes is not None:
-            _join.callback(_write_response, _found_nodes) 
+            _join.callback(_write_response, _found_nodes)
         return write_result
 
     def _write_failed(err):
@@ -975,7 +1002,7 @@ def write_verify_republish_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SEC
 
     def _do_verify(write_response, found_nodes):
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service._do_verify  %r via nodes: %r' % (write_response, found_nodes, ))
+            lg.out(_DebugLevel, 'dht_service._do_verify  %r via nodes: %r' % (write_response, found_nodes))
         for node in found_nodes:
             node.request(b'verify_update', key, raw_value, age, expire)
         ret.callback(write_response, found_nodes)
@@ -992,8 +1019,10 @@ def write_verify_republish_data(key, json_data, age=0, expire=KEY_EXPIRE_MAX_SEC
 
     return ret
 
+
 #------------------------------------------------------------------------------
 
+
 def on_nodes_found(result, node_id64):
     global _ActiveLookup
     global _ActiveLookupLayerID
@@ -1030,16 +1059,17 @@ def find_node(node_id, layer_id=0):
         return fail(Exception('DHT layer %d is not active' % layer_id))
     node_id64 = node_id
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.find_node   node_id=[%s]  layer_id=%d' % (
-            node_id64, layer_id))
+        lg.out(_DebugLevel, 'dht_service.find_node   node_id=[%s]  layer_id=%d' % (node_id64, layer_id))
     _ActiveLookupLayerID = layer_id
     _ActiveLookup = node().iterativeFindNode(node_id, layerID=layer_id)
     _ActiveLookup.addErrback(on_lookup_failed, node_id64)
     _ActiveLookup.addCallback(on_nodes_found, node_id64)
     return _ActiveLookup
 
+
 #------------------------------------------------------------------------------
 
+
 def get_node_data(key, layer_id=0):
     if not node():
         if _Debug:
@@ -1053,18 +1083,17 @@ def get_node_data(key, layer_id=0):
     key = strng.to_text(key)
     if key not in node().data[layer_id]:
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service.get_node_data   key=[%s] not exist   layer_id=%d' % (key, layer_id, ))
+            lg.out(_DebugLevel, 'dht_service.get_node_data   key=[%s] not exist   layer_id=%d' % (key, layer_id))
         return None
     value = node().data[layer_id][key]
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.get_node_data key=[%s] read %d bytes   layer_id=%d' % (
-            key, len(strng.to_text(value) or ''), layer_id, ))
+        lg.out(_DebugLevel, 'dht_service.get_node_data key=[%s] read %d bytes   layer_id=%d' % (key, len(strng.to_text(value) or ''), layer_id))
     return value
 
 
 def set_node_data(key, value, layer_id=0):
     if not node():
-        lg.warn('DHT node is not ready yet, not able to store key %r for layer_id=%d locally' % (key, layer_id, ))
+        lg.warn('DHT node is not ready yet, not able to store key %r for layer_id=%d locally' % (key, layer_id))
         return False
     count('set_node_data')
     if layer_id not in node().data:
@@ -1072,8 +1101,7 @@ def set_node_data(key, value, layer_id=0):
     key = strng.to_text(key)
     node().data[layer_id][key] = value
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.set_node_data key=[%s] wrote %d bytes  layer_id=%d' % (
-            key, len(strng.to_text(value) or ''), layer_id, ))
+        lg.out(_DebugLevel, 'dht_service.set_node_data key=[%s] wrote %d bytes  layer_id=%d' % (key, len(strng.to_text(value) or ''), layer_id))
     return True
 
 
@@ -1094,8 +1122,7 @@ def delete_node_data(key, layer_id=0):
         return False
     node().data[layer_id].pop(key)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.delete_node_data key=[%s]   layer_id=%d' % (
-            key, layer_id, ))
+        lg.out(_DebugLevel, 'dht_service.delete_node_data key=[%s]   layer_id=%d' % (key, layer_id))
     return True
 
 
@@ -1121,14 +1148,20 @@ def dump_local_db(value_as_json=False):
                 itm['scope'] = 'global'
                 l.append(itm)
             for k, v in node().data[layerID].items():
-                l.append({'key': k, 'value': v, 'scope': 'node', })
+                l.append({
+                    'key': k,
+                    'value': v,
+                    'scope': 'node',
+                })
             result[layerID] = l
     except:
         lg.exc()
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def cache():
     global _Cache
     return _Cache
@@ -1169,7 +1202,7 @@ def store_cached_key(hash_key, json_value, layer_id=0, timestamp=None):
         os.makedirs(layer_cache_dir_path)
     cached_record_file_path = os.path.join(layer_cache_dir_path, hash_key)
     if not local_fs.WriteTextFile(cached_record_file_path, jsn.dumps(cached_json_record)):
-        lg.err('failed to store cached dht key %r in layer %d' % (hash_key, layer_id, ))
+        lg.err('failed to store cached dht key %r in layer %d' % (hash_key, layer_id))
         return False
     _Cache[layer_id][hash_key] = cached_json_record
     if _Debug:
@@ -1201,19 +1234,28 @@ def get_cached_json_value(key, layer_id=0, cache_ttl=DEFAULT_CACHE_TTL):
     if utime.get_sec1970() - int(cached_record['t']) > cache_ttl:
         return get_json_value(key, layer_id=layer_id, update_cache=True)
     if _Debug:
-        lg.out(_DebugLevel, 'dht_service.get_cached_json_value key=[%r] layer_id=%d cache_ttl=%d' % (key, layer_id, cache_ttl, ))
+        lg.out(_DebugLevel, 'dht_service.get_cached_json_value key=[%r] layer_id=%d cache_ttl=%d' % (key, layer_id, cache_ttl))
     ret = Deferred()
     ret.callback(cached_record['v'])
     return ret
 
+
 #------------------------------------------------------------------------------
 
-class DHTNode(MultiLayerNode):
 
+class DHTNode(MultiLayerNode):
     def __init__(self, udpPort=4000, dataStores=None, routingTables=None, networkProtocol=None, nodeID=None):
-        super(DHTNode, self).__init__(udpPort=udpPort, dataStores=dataStores, routingTables=routingTables, networkProtocol=networkProtocol, id=nodeID, )
+        super(DHTNode, self).__init__(
+            udpPort=udpPort,
+            dataStores=dataStores,
+            routingTables=routingTables,
+            networkProtocol=networkProtocol,
+            id=nodeID,
+        )
         self._counter = count
-        self.data = {0: {}, }
+        self.data = {
+            0: {},
+        }
         if dataStores:
             for layer_id in dataStores.keys():
                 self.data[layer_id] = {}
@@ -1267,35 +1309,17 @@ class DHTNode(MultiLayerNode):
                 del self._dataStores[layer_id][key]
 
     @rpcmethod
-    def store(self, key, value, originalPublisherID=None,
-              age=0, expireSeconds=KEY_EXPIRE_MAX_SECONDS, **kwargs):
+    def store(self, key, value, originalPublisherID=None, age=0, expireSeconds=KEY_EXPIRE_MAX_SECONDS, **kwargs):
         count('store_dht_service')
         layerID = kwargs.pop('layerID', 0)
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service.DHTNode.store key=[%s] for %d seconds layerID=%d' % (
-                key, expireSeconds, layerID))
+            lg.out(_DebugLevel, 'dht_service.DHTNode.store key=[%s] for %d seconds layerID=%d' % (key, expireSeconds, layerID))
 
         if 'store' in self.rpc_callbacks and layerID in self.active_layers:
             # TODO: add signature validation to be sure this is the owner of that key:value pair
-            self.rpc_callbacks['store'](
-                key=key,
-                value=value,
-                originalPublisherID=originalPublisherID,
-                age=age,
-                expireSeconds=expireSeconds,
-                layerID=layerID,
-                **kwargs
-            )
+            self.rpc_callbacks['store'](key=key, value=value, originalPublisherID=originalPublisherID, age=age, expireSeconds=expireSeconds, layerID=layerID, **kwargs)
 
-        return super(DHTNode, self).store(
-            key=key,
-            value=value,
-            originalPublisherID=originalPublisherID,
-            age=age,
-            expireSeconds=expireSeconds,
-            layerID=layerID,
-            **kwargs
-        )
+        return super(DHTNode, self).store(key=key, value=value, originalPublisherID=originalPublisherID, age=age, expireSeconds=expireSeconds, layerID=layerID, **kwargs)
 
     @rpcmethod
     def request(self, key, **kwargs):
@@ -1303,10 +1327,13 @@ class DHTNode(MultiLayerNode):
         layerID = kwargs.get('layerID', 0)
         if layerID not in self.active_layers:
             if _Debug:
-                lg.out(_DebugLevel, 'dht_service.DHTNode.request key=[%r] SKIP because layer %d is not active' % (key, layerID, ))
-            return {key: 0, layerID:layerID, }
+                lg.out(_DebugLevel, 'dht_service.DHTNode.request key=[%r] SKIP because layer %d is not active' % (key, layerID))
+            return {
+                key: 0,
+                layerID: layerID,
+            }
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service.DHTNode.request key=[%r] layerID=%d' % (key, layerID, ))
+            lg.out(_DebugLevel, 'dht_service.DHTNode.request key=[%r] layerID=%d' % (key, layerID))
         if 'request' in self.rpc_callbacks:
             self.rpc_callbacks['request'](key=key, layerID=layerID)
         value = get_node_data(key, layer_id=layerID)
@@ -1314,7 +1341,10 @@ class DHTNode(MultiLayerNode):
             value = 0
         if _Debug:
             lg.out(_DebugLevel, '    read internal value: %r' % value)
-        return {key: value, layerID:layerID, }
+        return {
+            key: value,
+            layerID: layerID,
+        }
 
     @rpcmethod
     def verify_update(self, key, value, originalPublisherID=None, age=0, expireSeconds=KEY_EXPIRE_MAX_SECONDS, **kwargs):
@@ -1328,7 +1358,7 @@ class DHTNode(MultiLayerNode):
         count('findNode')
         layerID = kwargs.get('layerID', 0)
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service.DHTNode.findNode key=[%s] layerID=%d' % (key, layerID,))
+            lg.out(_DebugLevel, 'dht_service.DHTNode.findNode key=[%s] layerID=%d' % (key, layerID))
         return super(DHTNode, self).findNode(key, **kwargs)
 
     @rpcmethod
@@ -1336,7 +1366,7 @@ class DHTNode(MultiLayerNode):
         count('findValue')
         layerID = kwargs.get('layerID', 0)
         if _Debug:
-            lg.out(_DebugLevel, 'dht_service.DHTNode.findValue key=[%s] layerID=%d' % (key, layerID,))
+            lg.out(_DebugLevel, 'dht_service.DHTNode.findValue key=[%s] layerID=%d' % (key, layerID))
         return super(DHTNode, self).findValue(key, **kwargs)
 
     @rpcmethod
@@ -1357,14 +1387,16 @@ class DHTNode(MultiLayerNode):
         d.callback(1)
         return d
 
+
 #------------------------------------------------------------------------------
 
 
 class DHTProtocol(KademliaMultiLayerProtocol):
-
     def __init__(self, node, msgEncoder=encoding.Bencode(), msgTranslator=msgformat.MultiLayerFormat()):
         KademliaMultiLayerProtocol.__init__(self, node, msgEncoder=msgEncoder, msgTranslator=msgTranslator)
         self._counter = count
+
+
 #         self.receiving_queue = []
 #         self.receiving_worker = None
 #         self.sending_queue = []
@@ -1414,26 +1446,26 @@ class DHTProtocol(KademliaMultiLayerProtocol):
 
 def parseCommandLine():
     oparser = optparse.OptionParser()
-    oparser.add_option("-p", "--udpport", dest="udpport", type="int", help="specify UDP port for DHT network")
+    oparser.add_option('-p', '--udpport', dest='udpport', type='int', help='specify UDP port for DHT network')
     oparser.set_default('udpport', settings.DefaultDHTPort())
-    oparser.add_option("-d", "--dhtdb", dest="dhtdb", help="specify DHT folder location")
+    oparser.add_option('-d', '--dhtdb', dest='dhtdb', help='specify DHT folder location')
     oparser.set_default('dhtdb', settings.ServiceDir('service_entangled_dht'))
-    oparser.add_option("-s", "--seeds", dest="seeds", help="specify list of DHT seed nodes")
+    oparser.add_option('-s', '--seeds', dest='seeds', help='specify list of DHT seed nodes')
     oparser.set_default('seeds', '')
-    oparser.add_option("-l", "--layers", dest="layers", help="specify list of layers to be created")
+    oparser.add_option('-l', '--layers', dest='layers', help='specify list of layers to be created')
     oparser.set_default('layers', '')
-    oparser.add_option("-a", "--attach_layer", dest="attach_layer", help="specify which layer to be attached at start")
+    oparser.add_option('-a', '--attach_layer', dest='attach_layer', help='specify which layer to be attached at start')
     oparser.set_default('attach_layer', '')
-    oparser.add_option("-j", "--join_layer", dest="join_layer", help="specify which layer to be joined at start")
+    oparser.add_option('-j', '--join_layer', dest='join_layer', help='specify which layer to be joined at start')
     oparser.set_default('join_layer', '')
-    oparser.add_option("-w", "--wait", dest="delayed", type="int", help="wait N seconds before join the network")
+    oparser.add_option('-w', '--wait', dest='delayed', type='int', help='wait N seconds before join the network')
     oparser.set_default('delayed', 0)
     (options, args) = oparser.parse_args()
     return options, args
 
 
 def main(options=None, args=None):
-    from dht import dht_relations
+    from bitdust.dht import dht_relations
 
     if options is None and args is None:
         (options, args) = parseCommandLine()
@@ -1450,8 +1482,7 @@ def main(options=None, args=None):
 
     connect_layers = [int(l) for l in options.layers.split(',') if l]
     init(udp_port=options.udpport, dht_dir_path=options.dhtdb, open_layers=connect_layers)
-    lg.out(_DebugLevel, 'Init   udpport=%d   dhtdb=%s   node=%r   connect_layers=%r' % (
-        options.udpport, options.dhtdb, node(), connect_layers))
+    lg.out(_DebugLevel, 'Init   udpport=%d   dhtdb=%s   node=%r   connect_layers=%r' % (options.udpport, options.dhtdb, node(), connect_layers))
 
     seeds = []
 
@@ -1469,7 +1500,7 @@ def main(options=None, args=None):
                 lg.info('COMMAND: %r' % cmd)
 
                 def _r(x):
-                    lg.info('RESULT "%s": %r' % (cmd, x, ))
+                    lg.info('RESULT "%s": %r' % (cmd, x))
                     reactor.stop()  #@UndefinedVariable
 
                 if cmd == 'get':
@@ -1479,17 +1510,11 @@ def main(options=None, args=None):
                 elif cmd == 'get_json':
                     get_json_value(args[1], layer_id=0 if len(args) < 3 else int(args[2])).addBoth(_r)
                 elif cmd == 'set_json':
-                    set_json_value(args[1], jsn.loads(args[2]),
-                                   expire=int(args[3]),
-                                   layer_id=0 if len(args) < 3 else int(args[2])).addBoth(_r)
+                    set_json_value(args[1], jsn.loads(args[2]), expire=int(args[3]), layer_id=0 if len(args) < 3 else int(args[2])).addBoth(_r)
                 elif cmd == 'get_valid_data':
-                    get_valid_data(args[1], rules=jsn.loads(args[2]), return_details=True,
-                                   layer_id=0 if len(args) < 4 else int(args[3])).addBoth(_r)
+                    get_valid_data(args[1], rules=jsn.loads(args[2]), return_details=True, layer_id=0 if len(args) < 4 else int(args[3])).addBoth(_r)
                 elif cmd == 'set_valid_data':
-                    set_valid_data(args[1], jsn.loads(args[2]),
-                                   expire=int(args[3]),
-                                   rules=jsn.loads(args[4]),
-                                   layer_id=0 if len(args) < 6 else int(args[5])).addBoth(_r)
+                    set_valid_data(args[1], jsn.loads(args[2]), expire=int(args[3]), rules=jsn.loads(args[4]), layer_id=0 if len(args) < 6 else int(args[5])).addBoth(_r)
                 elif cmd == 'read_customer_suppliers':
                     dht_relations.read_customer_suppliers(args[1]).addBoth(_r)
                 elif cmd == 'write_customer_suppliers':
@@ -1503,19 +1528,24 @@ def main(options=None, args=None):
                 elif cmd == 'get_node_data':
                     pprint.pprint(get_node_data(args[1]))
                 elif cmd == 'observe_data':
+
                     def _p(val, n):
                         print('observed', n, val)
+
                     def _o(result):
                         for n in result:
                             d = n.request(args[2])
                             d.addCallback(_p, n)
+
                     d = find_node(key_to_hash(args[1]))
                     d.addErrback(_r)
                     d.addCallback(_o)
                 elif cmd == 'discover':
+
                     def _l(x):
                         lg.info(x)
                         find_node(random_key()).addBoth(_l)
+
                     _l('')
                 elif cmd == 'dump_db':
                     pprint.pprint(dump_local_db(value_as_json=True))
@@ -1524,21 +1554,32 @@ def main(options=None, args=None):
                         layer_id=int(args[1]),
                         seed_nodes=[(s[0], int(s[1])) for s in args[2].split(',') if s],
                         dht_dir_path=options.dhtdb,
-                        connect_now=True, ).addBoth(_r)
+                        connect_now=True,
+                    ).addBoth(_r)
         except:
             lg.exc()
-    
+
     possible_seeds = options.seeds
-    if possible_seeds in ['genesis', 'root', b'genesis', b'root', ]:
+    if possible_seeds in [
+        'genesis',
+        'root',
+        b'genesis',
+        b'root',
+    ]:
         # "genesis" node must not connect anywhere
         possible_seeds = []
 
     lg.out(_DebugLevel, 'options.seeds=%r' % options.seeds)
     lg.out(_DebugLevel, 'possible_seeds=%r' % possible_seeds)
 
-    if options.seeds in ['genesis', 'root', b'genesis', b'root', ]:
+    if options.seeds in [
+        'genesis',
+        'root',
+        b'genesis',
+        b'root',
+    ]:
         lg.out(_DebugLevel, 'Starting genesis node!!!!!!!!!!!!!!!!!!!!')
-    
+
     else:
         for dht_node_str in options.seeds.split(','):
             if dht_node_str.strip():
@@ -1548,8 +1589,11 @@ def main(options=None, args=None):
                     dht_node_port = int(dht_node[1].strip())
                 except:
                     continue
-                seeds.append((dht_node_host, dht_node_port, ))
-        
+                seeds.append((
+                    dht_node_host,
+                    dht_node_port,
+                ))
+
         if not seeds:
             seeds = known_nodes.nodes()
 
@@ -1582,14 +1626,13 @@ def main(options=None, args=None):
     reactor.callWhenRunning(_start)  # @UndefinedVariable
     reactor.run()  #@UndefinedVariable
 
+
 #------------------------------------------------------------------------------
 
-
 if __name__ == '__main__':
-    from dht import dht_service
+    from bitdust.dht import dht_service
     bpio.init()
     settings.init()
     lg.set_debug_level(20)
-    # dht_service._Debug = False
     dht_service.main()
     settings.shutdown()
