@@ -24,8 +24,6 @@
 #
 #
 from __future__ import absolute_import
-from fileinput import fileno
-
 """
 ..
 
@@ -55,19 +53,16 @@ from twisted.protocols.ftp import (
     FTP,
     ASCIIConsumerWrapper,
     _FileReader,
-    _FileWriter,
-    # methods
+    _FileWriter,  # methods
     toSegments,
-    errnoToFailure,
-    # exceptions
+    errnoToFailure,  # exceptions
     FTPCmdError,
     BadCmdSequenceError,
     InvalidPath,
     FileNotFoundError,
     FileExistsError,
     PermissionDeniedError,
-    IsADirectoryError,
-    # FTP codes constants
+    IsADirectoryError,  # FTP codes constants
     DATA_CNX_ALREADY_OPEN_START_XFR,
     TXFR_COMPLETE_OK,
     REQ_FILE_ACTN_COMPLETED_OK,
@@ -87,25 +82,17 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from main import settings
+from bitdust.main import settings
 
-from lib import packetid
-from lib import nameurl
+from bitdust.system import tmpfile
+from bitdust.system import bpio
 
-from system import tmpfile
-from system import bpio
+from bitdust.storage import backup_fs
+from bitdust.storage import backup_control
 
-from storage import backup_fs
-from storage import backup_control
-from storage import restore_monitor
-from storage import backup_monitor
-
-from userid import my_id
-from userid import global_id
-
-from interface import api
+from bitdust.interface import api
 
 #------------------------------------------------------------------------------
 
@@ -113,6 +100,7 @@ _FTPServer = None
 
 #------------------------------------------------------------------------------
 
+
 def init(ftp_port=None):
     global _FTPServer
     lg.out(4, 'ftp_server.init')
@@ -125,15 +113,13 @@ def init(ftp_port=None):
         bpio.WriteTextFile(settings.FTPServerCredentialsFile(), 'bitdust:bitdust')
     # TODO: add protection: accept connections only from local host: 127.0.0.1
     _FTPServer = reactor.listenTCP(  # @UndefinedVariable
-        ftp_port,
-        BitDustFTPFactory(
-            Portal(
-                FTPRealm('./'), [
-                    AllowAnonymousAccess(),
-                    FilePasswordDB(settings.FTPServerCredentialsFile()),
-                ]
-            ),
-        )
+        ftp_port, BitDustFTPFactory(Portal(
+            FTPRealm('./'),
+            [
+                AllowAnonymousAccess(),
+                FilePasswordDB(settings.FTPServerCredentialsFile()),
+            ],
+        ))
     )
     lg.out(4, '    started on port %d' % ftp_port)
 
@@ -149,10 +135,11 @@ def shutdown():
     _FTPServer = None
     return result
 
+
 #------------------------------------------------------------------------------
 
-class BitDustFileReader(_FileReader):
 
+class BitDustFileReader(_FileReader):
     def __init__(self, fObj, filepath):
         super(BitDustFileReader, self).__init__(fObj)
         self.filepath = filepath
@@ -162,13 +149,14 @@ class BitDustFileReader(_FileReader):
         # tmpfile.throw_out(os.path.dirname(self.filepath), 'file read')
         return passthrough
 
+
 #------------------------------------------------------------------------------
 
-class BitDustFTP(FTP):
 
+class BitDustFTP(FTP):
     def _accessGrantedResponse(self, result, segments):
         self.workingDirectory = segments
-        return (REQ_FILE_ACTN_COMPLETED_OK,)
+        return (REQ_FILE_ACTN_COMPLETED_OK, )
 
     def _dirListingResponse(self, results):
         self.reply(DATA_CNX_ALREADY_OPEN_START_XFR)
@@ -176,7 +164,7 @@ class BitDustFTP(FTP):
             name = self._encodeName(name)
             self.dtpInstance.sendListResponse(name, attrs)
         self.dtpInstance.transport.loseConnection()
-        return (TXFR_COMPLETE_OK,)
+        return (TXFR_COMPLETE_OK, )
 
     def _enableTimeoutLater(self, result, newsegs=None):
         self.setTimeout(self.factory.timeOut)
@@ -184,13 +172,13 @@ class BitDustFTP(FTP):
 
     def _cbFileSent(self, result):
         lg.out(8, 'ftp_server._cbFileSent %s' % result)
-        return (TXFR_COMPLETE_OK,)
+        return (TXFR_COMPLETE_OK, )
 
     def _ebFileSent(self, err):
-        lg.warn("Unexpected error attempting to transmit file to client: " + str(err))
+        lg.warn('Unexpected error attempting to transmit file to client: ' + str(err))
         if err.check(FTPCmdError):
             return err
-        return (CNX_CLOSED_TXFR_ABORTED,)
+        return (CNX_CLOSED_TXFR_ABORTED, )
 
     def _cbReadOpened(self, file_obj, consumer):
         lg.out(8, 'ftp_server._cbWriteOpened %s %s' % (file_obj, consumer))
@@ -206,17 +194,17 @@ class BitDustFTP(FTP):
         if not err:
             return (FILE_NOT_FOUND, '/'.join(newsegs))
         if not err.check(PermissionDeniedError, FileNotFoundError, IsADirectoryError):
-            lg.warn("Unexpected error attempting to open file for transmission: " + str(err))
+            lg.warn('Unexpected error attempting to open file for transmission: ' + str(err))
         if err.check(FTPCmdError):
             return (err.value.errorCode, '/'.join(newsegs))
         return (FILE_NOT_FOUND, '/'.join(newsegs))
 
     def _cbFileRecevied(self, consumer, local_path, newsegs):
         #         receive_defer.addCallback(self._startFileBackup, upload_filename, newsegs, d)
-#         consumer.fObj.flush()
-#         os.fsync(consumer.fObj.fileno())
-#         consumer.fObj.close()
-#         consumer.close()
+        #         consumer.fObj.flush()
+        #         os.fsync(consumer.fObj.fileno())
+        #         consumer.fObj.close()
+        #         consumer.close()
         remote_path = '/'.join(newsegs)
         lg.out(8, 'ftp_server._cbFileRecevied %s %s' % (local_path, remote_path))
         ret = api.file_info(remote_path)
@@ -241,15 +229,15 @@ class BitDustFTP(FTP):
 #         # upload_task.result_defer.addCallback(self._cbFileBackup, result_defer, newsegs)
 #         backup_fs.Calculate()
 #         backup_control.Save()
-        # result_defer.callback(None)
-        # return consumer
-        return (TXFR_COMPLETE_OK,)
+# result_defer.callback(None)
+# return consumer
+        return (TXFR_COMPLETE_OK, )
 
     def _ebFileReceived(self, err):
-        lg.warn("Unexpected error received during transfer: " + str(err))
+        lg.warn('Unexpected error received during transfer: ' + str(err))
         if err.check(FTPCmdError):
             return err
-        return (CNX_CLOSED_TXFR_ABORTED,)
+        return (CNX_CLOSED_TXFR_ABORTED, )
 
     def _cbWriteOpened(self, consumer, upload_filename, newsegs):
         remote_path = '/'.join(newsegs)
@@ -265,7 +253,7 @@ class BitDustFTP(FTP):
     def _ebWriteOpened(self, err, newsegs):
         if isinstance(err.value, FTPCmdError):
             return (err.value.errorCode, '/'.join(newsegs))
-        lg.warn("Unexpected error received while opening file: %s" % str(err))
+        lg.warn('Unexpected error received while opening file: %s' % str(err))
         return (FILE_NOT_FOUND, '/'.join(newsegs))
 
     def _startConsumer(self, consumer):
@@ -304,7 +292,7 @@ class BitDustFTP(FTP):
 #         (size,) = result
 #         return (FILE_STATUS, str(size))
 
-    #------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
 
     def ftp_LIST(self, path=''):
         # Uh, for now, do this retarded thing.
@@ -333,15 +321,18 @@ class BitDustFTP(FTP):
 #                 known_size = 1
             known_size = max(itm['local_size'], 0)
             key_alias, _, _ = itm['key_id'].partition('$')
-            result.append((os.path.basename(itm['path']), [  # name
-                known_size,  # size
-                True if itm['type'] == 'dir' else False,  # folder or file ?
-                filepath.Permissions(0o7777),  # permissions
-                0,  # hardlinks
-                time.mktime(time.strptime(itm['latest'], '%Y-%m-%d %H:%M:%S')) if itm['latest'] else None,  # time
-                itm['customer'],  # owner
-                key_alias,        # group
-            ], ))
+            result.append((
+                os.path.basename(itm['path']),
+                [  # name
+                    known_size,  # size
+                    True if itm['type'] == 'dir' else False,  # folder or file ?
+                    filepath.Permissions(0o7777),  # permissions
+                    0,  # hardlinks
+                    time.mktime(time.strptime(itm['latest'], '%Y-%m-%d %H:%M:%S'), ) if itm['latest'] else None,  # time
+                    itm['customer'],  # owner
+                    key_alias,  # group
+                ],
+            ))
         d = Deferred()
         d.addCallback(self._dirListingResponse)
         d.callback(result)
@@ -394,8 +385,8 @@ class BitDustFTP(FTP):
         d.addErrback(self._ebReadOpened, newsegs)
         d.addBoth(self._enableTimeoutLater)
         if isinstance(ret, dict):
-#             if ret['status'] != 'OK':
-#                 return defer.fail(FileNotFoundError(path))
+            #             if ret['status'] != 'OK':
+            #                 return defer.fail(FileNotFoundError(path))
             self._cbRestoreDone(ret, newsegs, d)
             return d
         ret.addCallback(self._cbRestoreDone, newsegs, d)
@@ -415,9 +406,9 @@ class BitDustFTP(FTP):
 #         if not parent_item:
 #             return defer.fail(FileNotFoundError(parent_path))
 
-        # XXX For now, just disable the timeout.  Later we'll want to
-        # leave it active and have the DTP connection reset it
-        # periodically.
+# XXX For now, just disable the timeout.  Later we'll want to
+# leave it active and have the DTP connection reset it
+# periodically.
         self.setTimeout(None)
         # Put it back later
 
@@ -442,13 +433,13 @@ class BitDustFTP(FTP):
         d.addBoth(self._enableTimeoutLater)
         d.callback(_FileWriter(fObj))
 
-#         d.addCallbacks(self._cbFileRecevied, self._ebFileReceived)
-#         fw = _FileWriter(fObj)
-#         receive_defer = fw.receive()
-#         receive_defer.addBoth(self._enableTimeoutLater)
-#         receive_defer.addCallback(self._prepareConsumer)
-#         receive_defer.addCallback(self._startFileBackup, upload_filename, newsegs, d)
-#         receive_defer.addErrback(lambda err: d.errback(FileNotFoundError(path)))
+        #         d.addCallbacks(self._cbFileRecevied, self._ebFileReceived)
+        #         fw = _FileWriter(fObj)
+        #         receive_defer = fw.receive()
+        #         receive_defer.addBoth(self._enableTimeoutLater)
+        #         receive_defer.addCallback(self._prepareConsumer)
+        #         receive_defer.addCallback(self._startFileBackup, upload_filename, newsegs, d)
+        #         receive_defer.addErrback(lambda err: d.errback(FileNotFoundError(path)))
 
         return d
 
@@ -461,7 +452,10 @@ class BitDustFTP(FTP):
         ret = api.file_info(full_path)
         if ret['status'] != 'OK':
             return defer.fail(FileNotFoundError(path))
-        return succeed((FILE_STATUS, str(ret['size']), ))
+        return succeed((
+            FILE_STATUS,
+            str(ret['size']),
+        ))
 
 #         shortPathID = backup_fs.ToID(full_path)
 #         if shortPathID is None:
@@ -491,7 +485,7 @@ class BitDustFTP(FTP):
         ret = api.file_delete(full_path)
         if ret['status'] != 'OK':
             return defer.fail(FileNotFoundError(str(ret['errors'])))
-        return succeed((REQ_FILE_ACTN_COMPLETED_OK,))
+        return succeed((REQ_FILE_ACTN_COMPLETED_OK, ))
 
     def ftp_DELE(self, path):
         try:
@@ -502,7 +496,7 @@ class BitDustFTP(FTP):
         ret = api.file_delete(full_path)
         if ret['status'] != 'OK':
             return defer.fail(FileNotFoundError(str(ret['errors'])))
-        return succeed((REQ_FILE_ACTN_COMPLETED_OK,))
+        return succeed((REQ_FILE_ACTN_COMPLETED_OK, ))
 
     def ftp_RNTO(self, toName):
         fromName = self._fromName
@@ -514,17 +508,19 @@ class BitDustFTP(FTP):
         except InvalidPath:
             return defer.fail(FileNotFoundError(fromName))
         # TODO:
-        return succeed((REQ_FILE_ACTN_COMPLETED_OK,))
+        return succeed((REQ_FILE_ACTN_COMPLETED_OK, ))
+
 
 #------------------------------------------------------------------------------
 
+
 class BitDustFTPFactory(FTPFactory):
     protocol = BitDustFTP
 
 
 #------------------------------------------------------------------------------
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     lg.set_debug_level(20)
     settings.init()
     backup_fs.init()
@@ -534,9 +530,6 @@ if __name__ == "__main__":
     reactor.run()  # @UndefinedVariable
     settings.shutdown()
 
-
-
-
 #     def ftp_NLST(self, path):
 #         """
 #         """
@@ -545,26 +538,26 @@ if __name__ == "__main__":
 #         if self.dtpInstance is None or not self.dtpInstance.isConnected:
 #             return defer.fail(
 #                 BadCmdSequenceError('must send PORT or PASV before RETR'))
-# 
+#
 #         try:
 #             segments = toSegments(self.workingDirectory, path)
 #         except InvalidPath:
 #             return defer.fail(FileNotFoundError(path))
-# 
+#
 #         def cbList(results, glob):
 #             """
 #             Send, line by line, each matching file in the directory listing, and
 #             then close the connection.
-# 
+#
 #             @type results: A C{list} of C{tuple}. The first element of each
 #                 C{tuple} is a C{str} and the second element is a C{list}.
 #             @param results: The names of the files in the directory.
-# 
+#
 #             @param glob: A shell-style glob through which to filter results (see
 #                 U{http://docs.python.org/2/library/fnmatch.html}), or L{None}
 #                 for no filtering.
 #             @type glob: L{str} or L{None}
-# 
+#
 #             @return: A C{tuple} containing the status code for a successful
 #                 transfer.
 #             @rtype: C{tuple}
@@ -576,31 +569,31 @@ if __name__ == "__main__":
 #                     self.dtpInstance.sendLine(name)
 #             self.dtpInstance.transport.loseConnection()
 #             return (TXFR_COMPLETE_OK,)
-# 
+#
 #         def listErr(results):
 #             """
 #             RFC 959 specifies that an NLST request may only return directory
 #             listings. Thus, send nothing and just close the connection.
-# 
+#
 #             @type results: L{Failure}
 #             @param results: The L{Failure} wrapping a L{FileNotFoundError} that
 #                 occurred while trying to list the contents of a nonexistent
 #                 directory.
-# 
+#
 #             @returns: A C{tuple} containing the status code for a successful
 #                 transfer.
 #             @rtype: C{tuple}
 #             """
 #             self.dtpInstance.transport.loseConnection()
 #             return (TXFR_COMPLETE_OK,)
-# 
+#
 #         if _isGlobbingExpression(segments):
 #             # Remove globbing expression from path
 #             # and keep to be used for filtering.
 #             glob = segments.pop()
 #         else:
 #             glob = None
-# 
+#
 #         d = Deferred()
 #         d.addCallback(cbList, glob)
 #         d.addErrback(listErr)
@@ -608,4 +601,4 @@ if __name__ == "__main__":
 # #             d.errback(None)
 #         result = [(itm['id'], []) for itm in api.backups_list()['result']]
 #         d.callback(result)
-#         return d
\ No newline at end of file
+#         return d
