@@ -32,7 +32,7 @@ from bitdust.lib import strng
 #------------------------------------------------------------------------------
 
 
-def DictToBytes(dct, encoding='latin1', errors='strict', keys_to_text=False, values_to_text=False, pack_types=False):
+def DictToBytes(dct, encoding='latin1', errors='strict', keys_to_text=False, values_to_text=False, pack_types=False, indent=None):
     """
     Calls `json.dupms()` method for input dict to build bytes output.
     Uses encoding to decode every byte string to text and ensure ascii output.
@@ -46,8 +46,8 @@ def DictToBytes(dct, encoding='latin1', errors='strict', keys_to_text=False, val
     result = strng.to_bin(
         jsn.dumps(
             jsn.pack_dict(dct, encoding=encoding, errors=errors) if pack_types else dct,
+            indent=indent,
             separators=(',', ':'),
-            indent=None,
             sort_keys=True,
             ensure_ascii=True,
             encoding=encoding,
