@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -232,6 +231,9 @@ You can use `TCP`, `UDP`, and other network protocols to communicate with people
 The `gateway` service controls application transport protocols and all encrypted packets passing through and reaching application engine.
 Every incoming packet is digitally verified here, processed and sent to the underlying services.
 
+{services/gateway/p2p-timeout} peer-to-peer reply timeout
+Due to network failures or slowness, signed peer-to-peer packets are considered as "undelivered" without receiving a confirmation of delivery within the specified number of seconds.
+
 {services/http-connections/enabled} HTTP enabled
 This will allow BitDust to use the HTTP protocol for service data and encrypted traffic
 
@@ -329,7 +331,7 @@ All your conversations are stored in a local SQLite3 database and are quickly se
 The service is under development.
 
 {services/my-data/enabled} remote files indexing
-The service synchronizes with my suppliers in real time and prepares the encrypted storage environment for other dependent network services. 
+The service synchronizes with my suppliers in real time and prepares the encrypted storage environment for other dependent network services.
 
 {services/my-ip-port/enabled} detect my external IP via other nodes
 The service relies on other nodes and uses the STUN protocol to recognize your public IP address when connecting to the network.
@@ -426,7 +428,7 @@ The `rebuilding` service will automatically download the available fragments fro
 Controls network connections and incoming data streams when downloading encrypted fragments from suppliers nodes.
 
 {services/shared-data/enabled} enable data sharing
-Makes possible decentralized sharing of encrypted files with other users. 
+Makes possible decentralized sharing of encrypted files with other users.
 
 {services/supplier/enabled} donate own disk space to people
 To make it possible to store any files on the network, some other nodes must already be connected and provide storage space.
