@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: lookup.
 
@@ -54,15 +53,15 @@ from twisted.internet.defer import DeferredList, Deferred
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
-from logs import lg
+from bitdust.logs import lg
 
-from dht import dht_service
+from bitdust.dht import dht_service
 
-from contacts import identitycache
+from bitdust.contacts import identitycache
 
-from userid import id_url
+from bitdust.userid import id_url
 
 #------------------------------------------------------------------------------
 
@@ -86,7 +85,7 @@ def init(lookup_method=None, observe_method=None, process_method=None):
     _ObserveMethod = observe_method
     _ProcessMethod = process_method
     if _Debug:
-        lg.out(_DebugLevel, "lookup.init")
+        lg.out(_DebugLevel, 'lookup.init')
 
 
 def shutdown():
@@ -97,7 +96,8 @@ def shutdown():
     _ObserveMethod = None
     _ProcessMethod = None
     if _Debug:
-        lg.out(_DebugLevel, "lookup.shutdown")
+        lg.out(_DebugLevel, 'lookup.shutdown')
+
 
 #------------------------------------------------------------------------------
 
@@ -113,6 +113,7 @@ def discovered_idurls(layer_id=0):
         _DiscoveredIDURLsList[layer_id] = []
     return _DiscoveredIDURLsList[layer_id]
 
+
 #------------------------------------------------------------------------------
 
 
@@ -143,39 +144,43 @@ def extract_discovered_idurls(count=1, layer_id=0):
         lg.out(_DebugLevel, 'lookup.extract_discovered_idurls : %s' % results)
     return results
 
+
 #------------------------------------------------------------------------------
 
+
 def random_proxy_router(**kwargs):
-    from dht import dht_records
+    from bitdust.dht import dht_records
     kwargs['layer_id'] = dht_records.LAYER_PROXY_ROUTERS
     return start(**kwargs)
 
 
 def random_supplier(**kwargs):
-    from dht import dht_records
+    from bitdust.dht import dht_records
     kwargs['layer_id'] = dht_records.LAYER_SUPPLIERS
     return start(**kwargs)
 
 
 def random_message_broker(**kwargs):
-    from dht import dht_records
+    from bitdust.dht import dht_records
     kwargs['layer_id'] = dht_records.LAYER_MESSAGE_BROKERS
     return start(**kwargs)
 
 
 def random_merchant(**kwargs):
-    from dht import dht_records
+    from bitdust.dht import dht_records
     kwargs['layer_id'] = dht_records.LAYER_MERCHANTS
     return start(**kwargs)
 
 
 def random_customer(**kwargs):
-    from dht import dht_records
+    from bitdust.dht import dht_records
     kwargs['layer_id'] = dht_records.LAYER_CUSTOMERS
     return start(**kwargs)
 
+
 #------------------------------------------------------------------------------
 
+
 def start(count=1, consume=True, lookup_method=None, observe_method=None, process_method=None, force_discovery=False, ignore_idurls=[], layer_id=0):
     """
     NOTE: no parallel threads, DHT lookup can be started only one at time.
@@ -192,8 +197,7 @@ def start(count=1, consume=True, lookup_method=None, observe_method=None, proces
     )
     if not force_discovery and len(discovered_idurls(layer_id=layer_id)) > count:
         if _Debug:
-            lg.out(_DebugLevel - 4, 'lookup.start  knows %d discovered nodes, SKIP and return %d nodes' % (
-                len(discovered_idurls(layer_id=layer_id)), count))
+            lg.out(_DebugLevel - 4, 'lookup.start  knows %d discovered nodes, SKIP and return %d nodes' % (len(discovered_idurls(layer_id=layer_id)), count))
         if consume:
             idurls = consume_discovered_idurls(count, layer_id=layer_id)
         else:
@@ -205,11 +209,13 @@ def start(count=1, consume=True, lookup_method=None, observe_method=None, proces
     _LookupTasks.append(t)
     reactor.callLater(0, work)  # @UndefinedVariable
     if _Debug:
-        lg.out(_DebugLevel - 4, 'lookup.start  new DiscoveryTask created for %d nodes at layer %d' % (count, layer_id, ))
+        lg.out(_DebugLevel - 4, 'lookup.start  new DiscoveryTask created for %d nodes at layer %d' % (count, layer_id))
     return t
 
+
 #------------------------------------------------------------------------------
 
+
 def on_lookup_task_success(result):
     global _CurrentLookupTask
     if _Debug:
@@ -254,8 +260,10 @@ def work():
         lg.warn('task %s was closed immediately' % _CurrentLookupTask)
         _CurrentLookupTask = None
 
+
 #------------------------------------------------------------------------------
 
+
 def lookup_in_dht(layer_id=0):
     """
     Pick random node from Distributed Hash Table.
@@ -264,8 +272,7 @@ def lookup_in_dht(layer_id=0):
     if _Debug:
         lg.out(_DebugLevel, 'lookup.lookup_in_dht layer_id=%d' % (layer_id, ))
     d = dht_service.find_node(dht_service.random_key(), layer_id=layer_id)
-    if _Debug:
-        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='lookup_in_dht')
+    d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='lookup_in_dht')
     return d
 
 
@@ -288,8 +295,7 @@ def on_idurl_response(response, result):
 
 def observe_dht_node(node, layer_id=0):
     if _Debug:
-        lg.out(_DebugLevel, 'lookup.observe_dht_node   %s  layer_id=%d' % (
-            node, layer_id, ))
+        lg.out(_DebugLevel, 'lookup.observe_dht_node   %s  layer_id=%d' % (node, layer_id))
     result = Deferred()
     d = node.request('idurl', layerID=layer_id)
     d.addCallback(on_idurl_response, result)
@@ -311,7 +317,7 @@ def on_identity_cached(src, idurl, result):
 
 def process_idurl(idurl, node):
     if _Debug:
-        lg.out(_DebugLevel, 'lookup.process_idurl %r from %r' % (idurl, node, ))
+        lg.out(_DebugLevel, 'lookup.process_idurl %r from %r' % (idurl, node))
     result = Deferred()
     if not idurl:
         result.errback(Exception(idurl))
@@ -321,10 +327,11 @@ def process_idurl(idurl, node):
     d.addErrback(result.errback)
     return result
 
+
 #------------------------------------------------------------------------------
 
-class DiscoveryTask(object):
 
+class DiscoveryTask(object):
     def __init__(
         self,
         count,
@@ -358,8 +365,7 @@ class DiscoveryTask(object):
         self.observe_finished = False
         self.lookup_task = None
         self.result_defer = Deferred(canceller=lambda d: self._close())
-        if _Debug:
-            self.result_defer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='DiscoveryTask')
+        self.result_defer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='DiscoveryTask')
         if _Debug:
             lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r].__init__   layer_id=%d' % (self.id, self.layer_id))
 
@@ -394,8 +400,7 @@ class DiscoveryTask(object):
         self.process_method = None
         self.result_defer = None
         if _Debug:
-            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r].close finished in %f seconds' % (
-                self.id, round(time.time() - self.started, 3)))
+            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r].close finished in %f seconds' % (self.id, round(time.time() - self.started, 3)))
 
     def _lookup_nodes(self):
         if self.lookup_task and not self.lookup_task.called:
@@ -415,8 +420,7 @@ class DiscoveryTask(object):
             lg.warn('DiscoveryTask[%r] : discovery process already stopped' % self.id)
             return
         if _Debug:
-            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._observe_nodes  started for %d items  layer_id=%d' % (
-                self.id, len(nodes), self.layer_id, ))
+            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._observe_nodes  started for %d items  layer_id=%d' % (self.id, len(nodes), self.layer_id))
         observe_list = []
         for node in nodes:
             d = self.observe_method(node, layer_id=self.layer_id)
@@ -426,30 +430,26 @@ class DiscoveryTask(object):
         self.observed_count = len(nodes)
         dl = DeferredList(observe_list, consumeErrors=False)
         dl.addCallback(self._on_all_nodes_observed)
-        if _Debug:
-            dl.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='DiscoveryTask._observe_nodes')
+        dl.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='DiscoveryTask._observe_nodes')
 
     def _report_result(self, results=None):
         if _Debug:
-            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]_report_result in %f seconds   %s,   result_defer=%s' % (
-                self.id, round(time.time() - self.started, 3), str(results), self.result_defer))
+            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]_report_result in %f seconds   %s,   result_defer=%s' % (self.id, round(time.time() - self.started, 3), str(results), self.result_defer))
         if results is None:
             if self.consume:
                 results = consume_discovered_idurls(self.count, layer_id=self.layer_id)
                 if _Debug:
-                    lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]    %d results consumed, %d were requested' % (
-                        self.id, len(results), self.count))
+                    lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]    %d results consumed, %d were requested' % (self.id, len(results), self.count))
             else:
                 results = extract_discovered_idurls(self.count, layer_id=self.layer_id)
                 if _Debug:
-                    lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]    %d results extracted, %d were requested' % (
-                        self.id, len(results), self.count))
+                    lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]    %d results extracted, %d were requested' % (self.id, len(results), self.count))
         if self.result_defer and not self.result_defer.called:
             self.result_defer.callback(results)
         self.result_defer = None
 
     def _report_fails(self, err):
-        lg.err('DHT lookup %r failed: %r' % (self.id, err, ))
+        lg.err('DHT lookup %r failed: %r' % (self.id, err))
         if self.result_defer:
             self.result_defer.errback(err)
         self.result_defer = None
@@ -490,8 +490,7 @@ class DiscoveryTask(object):
         cached_time = known_idurls().get(idurl)
         if cached_time and time.time() - cached_time < 30.0:
             if _Debug:
-                lg.out(_DebugLevel + 4, 'lookup.DiscoveryTask[%r]._on_node_observed   SKIP processing node %r because already observed recently' % (
-                    self.id, idurl))
+                lg.out(_DebugLevel + 4, 'lookup.DiscoveryTask[%r]._on_node_observed   SKIP processing node %r because already observed recently' % (self.id, idurl))
             self._on_identity_cached(idurl, node)
             return idurl
         d = self.process_method(idurl, node)
@@ -505,19 +504,16 @@ class DiscoveryTask(object):
                 lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed   node %s processed but task already finished' % (self.id, idurl))
             return None
         if _Debug:
-            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed  %r  discovered_idurls=%d count=%d  idurl=%s' % (
-                self.id, node, len(discovered_idurls(layer_id=self.layer_id)), self.count, idurl))
+            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed  %r  discovered_idurls=%d count=%d  idurl=%s' % (self.id, node, len(discovered_idurls(layer_id=self.layer_id)), self.count, idurl))
         if self.succeed + self.failed >= self.count:
             if _Debug:
-                lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed   enough node processed : succeed=%d  failed=%d' % (
-                    self.id, self.succeed, self.failed))
+                lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed   enough node processed : succeed=%d  failed=%d' % (self.id, self.succeed, self.failed))
             self._report_result()
             # self._close()
             return node
         if self.succeed + self.failed >= self.observed_count:
             if _Debug:
-                lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed   all observed nodes are processed : succeed=%d  failed=%d observed_count=%d' % (
-                    self.id, self.succeed, self.failed, self.observed_count))
+                lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_node_processed   all observed nodes are processed : succeed=%d  failed=%d observed_count=%d' % (self.id, self.succeed, self.failed, self.observed_count))
             self._report_result()
             self._close()
             return node
@@ -532,8 +528,7 @@ class DiscoveryTask(object):
             lg.warn('DiscoveryTask[%r] : observe finished, but discovery process already stopped' % self.id)
             return
         if _Debug:
-            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_all_nodes_observed results: %r, discovered nodes: %d' % (
-                self.id, observe_results, len(discovered_idurls(layer_id=self.layer_id))))
+            lg.out(_DebugLevel, 'lookup.DiscoveryTask[%r]._on_all_nodes_observed results: %r, discovered nodes: %d' % (self.id, observe_results, len(discovered_idurls(layer_id=self.layer_id))))
         self.observe_finished = True
         found_any_nodes = False
         for one_result in observe_results:
@@ -593,4 +588,5 @@ class DiscoveryTask(object):
         self._close()
         return err
 
+
 #------------------------------------------------------------------------------
