@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: p2p_service.
 
@@ -52,32 +51,27 @@ _DebugLevel = 10
 
 #------------------------------------------------------------------------------
 
-from twisted.internet import reactor  # @UnresolvedImport
-
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from contacts import identitycache
+from bitdust.main import settings
 
-from p2p import commands
+from bitdust.p2p import commands
 
-from lib import packetid
-from lib import nameurl
-from lib import serialization
+from bitdust.lib import packetid
+from bitdust.lib import nameurl
+from bitdust.lib import serialization
 
-from crypt import signed
-from crypt import my_keys
+from bitdust.crypt import signed
+from bitdust.crypt import my_keys
 
-from transport import gateway
-from transport import packet_out
-from transport import callback
+from bitdust.transport import gateway
+from bitdust.transport import callback
 
-from userid import identity
-from userid import id_url
-from userid import my_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -93,12 +87,14 @@ def shutdown():
         lg.out(_DebugLevel, 'p2p_service.shutdown')
     callback.remove_outbox_filter_callback(outbox)
 
+
 #------------------------------------------------------------------------------
 
+
 def inbox(newpacket, info, status, error_message):
-#     if newpacket.CreatorID != my_id.getIDURL() and newpacket.RemoteID != my_id.getIDURL():
-#         # packet is NOT for us, skip
-#         return False
+    #     if newpacket.CreatorID != my_id.getIDURL() and newpacket.RemoteID != my_id.getIDURL():
+    #         # packet is NOT for us, skip
+    #         return False
 
     if newpacket.Command == commands.Identity():
         # a response from remote node, typically handled in other places
@@ -187,25 +183,23 @@ def inbox(newpacket, info, status, error_message):
         Contacts(newpacket, info)
 
     else:
-        lg.warn('unexpected command received: %r from %r' % (newpacket, info, ))
+        lg.warn('unexpected command received: %r from %r' % (newpacket, info))
 
     return False
 
 
 def outbox(outpacket, wide, callbacks, target=None, route=None, response_timeout=None, keep_alive=True):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.outbox [%s:%s] to %s with route %r" % (
-            outpacket.Command, outpacket.PacketID, nameurl.GetName(outpacket.RemoteID), route, ))
+        lg.out(_DebugLevel, 'p2p_service.outbox [%s:%s] to %s with route %r' % (outpacket.Command, outpacket.PacketID, nameurl.GetName(outpacket.RemoteID), route))
     return None
 
+
 #------------------------------------------------------------------------------
 
 
 def Ack(newpacket, info):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.Ack %s from [%s] at %s://%s with %d bytes payload" % (
-            newpacket.PacketID, nameurl.GetName(newpacket.CreatorID),
-            info.proto, info.host, len(newpacket.Payload)))
+        lg.out(_DebugLevel, 'p2p_service.Ack %s from [%s] at %s://%s with %d bytes payload' % (newpacket.PacketID, nameurl.GetName(newpacket.CreatorID), info.proto, info.host, len(newpacket.Payload)))
 
 
 def SendAck(packettoack, response='', wide=False, callbacks={}, remote_idurl=None):
@@ -220,8 +214,7 @@ def SendAck(packettoack, response='', wide=False, callbacks={}, remote_idurl=Non
         RemoteID=remote_idurl,
     )
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendAck %s to %s  with %d bytes" % (
-            result.PacketID, result.RemoteID, len(response)))
+        lg.out(_DebugLevel, 'p2p_service.SendAck %s to %s  with %d bytes' % (result.PacketID, result.RemoteID, len(response)))
     gateway.outbox(result, wide=wide, callbacks=callbacks)
     return result
 
@@ -236,11 +229,11 @@ def SendAckNoRequest(remoteID, packetid, response='', wide=False, callbacks={}):
         RemoteID=remoteID,
     )
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendAckNoRequest packetID=%s to %s  with %d bytes" % (
-            result.PacketID, result.RemoteID, len(response)))
+        lg.out(_DebugLevel, 'p2p_service.SendAckNoRequest packetID=%s to %s  with %d bytes' % (result.PacketID, result.RemoteID, len(response)))
     gateway.outbox(result, wide=wide, callbacks=callbacks)
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -249,8 +242,7 @@ def Fail(newpacket):
         if newpacket.Payload:
             lg.warn('%r received from [%s] in %r' % (newpacket.Payload, newpacket.CreatorID, newpacket))
         else:
-            lg.out(_DebugLevel, "p2p_service.Fail from %s|%s packetID=%s : %s" % (
-                newpacket.CreatorID, newpacket.OwnerID, newpacket.PacketID, newpacket.Payload))
+            lg.out(_DebugLevel, 'p2p_service.Fail from %s|%s packetID=%s : %s' % (newpacket.CreatorID, newpacket.OwnerID, newpacket.PacketID, newpacket.Payload))
 
 
 def SendFail(request, response='', remote_idurl=None, wide=False):
@@ -265,8 +257,7 @@ def SendFail(request, response='', remote_idurl=None, wide=False):
         RemoteID=remote_idurl,
     )
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendFail packetID=%s to %s  with %d bytes" % (
-            result.PacketID, result.RemoteID, len(response)))
+        lg.out(_DebugLevel, 'p2p_service.SendFail packetID=%s to %s  with %d bytes' % (result.PacketID, result.RemoteID, len(response)))
     gateway.outbox(result, wide=wide)
     return result
 
@@ -281,17 +272,17 @@ def SendFailNoRequest(remoteID, packetID, response=''):
         RemoteID=remoteID,
     )
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendFailNoRequest packetID=%s to %s" % (result.PacketID, result.RemoteID))
+        lg.out(_DebugLevel, 'p2p_service.SendFailNoRequest packetID=%s to %s' % (result.PacketID, result.RemoteID))
     gateway.outbox(result)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def Identity(newpacket, info):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.Identity %s from [%s] at %s://%s with %d bytes payload" % (
-            newpacket.PacketID, nameurl.GetName(newpacket.CreatorID),
-            info.proto, info.host, len(newpacket.Payload)))
+        lg.out(_DebugLevel, 'p2p_service.Identity %s from [%s] at %s://%s with %d bytes payload' % (newpacket.PacketID, nameurl.GetName(newpacket.CreatorID), info.proto, info.host, len(newpacket.Payload)))
 
 
 #     """
@@ -359,11 +350,12 @@ def Identity(newpacket, info):
 #     return True
 
 
-def SendIdentity(remote_idurl, wide=False, timeout=10, callbacks={}):
+def SendIdentity(remote_idurl, wide=False, timeout=None, callbacks={}):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     packet_id = 'identity:%s' % packetid.UniqueID()
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendIdentity to %s wide=%s packet_id=%r" % (
-            nameurl.GetName(remote_idurl), wide, packet_id, ))
+        lg.out(_DebugLevel, 'p2p_service.SendIdentity to %s wide=%s packet_id=%r' % (nameurl.GetName(remote_idurl), wide, packet_id))
     result = signed.Packet(
         Command=commands.Identity(),
         OwnerID=my_id.getIDURL(),
@@ -375,6 +367,7 @@ def SendIdentity(remote_idurl, wide=False, timeout=10, callbacks={}):
     gateway.outbox(result, wide=wide, callbacks=callbacks, response_timeout=timeout)
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -385,13 +378,13 @@ def RequestService(request, info):
         except:
             lg.exc()
             service_info = {}
-        lg.out(_DebugLevel, 'p2p_service.RequestService %s with "%s" in %d bytes' % (
-            request.PacketID, service_info.get('name', 'unknown service name'), len(request.Payload)))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, 'p2p_service.RequestService %s with "%s" in %d bytes' % (request.PacketID, service_info.get('name', 'unknown service name'), len(request.Payload)))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
-def SendRequestService(remote_idurl, service_name, json_payload={}, wide=False, callbacks={}, timeout=60, packet_id=None):
+def SendRequestService(remote_idurl, service_name, json_payload={}, wide=False, callbacks={}, timeout=None, packet_id=None):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     service_info = {
         'name': service_name,
         'payload': json_payload,
@@ -400,8 +393,7 @@ def SendRequestService(remote_idurl, service_name, json_payload={}, wide=False,
     if packet_id is None:
         packet_id = packetid.UniqueID()
     if _Debug:
-        lg.out(_DebugLevel, 'p2p_service.SendRequestService "%s" to %s with %d bytes pid:%s timeout:%r' % (
-            service_name, remote_idurl, len(service_info_raw), packet_id, timeout, ))
+        lg.out(_DebugLevel, 'p2p_service.SendRequestService "%s" to %s with %d bytes pid:%s timeout:%r' % (service_name, remote_idurl, len(service_info_raw), packet_id, timeout))
     result = signed.Packet(
         Command=commands.RequestService(),
         OwnerID=my_id.getIDURL(),
@@ -421,21 +413,20 @@ def CancelService(request, info):
         except:
             lg.exc()
             service_info = {}
-        lg.out(_DebugLevel, 'p2p_service.CancelService %s with "%s" in %d bytes' % (
-            request.PacketID, service_info.get('name', 'unknown service name'), len(request.Payload), ))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, 'p2p_service.CancelService %s with "%s" in %d bytes' % (request.PacketID, service_info.get('name', 'unknown service name'), len(request.Payload)))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
-def SendCancelService(remote_idurl, service_name, json_payload={}, wide=False, callbacks={}, timeout=20):
+def SendCancelService(remote_idurl, service_name, json_payload={}, wide=False, callbacks={}, timeout=None):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     service_info = {
         'name': service_name,
         'payload': json_payload,
     }
     service_info_raw = serialization.DictToBytes(service_info)
     if _Debug:
-        lg.out(_DebugLevel, 'p2p_service.SendCancelService "%s" to %s with %d bytes payload' % (
-            service_name, remote_idurl, len(service_info_raw)))
+        lg.out(_DebugLevel, 'p2p_service.SendCancelService "%s" to %s with %d bytes payload' % (service_name, remote_idurl, len(service_info_raw)))
     result = signed.Packet(
         Command=commands.CancelService(),
         OwnerID=my_id.getIDURL(),
@@ -447,8 +438,10 @@ def SendCancelService(remote_idurl, service_name, json_payload={}, wide=False, c
     gateway.outbox(result, wide=wide, callbacks=callbacks, response_timeout=timeout)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def ListFiles(request, info):
     """
     We will want to use this to see what needs to be resent, and expect normal
@@ -459,8 +452,7 @@ def ListFiles(request, info):
     """
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.ListFiles %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendListFiles(target_supplier, customer_idurl=None, key_id=None, query_items=[], wide=False, callbacks={}, timeout=None):
@@ -468,6 +460,8 @@ def SendListFiles(target_supplier, customer_idurl=None, key_id=None, query_items
     This is used as a request method from your supplier : if you send him a ListFiles() packet
     he will reply you with a list of stored files in a Files() packet.
     """
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     MyID = my_id.getIDURL()
     if not customer_idurl:
         customer_idurl = MyID
@@ -476,7 +470,7 @@ def SendListFiles(target_supplier, customer_idurl=None, key_id=None, query_items
     else:
         RemoteID = contactsdb.supplier(target_supplier, customer_idurl=customer_idurl)
     if not RemoteID:
-        lg.warn("RemoteID is empty target_supplier=%s" % str(target_supplier))
+        lg.warn('RemoteID is empty target_supplier=%s' % str(target_supplier))
         return None
     if not key_id:
         # key_id = global_id.MakeGlobalID(idurl=customer_idurl, key_alias='customer')
@@ -491,13 +485,15 @@ def SendListFiles(target_supplier, customer_idurl=None, key_id=None, query_items
     if not my_keys.is_key_registered(key_id) or not my_keys.is_key_private(key_id):
         lg.warn('key %r not exist or public, my "master" key to be used with ListFiles() packet' % key_id)
         key_id = my_id.getGlobalID(key_alias='master')
-    PacketID = "%s:%s" % (key_id, packetid.UniqueID(), )
+    PacketID = '%s:%s' % (
+        key_id,
+        packetid.UniqueID(),
+    )
     if not query_items:
-        query_items = ['*', ]
-    Payload = serialization.DictToBytes({'items': query_items, })
+        query_items = ['*']
+    Payload = serialization.DictToBytes({'items': query_items})
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendListFiles %r to %r of customer %r with query : %r" % (
-            PacketID, nameurl.GetName(RemoteID), nameurl.GetName(customer_idurl), query_items, ))
+        lg.out(_DebugLevel, 'p2p_service.SendListFiles %r to %r of customer %r with query : %r' % (PacketID, nameurl.GetName(RemoteID), nameurl.GetName(customer_idurl), query_items))
     result = signed.Packet(
         Command=commands.ListFiles(),
         OwnerID=MyID,
@@ -509,25 +505,27 @@ def SendListFiles(target_supplier, customer_idurl=None, key_id=None, query_items
     gateway.outbox(result, wide=wide, callbacks=callbacks, response_timeout=timeout)
     return result
 
+
 #------------------------------------------------------------------------------
 
+
 def Files(request, info):
     """
     A directory list came in from some supplier or another customer.
     """
     if _Debug:
-        lg.out(_DebugLevel, 'p2p_service.Files %d bytes in [%s] from %s by %s|%s' % (
-            len(request.Payload), request.PacketID, nameurl.GetName(request.RemoteID),
-            nameurl.GetName(request.OwnerID), nameurl.GetName(request.CreatorID), ))
+        lg.out(_DebugLevel, 'p2p_service.Files %d bytes in [%s] from %s by %s|%s' % (len(request.Payload), request.PacketID, nameurl.GetName(request.RemoteID), nameurl.GetName(request.OwnerID), nameurl.GetName(request.CreatorID)))
 
 
-def SendFiles(idurl, raw_list_files_info, packet_id, callbacks={}, timeout=10, ):
+def SendFiles(idurl, raw_list_files_info, packet_id, callbacks={}, timeout=None):
     """
     Sending information about known files stored locally for given customer (if you are supplier).
     You can also send a list of your files to another user if you wish to grand access.
     This will not send any personal data : only file names, ids, versions, etc.
     So pass list of files in encrypted form in the `payload` or leave it empty.
     """
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     MyID = my_id.getIDURL()
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.SendFiles %d bytes in packetID=%s' % (len(raw_list_files_info), packet_id))
@@ -543,6 +541,7 @@ def SendFiles(idurl, raw_list_files_info, packet_id, callbacks={}, timeout=10, )
     result = gateway.outbox(newpacket, callbacks=callbacks, response_timeout=timeout)
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -553,8 +552,7 @@ def Data(request):
     """
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Data %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendData(raw_data, ownerID, creatorID, remoteID, packetID, callbacks={}):
@@ -568,8 +566,7 @@ def SendData(raw_data, ownerID, creatorID, remoteID, packetID, callbacks={}):
     )
     result = gateway.outbox(newpacket, callbacks=callbacks)
     if _Debug:
-        lg.out(_DebugLevel, 'p2p_service.SendData %d bytes in packetID=%s' % (
-            len(raw_data), packetID))
+        lg.out(_DebugLevel, 'p2p_service.SendData %d bytes in packetID=%s' % (len(raw_data), packetID))
         lg.out(_DebugLevel, '  to remoteID=%s  ownerID=%s  creatorID=%s' % (remoteID, ownerID, creatorID))
     return newpacket, result
 
@@ -583,8 +580,7 @@ def Retrieve(request):
     """
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Retrieve %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendRetreive(ownerID, creatorID, packetID, remoteID, payload='', response_timeout=None, callbacks={}):
@@ -602,6 +598,7 @@ def SendRetreive(ownerID, creatorID, packetID, remoteID, payload='', response_ti
         lg.out(_DebugLevel, '  remoteID=%s  ownerID=%s  creatorID=%s' % (remoteID, ownerID, creatorID))
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -611,13 +608,12 @@ def DeleteFile(request):
     """
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.DeleteFile %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendDeleteFile(SupplierID, pathID):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendDeleteFile SupplierID=%s PathID=%s" % (SupplierID, pathID))
+        lg.out(_DebugLevel, 'p2p_service.SendDeleteFile SupplierID=%s PathID=%s' % (SupplierID, pathID))
     MyID = my_id.getIDURL()
     PacketID = pathID
     RemoteID = SupplierID
@@ -626,7 +622,7 @@ def SendDeleteFile(SupplierID, pathID):
         OwnerID=MyID,
         CreatorID=MyID,
         PacketID=PacketID,
-        Payload="",
+        Payload='',
         RemoteID=RemoteID,
     )
     gateway.outbox(result)
@@ -635,7 +631,7 @@ def SendDeleteFile(SupplierID, pathID):
 
 def SendDeleteListPaths(SupplierID, ListPathIDs):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendDeleteListPaths SupplierID=%s PathIDs: %s" % (SupplierID, ListPathIDs))
+        lg.out(_DebugLevel, 'p2p_service.SendDeleteListPaths SupplierID=%s PathIDs: %s' % (SupplierID, ListPathIDs))
     MyID = my_id.getIDURL()
     PacketID = packetid.UniqueID()
     RemoteID = SupplierID
@@ -651,6 +647,7 @@ def SendDeleteListPaths(SupplierID, ListPathIDs):
     gateway.outbox(result)
     return result
 
+
 #------------------------------------------------------------------------------
 
 
@@ -660,13 +657,12 @@ def DeleteBackup(request):
     """
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.DeleteBackup %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendDeleteBackup(SupplierID, BackupID):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendDeleteBackup SupplierID=%s  BackupID=%s" % (SupplierID, BackupID))
+        lg.out(_DebugLevel, 'p2p_service.SendDeleteBackup SupplierID=%s  BackupID=%s' % (SupplierID, BackupID))
     MyID = my_id.getIDURL()
     PacketID = packetid.RemotePath(BackupID)
     RemoteID = SupplierID
@@ -675,7 +671,7 @@ def SendDeleteBackup(SupplierID, BackupID):
         OwnerID=MyID,
         CreatorID=MyID,
         PacketID=PacketID,
-        Payload="",
+        Payload='',
         RemoteID=RemoteID,
     )
     gateway.outbox(result)
@@ -684,7 +680,7 @@ def SendDeleteBackup(SupplierID, BackupID):
 
 def SendDeleteListBackups(SupplierID, ListBackupIDs):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendDeleteListBackups SupplierID=%s BackupIDs: %s" % (SupplierID, ListBackupIDs))
+        lg.out(_DebugLevel, 'p2p_service.SendDeleteListBackups SupplierID=%s BackupIDs: %s' % (SupplierID, ListBackupIDs))
     MyID = my_id.getIDURL()
     PacketID = packetid.UniqueID()
     RemoteID = SupplierID
@@ -700,24 +696,26 @@ def SendDeleteListBackups(SupplierID, ListBackupIDs):
     gateway.outbox(result)
     return result
 
+
 #------------------------------------------------------------------------------
 
 
 def Correspondent(request):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Correspondent %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
     # TODO: need to connect users here
 
+
 #------------------------------------------------------------------------------
 
+
 def RequestDeleteBackup(BackupID):
     """
     Need to send a "DeleteBackup" command to all suppliers.
     """
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.RequestDeleteBackup with BackupID=" + str(BackupID))
+        lg.out(_DebugLevel, 'p2p_service.RequestDeleteBackup with BackupID=' + str(BackupID))
     for supplier_idurl in contactsdb.suppliers(customer_idurl=packetid.CustomerIDURL(BackupID)):
         if not supplier_idurl:
             continue
@@ -726,7 +724,7 @@ def RequestDeleteBackup(BackupID):
 
 def RequestDeleteListBackups(backupIDs):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.RequestDeleteListBackups wish to delete %d backups" % len(backupIDs))
+        lg.out(_DebugLevel, 'p2p_service.RequestDeleteListBackups wish to delete %d backups' % len(backupIDs))
     customers = {}
     for backupID in backupIDs:
         customer_idurl = packetid.CustomerIDURL(backupID)
@@ -741,7 +739,7 @@ def RequestDeleteListBackups(backupIDs):
 
 def RequestDeleteListPaths(pathIDs):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.RequestDeleteListPaths wish to delete %d paths" % len(pathIDs))
+        lg.out(_DebugLevel, 'p2p_service.RequestDeleteListPaths wish to delete %d paths' % len(pathIDs))
     customers = {}
     for pathID in pathIDs:
         customer_idurl = packetid.CustomerIDURL(pathID)
@@ -756,7 +754,8 @@ def RequestDeleteListPaths(pathIDs):
 
 def CheckWholeBackup(BackupID):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.CheckWholeBackup with BackupID=" + BackupID)
+        lg.out(_DebugLevel, 'p2p_service.CheckWholeBackup with BackupID=' + BackupID)
+
 
 #-------------------------------------------------------------------------------
 
@@ -764,16 +763,16 @@ def CheckWholeBackup(BackupID):
 def Broadcast(request, info):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Broadcast %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s  sender_idurl=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID, info.sender_idurl))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s  sender_idurl=%s' % (request.RemoteID, request.OwnerID, request.CreatorID, info.sender_idurl))
 
 
 def SendBroadcastMessage(outpacket):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendBroadcastMessage to %s" % outpacket.RemoteID)
+        lg.out(_DebugLevel, 'p2p_service.SendBroadcastMessage to %s' % outpacket.RemoteID)
     gateway.outbox(outpacket)
     return outpacket
 
+
 #------------------------------------------------------------------------------
 
 
@@ -784,13 +783,12 @@ def Coin(request, info):
         except:
             lg.exc()
             input_coins = []
-        lg.out(_DebugLevel, "p2p_service.Coin from %s with %d coins" % (
-            nameurl.GetName(info.sender_idurl), len(input_coins), ))
+        lg.out(_DebugLevel, 'p2p_service.Coin from %s with %d coins' % (nameurl.GetName(info.sender_idurl), len(input_coins)))
 
 
 def SendCoin(remote_idurl, coins, packet_id=None, wide=False, callbacks={}):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendCoin to %s with %d records" % (remote_idurl, len(coins)))
+        lg.out(_DebugLevel, 'p2p_service.SendCoin to %s with %d records' % (remote_idurl, len(coins)))
     if packet_id is None:
         packet_id = packetid.UniqueID()
     outpacket = signed.Packet(
@@ -807,13 +805,12 @@ def SendCoin(remote_idurl, coins, packet_id=None, wide=False, callbacks={}):
 
 def RetrieveCoin(request, info):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.RetrieveCoin from %s : %s" % (
-            nameurl.GetName(info.sender_idurl), request.Payload))
+        lg.out(_DebugLevel, 'p2p_service.RetrieveCoin from %s : %s' % (nameurl.GetName(info.sender_idurl), request.Payload))
 
 
 def SendRetrieveCoin(remote_idurl, query, wide=False, callbacks={}):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendRetrieveCoin to %s" % remote_idurl)
+        lg.out(_DebugLevel, 'p2p_service.SendRetrieveCoin to %s' % remote_idurl)
     outpacket = signed.Packet(
         Command=commands.RetrieveCoin(),
         OwnerID=my_id.getIDURL(),
@@ -825,21 +822,30 @@ def SendRetrieveCoin(remote_idurl, query, wide=False, callbacks={}):
     gateway.outbox(outpacket, wide=wide, callbacks=callbacks)
     return outpacket
 
+
 #------------------------------------------------------------------------------
 
+
 def Key(request, info):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Key %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from senderID=%s to remoteID=%s  ownerID=%s  creatorID=%s  ' % (
-            info.sender_idurl, request.RemoteID, request.OwnerID, request.CreatorID, ))
+        lg.out(_DebugLevel, '  from senderID=%s to remoteID=%s  ownerID=%s  creatorID=%s  ' % (info.sender_idurl, request.RemoteID, request.OwnerID, request.CreatorID))
 
 
-def SendKey(remote_idurl, encrypted_key_data, packet_id=None, wide=False, callbacks={}, timeout=20, ):
+def SendKey(
+    remote_idurl,
+    encrypted_key_data,
+    packet_id=None,
+    wide=False,
+    callbacks={},
+    timeout=None,
+):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     if packet_id is None:
         packet_id = packetid.UniqueID()
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendKey [%s] to %s with %d bytes encrypted key data" % (
-            packet_id, remote_idurl, len(encrypted_key_data)))
+        lg.out(_DebugLevel, 'p2p_service.SendKey [%s] to %s with %d bytes encrypted key data' % (packet_id, remote_idurl, len(encrypted_key_data)))
     outpacket = signed.Packet(
         Command=commands.Key(),
         OwnerID=my_id.getIDURL(),
@@ -855,14 +861,14 @@ def SendKey(remote_idurl, encrypted_key_data, packet_id=None, wide=False, callba
 def AuditKey(request, info):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.AuditKey %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s  sender_idurl=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID, info.sender_idurl))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s  sender_idurl=%s' % (request.RemoteID, request.OwnerID, request.CreatorID, info.sender_idurl))
 
 
-def SendAuditKey(remote_idurl, encrypted_payload, packet_id=None, timeout=10, wide=False, callbacks={}):
+def SendAuditKey(remote_idurl, encrypted_payload, packet_id=None, timeout=None, wide=False, callbacks={}):
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendAuditKey to %s with %d bytes in json payload data" % (
-            remote_idurl, len(encrypted_payload)))
+        lg.out(_DebugLevel, 'p2p_service.SendAuditKey to %s with %d bytes in json payload data' % (remote_idurl, len(encrypted_payload)))
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
     if packet_id is None:
         packet_id = packetid.UniqueID()
     outpacket = signed.Packet(
@@ -876,8 +882,10 @@ def SendAuditKey(remote_idurl, encrypted_payload, packet_id=None, timeout=10, wi
     gateway.outbox(outpacket, wide=wide, callbacks=callbacks, response_timeout=timeout)
     return outpacket
 
+
 #------------------------------------------------------------------------------
 
+
 def Event(request, info):
     if _Debug:
         try:
@@ -887,14 +895,12 @@ def Event(request, info):
         except:
             lg.exc()
             return
-        lg.out(_DebugLevel, "p2p_service.Event %s from %s with %d bytes in json" % (
-            e_json['event_id'], info.sender_idurl, len(request.Payload), ))
+        lg.out(_DebugLevel, 'p2p_service.Event %s from %s with %d bytes in json' % (e_json['event_id'], info.sender_idurl, len(request.Payload)))
 
 
-def SendEvent(remote_idurl, event_id, payload=None,
-              producer_id=None, consumer_id=None, queue_id=None,
-              message_id=None, created=None, packet_id=None,
-              wide=False, callbacks={}, response_timeout=5):
+def SendEvent(remote_idurl, event_id, payload=None, producer_id=None, consumer_id=None, queue_id=None, message_id=None, created=None, packet_id=None, wide=False, callbacks={}, response_timeout=None):
+    if response_timeout is None:
+        response_timeout = settings.P2PTimeOut()
     if packet_id is None:
         packet_id = packetid.UniqueID()
     e_json = {
@@ -913,8 +919,7 @@ def SendEvent(remote_idurl, event_id, payload=None,
         e_json['created'] = created
     e_json_src = serialization.DictToBytes(e_json)
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendEvent to %s with %d bytes message json data" % (
-            remote_idurl, len(e_json_src)))
+        lg.out(_DebugLevel, 'p2p_service.SendEvent to %s with %d bytes message json data' % (remote_idurl, len(e_json_src)))
     outpacket = signed.Packet(
         Command=commands.Event(),
         OwnerID=my_id.getIDURL(),
@@ -926,20 +931,21 @@ def SendEvent(remote_idurl, event_id, payload=None,
     gateway.outbox(outpacket, wide=wide, callbacks=callbacks, response_timeout=response_timeout)
     return outpacket
 
+
 #------------------------------------------------------------------------------
 
+
 def Message(request, info):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Message %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendMessage(remote_idurl, packet_id=None, payload=None, wide=True, callbacks={}, response_timeout=None):
     if packet_id is None:
         packet_id = packetid.UniqueID()
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendMessage to %s with packet_id=%s" % (nameurl.GetName(remote_idurl), packet_id, ))
+        lg.out(_DebugLevel, 'p2p_service.SendMessage to %s with packet_id=%s' % (nameurl.GetName(remote_idurl), packet_id))
     outpacket = signed.Packet(
         Command=commands.Message(),
         OwnerID=my_id.getIDURL(),
@@ -951,19 +957,20 @@ def SendMessage(remote_idurl, packet_id=None, payload=None, wide=True, callbacks
     result = gateway.outbox(outpacket, wide=wide, callbacks=callbacks, response_timeout=response_timeout)
     return result, outpacket
 
+
 #------------------------------------------------------------------------------
 
+
 def Contacts(request, info):
     if _Debug:
         lg.out(_DebugLevel, 'p2p_service.Contacts %d bytes in [%s]' % (len(request.Payload), request.PacketID))
-        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (
-            request.RemoteID, request.OwnerID, request.CreatorID))
+        lg.out(_DebugLevel, '  from remoteID=%s  ownerID=%s  creatorID=%s' % (request.RemoteID, request.OwnerID, request.CreatorID))
 
 
 def SendContacts(remote_idurl, json_payload={}, wide=False, callbacks={}):
     MyID = my_id.getIDURL()
     if _Debug:
-        lg.out(_DebugLevel, "p2p_service.SendContacts to %s" % nameurl.GetName(remote_idurl))
+        lg.out(_DebugLevel, 'p2p_service.SendContacts to %s' % nameurl.GetName(remote_idurl))
     PacketID = packetid.UniqueID()
     try:
         json_payload['type']
@@ -983,4 +990,5 @@ def SendContacts(remote_idurl, json_payload={}, wide=False, callbacks={}):
     gateway.outbox(result, wide=wide, callbacks=callbacks)
     return result
 
+
 #------------------------------------------------------------------------------
