@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: p2p_service_seeker
 
@@ -55,22 +53,24 @@ from twisted.internet.defer import Deferred
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import strng
-from lib import packetid
+from bitdust.lib import strng
+from bitdust.lib import packetid
 
-from p2p import commands
-from p2p import p2p_service
-from p2p import handshaker
+from bitdust.main import settings
 
-from contacts import identitycache
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import handshaker
 
-from userid import id_url
-from userid import global_id
-from userid import my_id
+from bitdust.contacts import identitycache
+
+from bitdust.userid import id_url
+from bitdust.userid import global_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -78,6 +78,7 @@ _P2PServiceSeekerInstaceCounter = 0
 
 #------------------------------------------------------------------------------
 
+
 class P2PServiceSeeker(automat.Automat):
     """
     This class implements all the functionality of the ``p2p_service_seeker()``
@@ -87,8 +88,7 @@ class P2PServiceSeeker(automat.Automat):
     fast = True
 
     def __repr__(self):
-        return '%s[%s@%s%s%s](%s)' % (self.id, self.target_service or '', self.target_id or '',
-                                      '#' if self.RandomLookup else '!', self.Attempts, self.state)
+        return '%s[%s@%s%s%s](%s)' % (self.id, self.target_service or '', self.target_id or '', '#' if self.RandomLookup else '!', self.Attempts, self.state)
 
     def init(self):
         """
@@ -120,29 +120,29 @@ class P2PServiceSeeker(automat.Automat):
             if event == 'connect-known-user':
                 self.state = 'HANDSHAKE?'
                 self.doInit(*args, **kwargs)
-                self.Attempts=0
-                self.RandomLookup=False
+                self.Attempts = 0
+                self.RandomLookup = False
                 self.doSelectOneUser(*args, **kwargs)
                 self.doHandshake(*args, **kwargs)
             elif event == 'lookup-random-user':
                 self.state = 'RANDOM_USER?'
                 self.doInit(*args, **kwargs)
-                self.Attempts=0
-                self.RandomLookup=True
+                self.Attempts = 0
+                self.RandomLookup = True
                 self.doLookupRandomNode(*args, **kwargs)
         #---RANDOM_USER?---
         elif self.state == 'RANDOM_USER?':
             if event == 'found-users':
                 self.state = 'HANDSHAKE?'
                 self.doSelectOneUser(*args, **kwargs)
-                self.Attempts+=1
+                self.Attempts += 1
                 self.doHandshake(*args, **kwargs)
             elif event == 'users-not-found' and not self.isRetries(*args, **kwargs):
                 self.state = 'FAILED'
                 self.doNotifyLookupFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
             elif event == 'users-not-found' and self.isRetries(*args, **kwargs):
-                self.Attempts+=1
+                self.Attempts += 1
                 self.doLookupRandomNode(*args, **kwargs)
         #---HANDSHAKE?---
         elif self.state == 'HANDSHAKE?':
@@ -152,7 +152,7 @@ class P2PServiceSeeker(automat.Automat):
             elif event == 'fail' and self.isRetries(*args, **kwargs) and self.RandomLookup:
                 self.state = 'RANDOM_USER?'
                 self.doLookupRandomNode(*args, **kwargs)
-            elif ( not self.isRetries(*args, **kwargs) or not self.RandomLookup ) and event == 'fail':
+            elif (not self.isRetries(*args, **kwargs) or not self.RandomLookup) and event == 'fail':
                 self.state = 'FAILED'
                 self.doNotifyHandshakeFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
@@ -162,11 +162,11 @@ class P2PServiceSeeker(automat.Automat):
                 self.state = 'SUCCESS'
                 self.doNotifyServiceAccepted(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'request-timeout' or event == 'fail' or event == 'service-denied' ) and ( not self.RandomLookup or ( not self.isRetries(*args, **kwargs) and self.RandomLookup ) ):
+            elif (event == 'request-timeout' or event == 'fail' or event == 'service-denied') and (not self.RandomLookup or (not self.isRetries(*args, **kwargs) and self.RandomLookup)):
                 self.state = 'FAILED'
                 self.doNotifyServiceRequestFailed(event, *args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'request-timeout' or event == 'fail' or event == 'service-denied' ) and self.isRetries(*args, **kwargs) and self.RandomLookup:
+            elif (event == 'request-timeout' or event == 'fail' or event == 'service-denied') and self.isRetries(*args, **kwargs) and self.RandomLookup:
                 self.state = 'RANDOM_USER?'
                 self.doLookupRandomNode(*args, **kwargs)
         #---SUCCESS---
@@ -205,8 +205,7 @@ class P2PServiceSeeker(automat.Automat):
         self.lookup_task = self.lookup_method()
         if self.lookup_task.result_defer:
             self.lookup_task.result_defer.addCallback(self._nodes_lookup_finished)
-            if _Debug:
-                self.lookup_task.result_defer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='p2p_service_seeker.doLookupRandomNode')
+            self.lookup_task.result_defer.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='p2p_service_seeker.doLookupRandomNode')
             self.lookup_task.result_defer.addErrback(lambda err: self.automat('users-not-found'))
         else:
             self.automat('users-not-found')
@@ -234,12 +233,11 @@ class P2PServiceSeeker(automat.Automat):
             keep_alive=True,
             force_cache=False,
             ping_retries=(1 if self.ping_retries is None else self.ping_retries),
-            ack_timeout=(15 if self.ack_timeout is None else self.ack_timeout),
+            ack_timeout=(settings.P2PTimeOut() if self.ack_timeout is None else self.ack_timeout),
             cancel_running=self.force_handshake,
         )
         d.addCallback(lambda ok: self.automat('shook-hands'))
-        if _Debug:
-            d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='p2p_service_seeker.doHandshake')
+        d.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='p2p_service_seeker.doHandshake')
         d.addErrback(lambda err: self.automat('fail', reason='handshake-failed'))
 
     def doSendRequestService(self, *args, **kwargs):
@@ -272,8 +270,7 @@ class P2PServiceSeeker(automat.Automat):
         Action method.
         """
         if _Debug:
-            lg.out(_DebugLevel, 'p2p_service_seeker.doNotifyServiceAccepted %r from %r with %s' % (
-                self.target_service, self.target_id, args[0]))
+            lg.out(_DebugLevel, 'p2p_service_seeker.doNotifyServiceAccepted %r from %r with %s' % (self.target_service, self.target_id, args[0]))
         if self.result_callback:
             self.result_callback('node-connected', *args, **kwargs)
         self.result_callback = None
@@ -334,16 +331,33 @@ class P2PServiceSeeker(automat.Automat):
         if not strng.to_text(response.Payload).startswith('accepted'):
             if _Debug:
                 lg.out(_DebugLevel, 'p2p_service_seeker._node_acked with "service denied" response: %r %r' % (response, info))
-            self.automat('service-denied', (response, info, ), reason='service-denied')
+            self.automat(
+                'service-denied',
+                (
+                    response,
+                    info,
+                ),
+                reason='service-denied',
+            )
             return
         if _Debug:
             lg.out(_DebugLevel, 'p2p_service_seeker._node_acked %s is connected' % response.CreatorID)
-        self.automat('service-accepted', (response, info, ))
+        self.automat('service-accepted', (
+            response,
+            info,
+        ))
 
     def _node_failed(self, response, info):
         if _Debug:
             lg.out(_DebugLevel, 'p2p_service_seeker._node_failed %r %r' % (response, info))
-        self.automat('service-denied', (response, info, ), reason='service-denied')
+        self.automat(
+            'service-denied',
+            (
+                response,
+                info,
+            ),
+            reason='service-denied',
+        )
 
     def _node_timed_out(self, pkt_out):
         if _Debug:
@@ -369,8 +383,10 @@ class P2PServiceSeeker(automat.Automat):
         else:
             self.automat('users-not-found')
 
+
 #------------------------------------------------------------------------------
 
+
 def on_lookup_result(event, result_defer, *args, **kwargs):
     if _Debug:
         lg.args(_DebugLevel, event=event, args=args, kwargs=kwargs)
@@ -379,10 +395,11 @@ def on_lookup_result(event, result_defer, *args, **kwargs):
     else:
         result_defer.errback(Exception(event, args, kwargs))
 
+
 #------------------------------------------------------------------------------
 
-def connect_random_node(lookup_method, service_name, service_params=None, exclude_nodes=[], attempts=5,
-                        request_service_timeout=None, ping_retries=None, ack_timeout=None, force_handshake=False):
+
+def connect_random_node(lookup_method, service_name, service_params=None, exclude_nodes=[], attempts=5, request_service_timeout=None, ping_retries=None, ack_timeout=None, force_handshake=False):
     global _P2PServiceSeekerInstaceCounter
     _P2PServiceSeekerInstaceCounter += 1
     result = Deferred()
@@ -412,8 +429,7 @@ def connect_random_node(lookup_method, service_name, service_params=None, exclud
     return result
 
 
-def connect_known_node(remote_idurl, service_name, service_params=None, exclude_nodes=[], attempts=2,
-                       request_service_timeout=None, ping_retries=None, ack_timeout=None, force_handshake=False):
+def connect_known_node(remote_idurl, service_name, service_params=None, exclude_nodes=[], attempts=2, request_service_timeout=None, ping_retries=None, ack_timeout=None, force_handshake=False):
     global _P2PServiceSeekerInstaceCounter
     _P2PServiceSeekerInstaceCounter += 1
     result = Deferred()
