@@ -24,7 +24,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -33,7 +32,7 @@ module:: p2p_stats
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
@@ -81,8 +80,10 @@ def counters_out():
     global _CountersOut
     return _CountersOut
 
+
 #------------------------------------------------------------------------------
 
+
 def get_total_bytes_in():
     return counters_in()['total_bytes']
 
@@ -90,6 +91,7 @@ def get_total_bytes_in():
 def get_total_bytes_out():
     return counters_out()['total_bytes']
 
+
 #------------------------------------------------------------------------------
 
 
@@ -105,12 +107,13 @@ def EraseAllMyProtosStates():
 def EraseMyProtosStates(idurl):
     my_protos().pop(idurl, None)
 
+
 #------------------------------------------------------------------------------
 
 
 def count_outbox(remote_idurl, proto, status, size):
     """
-    
+
     """
     remote_idurl = strng.to_text(remote_idurl)
     proto = strng.to_text(proto)
