@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: propagate.
 
@@ -63,28 +62,30 @@ from twisted.internet.defer import DeferredList, Deferred
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import nameurl
-from lib import net_misc
-from lib import strng
-from lib import packetid
+from bitdust.lib import nameurl
+from bitdust.lib import net_misc
+from bitdust.lib import strng
+from bitdust.lib import packetid
 
-from contacts import contactsdb
-from contacts import identitycache
+from bitdust.contacts import contactsdb
+from bitdust.contacts import identitycache
 
-from userid import my_id
-from userid import id_url
+from bitdust.main import settings
 
-from p2p import commands
-from p2p import p2p_stats
+from bitdust.userid import my_id
+from bitdust.userid import id_url
 
-from crypt import signed
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_stats
 
-from transport import gateway
-from transport import packet_out
+from bitdust.crypt import signed
 
-from dht import dht_records
+from bitdust.transport import gateway
+from bitdust.transport import packet_out
+
+from bitdust.dht import dht_records
 
 #------------------------------------------------------------------------------
 
@@ -100,30 +101,34 @@ def init():
     Need to call that at start up to link with transport_control.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.init")
+        lg.out(_DebugLevel, 'propagate.init')
     # callback.add_finish_file_sending_callback(OnFileSent)
 
 
 def shutdown():
     if _Debug:
-        lg.out(_DebugLevel, "propagate.shutdown")
+        lg.out(_DebugLevel, 'propagate.shutdown')
 
 
 def startup_list():
     global _StartupPropagateList
     return _StartupPropagateList
 
+
 #------------------------------------------------------------------------------
 
-def propagate(selected_contacts, ack_handler=None, wide=False, refresh_cache=False, wait_packets=False, response_timeout=10):
+
+def propagate(selected_contacts, ack_handler=None, wide=False, refresh_cache=False, wait_packets=False, response_timeout=None):
     """
     Run the "propagate" process.
 
     First need to fetch ``selected_contacts`` IDs from id servers. And
     then send our Identity file to that contacts.
     """
+    if response_timeout is None:
+        response_timeout = settings.P2PTimeOut()
     if _Debug:
-        lg.out(_DebugLevel, "propagate.propagate to %d contacts" % len(selected_contacts))
+        lg.out(_DebugLevel, 'propagate.propagate to %d contacts' % len(selected_contacts))
     result = Deferred()
 
     def contacts_fetched(x):
@@ -135,8 +140,7 @@ def propagate(selected_contacts, ack_handler=None, wide=False, refresh_cache=Fal
             response_timeout=response_timeout,
         )
         if _Debug:
-            lg.out(_DebugLevel, "propagate.contacts_fetched with %d identities, sending my identity to %d remote nodes: %r" % (
-                len(x), len(selected_contacts), res, ))
+            lg.out(_DebugLevel, 'propagate.contacts_fetched with %d identities, sending my identity to %d remote nodes: %r' % (len(x), len(selected_contacts), res))
         if wait_packets:
             if not res:
                 result.callback([])
@@ -151,12 +155,12 @@ def propagate(selected_contacts, ack_handler=None, wide=False, refresh_cache=Fal
     return result
 
 
-def fetch(list_ids, refresh_cache=False, timeout=10, try_other_sources=True):
+def fetch(list_ids, refresh_cache=False, timeout=15, try_other_sources=True):
     """
     Request a list of identity files.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.fetch %d identities" % len(list_ids))
+        lg.out(_DebugLevel, 'propagate.fetch %d identities' % len(list_ids))
     dl = []
     for url in list_ids:
         if not url:
@@ -171,10 +175,12 @@ def fetch(list_ids, refresh_cache=False, timeout=10, try_other_sources=True):
     return DeferredList(dl, consumeErrors=True)
 
 
-def start(ack_handler=None, wide=False, refresh_cache=False, include_all=True, include_enabled=True, include_startup=False, wait_packets=False, response_timeout=10):
+def start(ack_handler=None, wide=False, refresh_cache=False, include_all=True, include_enabled=True, include_startup=False, wait_packets=False, response_timeout=None):
     """
     Call ``propagate()`` for all known contacts or only for those which are related to enabled/active services.
     """
+    if response_timeout is None:
+        response_timeout = settings.P2PTimeOut()
     selected_contacts = set(filter(None, contactsdb.contacts_remote(include_all=include_all, include_enabled=include_enabled)))
     if include_startup and startup_list():
         lg.warn('going to propagate my identity also to %d nodes from startup list' % len(startup_list()))
@@ -225,7 +231,13 @@ def single(idurl, ack_handler=None, wide=False, fail_handler=None):
     Do "propagate" for a single contact.
     """
     d = FetchSingle(idurl)
-    d.addCallback(lambda x: SendToIDs([idurl, ], ack_handler=ack_handler, wide=wide))
+    d.addCallback(lambda x: SendToIDs(
+        [
+            idurl,
+        ],
+        ack_handler=ack_handler,
+        wide=wide,
+    ))
     if ack_handler:
         d.addErrback(fail_handler or ack_handler)
     return d
@@ -236,7 +248,7 @@ def update():
     A wrapper of ``SendServers()`` method.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.update")
+        lg.out(_DebugLevel, 'propagate.update')
     return SendServers()
 
 
@@ -245,13 +257,14 @@ def write_to_dht():
 
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.write_to_dht")
+        lg.out(_DebugLevel, 'propagate.write_to_dht')
     LocalIdentity = my_id.getLocalIdentity()
     return dht_records.set_identity(
         LocalIdentity.getIDURL(),
         LocalIdentity.serialize(as_text=True),
     )
 
+
 #------------------------------------------------------------------------------
 
 
@@ -260,7 +273,7 @@ def FetchSingle(idurl):
     Fetch single identity file from given ``idurl``.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.fetch_single " + idurl)
+        lg.out(_DebugLevel, 'propagate.fetch_single ' + idurl)
     return identitycache.scheduleForCaching(idurl)
 
 
@@ -284,8 +297,10 @@ def FetchCustomers():
     """
     return fetch(contactsdb.customers())
 
+
 #------------------------------------------------------------------------------
 
+
 def SendServers():
     """
     My identity file can be stored in different locations, see the "sources" field.
@@ -297,7 +312,13 @@ def SendServers():
     dlist = []
     for idurl in LocalIdentity.getSources(as_originals=True):
         _, host, webport, filename = nameurl.UrlParse(idurl)
-        url = net_misc.pack_address((host, webport, ), proto='http')
+        url = net_misc.pack_address(
+            (
+                host,
+                webport,
+            ),
+            proto='http',
+        )
         dlist.append(net_misc.http_post_data(
             url=url,
             data=payload,
@@ -314,7 +335,7 @@ def SendSuppliers(customer_idurl=None):
     Send my identity file to all my suppliers, calls to ``SendToIDs()`` method.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SendSuppliers")
+        lg.out(_DebugLevel, 'propagate.SendSuppliers')
     SendToIDs(contactsdb.suppliers(customer_idurl=customer_idurl), ack_handler=HandleSuppliersAck, wide=True)
 
 
@@ -323,7 +344,7 @@ def SendCustomers():
     Calls ``SendToIDs()`` to send identity to all my customers.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SendCustomers")
+        lg.out(_DebugLevel, 'propagate.SendCustomers')
     SendToIDs(contactsdb.customers(), ack_handler=HandleCustomersAck, wide=True)
 
 
@@ -336,10 +357,10 @@ def SlowSendSuppliers(delay=1, customer_idurl=None):
     global _SlowSendIsWorking
     if _SlowSendIsWorking:
         if _Debug:
-            lg.out(_DebugLevel, "propagate.SlowSendSuppliers  is working at the moment. skip.")
+            lg.out(_DebugLevel, 'propagate.SlowSendSuppliers  is working at the moment. skip.')
         return
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SlowSendSuppliers delay=%s" % str(delay))
+        lg.out(_DebugLevel, 'propagate.SlowSendSuppliers delay=%s' % str(delay))
 
     def _send(index, payload, delay):
         global _SlowSendIsWorking
@@ -364,10 +385,10 @@ def SlowSendCustomers(delay=1):
     global _SlowSendIsWorking
     if _SlowSendIsWorking:
         if _Debug:
-            lg.out(_DebugLevel, "propagate.SlowSendCustomers  slow send is working at the moment. skip.")
+            lg.out(_DebugLevel, 'propagate.SlowSendCustomers  slow send is working at the moment. skip.')
         return
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SlowSendCustomers delay=%s" % str(delay))
+        lg.out(_DebugLevel, 'propagate.SlowSendCustomers delay=%s' % str(delay))
 
     def _send(index, payload, delay):
         global _SlowSendIsWorking
@@ -389,7 +410,7 @@ def HandleSuppliersAck(ackpacket, info):
     Called when supplier is "Acked" to my after call to ``SendSuppliers()``.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.HandleSupplierAck %s" % ackpacket.OwnerID)
+        lg.out(_DebugLevel, 'propagate.HandleSupplierAck %s' % ackpacket.OwnerID)
 
 
 def HandleCustomersAck(ackpacket, info):
@@ -397,31 +418,40 @@ def HandleCustomersAck(ackpacket, info):
     Called when supplier is "Acked" to my after call to ``SendCustomers()``.
     """
     if _Debug:
-        lg.out(_DebugLevel, "propagate.HandleCustomerAck %s" % ackpacket.OwnerID)
+        lg.out(_DebugLevel, 'propagate.HandleCustomerAck %s' % ackpacket.OwnerID)
 
 
 def HandleAck(ackpacket, info):
     if _Debug:
-        lg.out(_DebugLevel, "propagate.HandleAck %r %r" % (ackpacket, info))
+        lg.out(_DebugLevel, 'propagate.HandleAck %r %r' % (ackpacket, info))
 
 
 def HandleTimeOut(pkt_out):
     if _Debug:
-        lg.out(_DebugLevel, "propagate.HandleTimeOut %r" % pkt_out)
+        lg.out(_DebugLevel, 'propagate.HandleTimeOut %r' % pkt_out)
 
 
 def OnFileSent(pkt_out, item, status, size, error_message):
     return False
 
 
-def SendToID(idurl, Payload=None, wide=False, ack_handler=None, timeout_handler=None, response_timeout=20, ):
+def SendToID(
+    idurl,
+    Payload=None,
+    wide=False,
+    ack_handler=None,
+    timeout_handler=None,
+    response_timeout=None,
+):
     """
     Create ``packet`` with my Identity file and calls
     ``transport.gateway.outbox()`` to send it.
     """
     global _PropagateCounter
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SendToID [%s] wide=%s" % (nameurl.GetName(idurl), str(wide)))
+        lg.out(_DebugLevel, 'propagate.SendToID [%s] wide=%s' % (nameurl.GetName(idurl), str(wide)))
+    if response_timeout is None:
+        response_timeout = settings.P2PTimeOut()
     if ack_handler is None:
         ack_handler = HandleAck
     if timeout_handler is None:
@@ -438,11 +468,16 @@ def SendToID(idurl, Payload=None, wide=False, ack_handler=None, timeout_handler=
         RemoteID=idurl,
     )
     _PropagateCounter += 1
-    result = gateway.outbox(p, wide, response_timeout=response_timeout, callbacks={
-        commands.Ack(): ack_handler,
-        commands.Fail(): ack_handler,
-        None: timeout_handler,
-    })
+    result = gateway.outbox(
+        p,
+        wide,
+        response_timeout=response_timeout,
+        callbacks={
+            commands.Ack(): ack_handler,
+            commands.Fail(): ack_handler,
+            None: timeout_handler,
+        },
+    )
     if wide:
         # this is a ping packet - need to clear old info
         p2p_stats.ErasePeerProtosStates(idurl)
@@ -450,11 +485,13 @@ def SendToID(idurl, Payload=None, wide=False, ack_handler=None, timeout_handler=
     return result
 
 
-def SendToIDs(idlist, wide=False, ack_handler=None, timeout_handler=None, response_timeout=20, wait_packets=False):
+def SendToIDs(idlist, wide=False, ack_handler=None, timeout_handler=None, response_timeout=None, wait_packets=False):
     """
     Same, but send to many IDs and also check previous packets to not re-send.
     """
     global _PropagateCounter
+    if response_timeout is None:
+        response_timeout = settings.P2PTimeOut()
     if ack_handler is None:
         ack_handler = HandleAck
     if timeout_handler is None:
@@ -462,7 +499,7 @@ def SendToIDs(idlist, wide=False, ack_handler=None, timeout_handler=None, respon
     LocalIdentity = my_id.getLocalIdentity()
     Payload = strng.to_bin(LocalIdentity.serialize())
     if _Debug:
-        lg.out(_DebugLevel, "propagate.SendToIDs to %d users, rev=%r wide=%s" % (len(idlist), LocalIdentity.getRevisionValue(), wide))
+        lg.out(_DebugLevel, 'propagate.SendToIDs to %d users, rev=%r wide=%s' % (len(idlist), LocalIdentity.getRevisionValue(), wide))
     alreadysent = set()
     totalsent = 0
     inqueue = {}
@@ -496,12 +533,17 @@ def SendToIDs(idlist, wide=False, ack_handler=None, timeout_handler=None, respon
         )
         _PropagateCounter += 1
         if _Debug:
-            lg.out(_DebugLevel, "        sending %r to %s" % (p, nameurl.GetName(contact), ))
-        res = gateway.outbox(p, wide, response_timeout=response_timeout, callbacks={
-            commands.Ack(): ack_handler,
-            commands.Fail(): ack_handler,
-            None: timeout_handler,
-        })
+            lg.out(_DebugLevel, '        sending %r to %s' % (p, nameurl.GetName(contact)))
+        res = gateway.outbox(
+            p,
+            wide,
+            response_timeout=response_timeout,
+            callbacks={
+                commands.Ack(): ack_handler,
+                commands.Fail(): ack_handler,
+                None: timeout_handler,
+            },
+        )
         if not res:
             lg.warn('my Identity() was not sent to %r' % contact)
             continue
@@ -521,10 +563,14 @@ def SendToIDs(idlist, wide=False, ack_handler=None, timeout_handler=None, respon
         return totalsent
     return DeferredList(wait_list, consumeErrors=True)
 
+
 #------------------------------------------------------------------------------
 
-def ping_suppliers(customer_idurl=None, timeout=20):
-    from p2p import online_status
+
+def ping_suppliers(customer_idurl=None, timeout=None):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
+    from bitdust.p2p import online_status
     l = []
     for supplier_idurl in contactsdb.suppliers(customer_idurl=customer_idurl):
         if supplier_idurl:
@@ -532,8 +578,10 @@ def ping_suppliers(customer_idurl=None, timeout=20):
     return DeferredList(l, consumeErrors=True)
 
 
-def ping_customers(timeout=20):
-    from p2p import online_status
+def ping_customers(timeout=None):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
+    from bitdust.p2p import online_status
     l = []
     for customer_idurl in contactsdb.customers():
         if customer_idurl:
@@ -541,8 +589,10 @@ def ping_customers(timeout=20):
     return DeferredList(l, consumeErrors=True)
 
 
-def ping_nodes(idurl_list, timeout=15, channel='ping_nodes', keep_alive=True):
-    from p2p import online_status
+def ping_nodes(idurl_list, timeout=None, channel='ping_nodes', keep_alive=True):
+    if timeout is None:
+        timeout = settings.P2PTimeOut()
+    from bitdust.p2p import online_status
     l = []
     for idurl in idurl_list:
         if idurl:
