@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: raid_worker.
 
@@ -81,25 +80,25 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from system import bpio
+from bitdust.system import bpio
 
-from raid import read
-from raid import make
-from raid import rebuild
+from bitdust.raid import read
+from bitdust.raid import make
+from bitdust.raid import rebuild
 
 #------------------------------------------------------------------------------
 
 _MODULES = (
-    'raid.read',
-    'raid.make',
-    'raid.rebuild',
-    'raid.eccmap',
-    'raid.raidutils',
-    'logs.lg',
+    'bitdust.raid.read',
+    'bitdust.raid.make',
+    'bitdust.raid.rebuild',
+    'bitdust.raid.eccmap',
+    'bitdust.raid.raidutils',
+    'bitdust.logs.lg',
     'os',
     'sys',
     'copy',
@@ -110,8 +109,22 @@ _MODULES = (
 )
 
 _VALID_TASKS = {
-    'make': (make.do_in_memory, (make.RoundupFile, make.ReadBinaryFile, make.WriteFile, make.ReadBinaryFileAsArray, )),
-    'read': (read.raidread, (read.RebuildOne, read.ReadBinaryFile, )),
+    'make': (
+        make.do_in_memory,
+        (
+            make.RoundupFile,
+            make.ReadBinaryFile,
+            make.WriteFile,
+            make.ReadBinaryFileAsArray,
+        ),
+    ),
+    'read': (
+        read.raidread,
+        (
+            read.RebuildOne,
+            read.ReadBinaryFile,
+        ),
+    ),
     'rebuild': (rebuild.rebuild, ()),
 }
 
@@ -158,6 +171,7 @@ def cancel_task(cmd, first_parameter):
         return False
     return True
 
+
 #------------------------------------------------------------------------------
 
 
@@ -294,16 +308,20 @@ class RaidWorker(automat.Automat):
         """
         Action method.
         """
-        ncpus = bpio.detect_number_of_cpu_cores()
-        if ncpus > 1:
-            # do not use all CPU cors at once
-            # need to keep at least one for all other operations
-            # even decided to use only half of CPUs at the moment
-            # TODO: make an option in the software settings
-            ncpus = int(ncpus / 2.0)
-
         self.processor = ThreadedRaidProcessor()
 
+        # TODO: possible improvement in the future
+        # On Android it is not possible to run a separate sub-process: the only possible way is to use threads
+        # but on Windows and Linux we can use parallelp or multiprocessing libraries to utilize other CPU cores and
+        # gain more performance
+
+        # we do not want to use all CPU cores at once
+        # need to keep at least one for all other operations
+        # decided to use only half of CPUs at the moment
+        # TODO: make an option in the software settings
+        # ncpus = bpio.detect_number_of_cpu_cores()
+        # if ncpus > 1:
+        #     ncpus = int(ncpus/2.0)
         # if bpio.Android() or not config.conf().getBool('services/rebuilding/child-processes-enabled'):
         #     self.processor = ThreadedRaidProcessor()
         # else:
@@ -316,7 +334,7 @@ class RaidWorker(automat.Automat):
         #         logfile=settings.ParallelPLogFilename(),
         #     )
         # else:
-        #     from raid import worker
+        #     from bitdust.raid import worker
         #     self.processor = worker.Manager(ncpus=ncpus)
 
         self.automat('process-started')
@@ -362,14 +380,12 @@ class RaidWorker(automat.Automat):
             args=params,
             depfuncs=depfuncs,
             modules=_MODULES,
-            callback=lambda result: self._job_done(task_id, cmd, params, result),
-            # error_callback=lambda err: self._job_failed(task_id, cmd, params, err),
+            callback=lambda result: self._job_done(task_id, cmd, params, result),  # error_callback=lambda err: self._job_failed(task_id, cmd, params, err),
         )
 
         self.activetasks[task_id] = (proc, cmd, params)
         if _Debug:
-            lg.out(_DebugLevel, 'raid_worker.doStartTask job_id=%r active=%d cpus=%d %s' % (
-                task_id, len(self.activetasks), self.processor.get_ncpus(), threading.currentThread().getName()))
+            lg.out(_DebugLevel, 'raid_worker.doStartTask job_id=%r active=%d cpus=%d %s' % (task_id, len(self.activetasks), self.processor.get_ncpus(), threading.currentThread().getName()))
 
         # reactor.callLater(0, self.automat, 'task-started', task_id)  # @UndefinedVariable
         self.automat('task-started', task_id)
@@ -383,12 +399,10 @@ class RaidWorker(automat.Automat):
         reactor.callLater(0, cb, cmd, params, result)  # @UndefinedVariable
         if result is not None:
             if _Debug:
-                lg.out(_DebugLevel, 'raid_worker.doReportTaskDone callbacks: %d tasks: %d active: %d' % (
-                    len(self.callbacks), len(self.tasks), len(self.activetasks)))
+                lg.out(_DebugLevel, 'raid_worker.doReportTaskDone callbacks: %d tasks: %d active: %d' % (len(self.callbacks), len(self.tasks), len(self.activetasks)))
         else:
             if _Debug:
-                lg.out(_DebugLevel, 'raid_worker.doReportTaskDone result=None !!!!! callbacks: %d tasks: %d active: %d' % (
-                    len(self.callbacks), len(self.tasks), len(self.activetasks)))
+                lg.out(_DebugLevel, 'raid_worker.doReportTaskDone result=None !!!!! callbacks: %d tasks: %d active: %d' % (len(self.callbacks), len(self.tasks), len(self.activetasks)))
 
     def doReportTasksFailed(self, *args, **kwargs):
         """
@@ -414,8 +428,7 @@ class RaidWorker(automat.Automat):
 
     def _job_done(self, task_id, cmd, params, result):
         if _Debug:
-            lg.out(_DebugLevel, 'raid_worker._job_done %r : %r active:%r cmd=%r params=%r %s' % (
-                task_id, result, list(self.activetasks.keys()), cmd, params, threading.currentThread().getName()))
+            lg.out(_DebugLevel, 'raid_worker._job_done %r : %r active:%r cmd=%r params=%r %s' % (task_id, result, list(self.activetasks.keys()), cmd, params, threading.currentThread().getName()))
         reactor.callFromThread(self.automat, 'task-done', (task_id, cmd, params, result))  # @UndefinedVariable
 
     # def _job_failed(self, task_id, cmd, params, err):
@@ -432,8 +445,8 @@ class RaidWorker(automat.Automat):
 
 #------------------------------------------------------------------------------
 
-class RaidTask(object):
 
+class RaidTask(object):
     def __init__(self, task_id, worker_method, worker_args=None, on_success=None, on_fail=None):
         self.task_id = task_id
         self.result = None
@@ -472,18 +485,19 @@ class RaidTask(object):
     def stop(self):
         self._stopped = True
 
+
 #------------------------------------------------------------------------------
 
-class RaidTaskInfo(object):
 
+class RaidTaskInfo(object):
     def __init__(self, task_id):
         self.tid = task_id
 
 
 #------------------------------------------------------------------------------
 
-class ThreadedRaidProcessor(object):
 
+class ThreadedRaidProcessor(object):
     def __init__(self):
         self.latest_task_id = 0
         self.tasks = {}
@@ -547,8 +561,10 @@ class ThreadedRaidProcessor(object):
         reactor.callLater(0, self.process)  # @UndefinedVariable
         return RaidTaskInfo(task_id)
 
+
 #------------------------------------------------------------------------------
 
+
 def _read_done(cmd, taskdata, result):
     lg.out(0, '_read_done %r %r %r' % (cmd, taskdata, result))
     A('shutdown')
@@ -575,5 +591,6 @@ def main():
 
     reactor.run()  # @UndefinedVariable
 
-if __name__ == "__main__":
+
+if __name__ == '__main__':
     main()
