@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_data_motion
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -49,25 +48,25 @@ class DataMotionService(LocalService):
         ]
 
     def init(self, **kwargs):
-        from main import events
+        from bitdust.main import events
         events.add_subscriber(self._on_my_suppliers_all_hired, 'my-suppliers-all-hired')
         events.add_subscriber(self._on_my_suppliers_yet_not_hired, 'my-suppliers-yet-not-hired')
 
     def shutdown(self):
-        from main import events
+        from bitdust.main import events
         events.remove_subscriber(self._on_my_suppliers_yet_not_hired, 'my-suppliers-yet-not-hired')
         events.remove_subscriber(self._on_my_suppliers_all_hired, 'my-suppliers-all-hired')
 
     def start(self):
-        from logs import lg
-        from customer import fire_hire
+        from bitdust.logs import lg
+        from bitdust.customer import fire_hire
         if not fire_hire.IsAllHired():
             lg.warn('service_data_motion() can not start right now, not all suppliers hired yet')
             return False
-        from main import events
-        from stream import io_throttle
-        from stream import data_sender
-        from stream import data_receiver
+        from bitdust.main import events
+        from bitdust.stream import io_throttle
+        from bitdust.stream import data_sender
+        from bitdust.stream import data_receiver
         io_throttle.init()
         data_sender.SetShutdownFlag(False)
         data_sender.A('init')
@@ -77,10 +76,10 @@ class DataMotionService(LocalService):
         return True
 
     def stop(self):
-        from main import events
-        from stream import io_throttle
-        from stream import data_sender
-        from stream import data_receiver
+        from bitdust.main import events
+        from bitdust.stream import io_throttle
+        from bitdust.stream import data_sender
+        from bitdust.stream import data_receiver
         events.remove_subscriber(self._on_supplier_modified, 'supplier-modified')
         events.remove_subscriber(self._on_identity_url_changed, 'identity-url-changed')
         data_receiver.A('shutdown')
@@ -93,38 +92,36 @@ class DataMotionService(LocalService):
         return True
 
     def _on_my_suppliers_all_hired(self, evt):
-        from logs import lg
-        from services import driver
+        from bitdust.logs import lg
+        from bitdust.services import driver
         if driver.is_enabled('service_data_motion'):
             if not driver.is_started('service_data_motion'):
-                from customer import fire_hire
+                from bitdust.customer import fire_hire
                 if fire_hire.IsAllHired():
                     lg.info('all my suppliers are hired, starting service_data_motion()')
                     driver.start_single('service_data_motion')
 
     def _on_my_suppliers_yet_not_hired(self, evt):
-        from logs import lg
-        from services import driver
+        from bitdust.logs import lg
+        from bitdust.services import driver
         if driver.is_enabled('service_data_motion'):
             if driver.is_started('service_data_motion'):
                 lg.info('my suppliers failed to hire, stopping service_data_motion()')
                 driver.stop_single('service_data_motion')
 
     def _on_identity_url_changed(self, evt):
-        from logs import lg
-        from userid import id_url
-        from stream import io_throttle
+        from bitdust.logs import lg
+        from bitdust.userid import id_url
+        from bitdust.stream import io_throttle
         old_idurl = id_url.field(evt.data['old_idurl'])
         for supplier_idurl, supplier_queue in io_throttle.throttle().supplierQueues.items():
             if old_idurl == supplier_idurl:
                 supplier_idurl.refresh()
-                lg.info('found supplier idurl rotated in io_throttle: %r -> %r' % (
-                    evt.data['old_idurl'], evt.data['new_idurl'], ))
+                lg.info('found supplier idurl rotated in io_throttle: %r -> %r' % (evt.data['old_idurl'], evt.data['new_idurl']))
             if old_idurl == supplier_queue.customerIDURL:
                 supplier_queue.customerIDURL.refresh()
-                lg.info('found customer idurl rotated in io_throttle %r supplier queue: %r -> %r' % (
-                    supplier_idurl, evt.data['old_idurl'], evt.data['new_idurl'], ))
+                lg.info('found customer idurl rotated in io_throttle %r supplier queue: %r -> %r' % (supplier_idurl, evt.data['old_idurl'], evt.data['new_idurl']))
 
     def _on_supplier_modified(self, evt):
-        from stream import data_sender
+        from bitdust.stream import data_sender
         data_sender.A('restart')
