@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 ..
 
@@ -31,7 +30,7 @@ module:: service_keys_storage
 """
 
 from __future__ import absolute_import
-from services.local_service import LocalService
+from bitdust.services.local_service import LocalService
 
 
 def create_service():
@@ -53,14 +52,13 @@ class KeysStorageService(LocalService):
 
     def start(self):
         from twisted.internet.defer import Deferred
-        from logs import lg
-        from main import events
-        from storage import index_synchronizer
-        from storage import keys_synchronizer
+        from bitdust.logs import lg
+        from bitdust.main import events
+        from bitdust.storage import index_synchronizer
+        from bitdust.storage import keys_synchronizer
         keys_synchronizer.A('init')
         self.starting_deferred = Deferred()
-        self.starting_deferred.addErrback(lambda err: lg.warn('service %r was not started: %r' % (
-            self.service_name, err.getErrorMessage() if err else 'unknown reason')))
+        self.starting_deferred.addErrback(lambda err: lg.warn('service %r was not started: %r' % (self.service_name, err.getErrorMessage() if err else 'unknown reason')))
         events.add_subscriber(self._on_identity_url_changed, 'identity-url-changed')
         events.add_subscriber(self._on_key_generated, 'key-generated')
         events.add_subscriber(self._on_key_registered, 'key-registered')
@@ -80,9 +78,9 @@ class KeysStorageService(LocalService):
         return self.starting_deferred
 
     def stop(self):
-        from main import events
-        from storage import index_synchronizer
-        from storage import keys_synchronizer
+        from bitdust.main import events
+        from bitdust.storage import index_synchronizer
+        from bitdust.storage import keys_synchronizer
         if index_synchronizer.A():
             index_synchronizer.A().removeStateChangedCallback(self._on_index_synchronizer_state_changed)
         events.remove_subscriber(self._on_my_keys_synchronize_failed, 'my-keys-synchronize-failed')
@@ -97,8 +95,8 @@ class KeysStorageService(LocalService):
         return True
 
     def health_check(self):
-        from storage import index_synchronizer
-        from storage import keys_synchronizer
+        from bitdust.storage import index_synchronizer
+        from bitdust.storage import keys_synchronizer
         return keys_synchronizer.is_synchronized() and index_synchronizer.is_synchronized()
 
     def _do_synchronize_keys(self):
@@ -106,10 +104,10 @@ class KeysStorageService(LocalService):
         Make sure all my keys are stored on my suppliers nodes (encrypted with my master key).
         If some key I do not have locally, but I know remote copy exists - download it.
         If some key was not stored - make a remote copy on supplier machine.
-        When key was renamed (after identity rotate) make sure to store the latest copy and remove older one. 
+        When key was renamed (after identity rotate) make sure to store the latest copy and remove older one.
         """
-        from logs import lg
-        from storage import index_synchronizer
+        from bitdust.logs import lg
+        from bitdust.storage import index_synchronizer
         from twisted.internet.defer import Deferred
         is_in_sync = index_synchronizer.is_synchronized()
         if is_in_sync:
@@ -129,14 +127,13 @@ class KeysStorageService(LocalService):
         return None
 
     def _do_check_sync_keys(self, result):
-        from logs import lg
-        from interface import api
-        from storage import keys_synchronizer
-        from userid import global_id
-        from userid import my_id
+        from bitdust.logs import lg
+        from bitdust.interface import api
+        from bitdust.storage import keys_synchronizer
+        from bitdust.userid import global_id
+        from bitdust.userid import my_id
         self.sync_keys_requested = False
-        global_keys_folder_path = global_id.MakeGlobalID(
-            key_alias='master', customer=my_id.getGlobalID(), path='.keys')
+        global_keys_folder_path = global_id.MakeGlobalID(key_alias='master', customer=my_id.getGlobalID(), path='.keys')
         res = api.file_exists(global_keys_folder_path)
         if res['status'] != 'OK' or not res['result'] or not res['result'].get('exist'):
             res = api.file_create(global_keys_folder_path, as_folder=True)
@@ -154,9 +151,9 @@ class KeysStorageService(LocalService):
         self._do_synchronize_keys()
 
     def _on_key_erased(self, evt):
-        from interface import api
-        from userid import global_id
-        from userid import my_id
+        from bitdust.interface import api
+        from bitdust.userid import global_id
+        from bitdust.userid import my_id
         if evt.data['is_private']:
             remote_path_for_key = '.keys/%s.private' % evt.data['key_id']
         else:
@@ -171,27 +168,27 @@ class KeysStorageService(LocalService):
 
     def _on_my_backup_index_synchronized(self, evt):
         import time
-        from logs import lg
+        from bitdust.logs import lg
         if self.starting_deferred:
             self._do_synchronize_keys()
             return
         if not self.last_time_keys_synchronized:
             self._do_synchronize_keys()
             return
-        from storage import keys_synchronizer
+        from bitdust.storage import keys_synchronizer
         if not keys_synchronizer.is_synchronized():
             self._do_synchronize_keys()
             return
-        if time.time() - self.last_time_keys_synchronized > 5 * 60:
+        if time.time() - self.last_time_keys_synchronized > 5*60:
             self._do_synchronize_keys()
             return
-        from main import events
+        from bitdust.main import events
         lg.info('backup index and all my keys synchronized')
         events.send('my-storage-ready', data=dict())
 
     def _on_my_backup_index_out_of_sync(self, evt):
-        from logs import lg
-        from main import events
+        from bitdust.logs import lg
+        from bitdust.main import events
         if self.starting_deferred:
             self.starting_deferred.errback(Exception('not possible to synchronize keys because backup index is out of sync'))
             self.starting_deferred = None
@@ -200,8 +197,8 @@ class KeysStorageService(LocalService):
 
     def _on_keys_synchronized(self, x):
         import time
-        from logs import lg
-        from main import events
+        from bitdust.logs import lg
+        from bitdust.main import events
         self.last_time_keys_synchronized = time.time()
         if self.starting_deferred:
             self.starting_deferred.callback(True)
@@ -212,8 +209,8 @@ class KeysStorageService(LocalService):
         return None
 
     def _on_keys_synchronize_failed(self, err=None):
-        from logs import lg
-        from main import events
+        from bitdust.logs import lg
+        from bitdust.main import events
         if self.starting_deferred:
             self.starting_deferred.errback(err)
             self.starting_deferred = None
@@ -223,16 +220,19 @@ class KeysStorageService(LocalService):
         return None
 
     def _on_identity_url_changed(self, evt):
-        from crypt import my_keys
-        from storage import backup_control
+        from bitdust.crypt import my_keys
+        # from bitdust.storage import backup_control
         my_keys.check_rename_my_keys()
         self._do_synchronize_keys()
-        backup_control.Save()
+        # backup_control.Save()
         return None
 
     def _on_index_synchronizer_state_changed(self, oldstate, newstate, event_string, *args, **kwargs):
         from twisted.internet.defer import Deferred
-        if oldstate in ['REQUEST?', 'SENDING', ] and newstate == 'IN_SYNC!':
+        if oldstate in [
+            'REQUEST?',
+            'SENDING',
+        ] and newstate == 'IN_SYNC!':
             if self.sync_keys_requested:
                 result = Deferred()
                 result.addCallback(self._on_keys_synchronized)
@@ -240,15 +240,14 @@ class KeysStorageService(LocalService):
                 self._do_check_sync_keys(result)
 
     def _on_my_keys_synchronize_failed(self, evt):
-        from logs import lg
-        from main import config
-        from interface import api
-        from userid import global_id
-        from userid import my_id
+        from bitdust.logs import lg
+        from bitdust.main import config
+        from bitdust.interface import api
+        from bitdust.userid import global_id
+        from bitdust.userid import my_id
         if not config.conf().getBool('services/keys-storage/reset-unreliable-backup-copies'):
             return
-        global_keys_folder_path = global_id.MakeGlobalID(
-            key_alias='master', customer=my_id.getGlobalID(), path='.keys')
+        global_keys_folder_path = global_id.MakeGlobalID(key_alias='master', customer=my_id.getGlobalID(), path='.keys')
         lg.info('about to erase ".keys" folder in the catalog: %r' % global_keys_folder_path)
         res = api.file_delete(global_keys_folder_path)
         if res['status'] == 'OK':
