@@ -305,7 +305,7 @@ def report_local_storage():
     # r['temp_str'] = diskspace.MakeStringFromBytes(r['temp'])
     r['customers'] = bpio.getDirectorySize(settings.getCustomersFilesDir())
     # r['customers_str'] = diskspace.MakeStringFromBytes(r['customers'])
-    r['total'] = bpio.getDirectorySize(settings.BaseDir())
+    r['total'] = bpio.getDirectorySize(settings.AppDataDir())
     # r['total_str'] = diskspace.MakeStringFromBytes(r['total'])
     dataDriveFreeSpace, dataDriveTotalSpace = diskusage.GetDriveSpace(settings.getCustomersFilesDir())
     if dataDriveFreeSpace is None:
