@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: archive_reader
 .. role:: red
@@ -58,60 +56,49 @@ from twisted.internet import reactor  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import packetid
-from lib import serialization
+from bitdust.lib import packetid
+from bitdust.lib import serialization
 
-from main import settings
+from bitdust.system import tmpfile
+from bitdust.system import local_fs
 
-from system import tmpfile
-from system import local_fs
-from system import bpio
+from bitdust.crypt import my_keys
 
-from crypt import my_keys
+from bitdust.dht import dht_relations
 
-from dht import dht_relations
+from bitdust.contacts import contactsdb
 
-from contacts import contactsdb
+from bitdust.raid import eccmap
 
-from raid import eccmap
+from bitdust.p2p import commands
+from bitdust.p2p import p2p_service
 
-from p2p import commands
-from p2p import p2p_service
+from bitdust.access import groups
 
-from access import groups
+from bitdust.storage import restore_worker
+from bitdust.storage import backup_fs
+from bitdust.storage import backup_matrix
+from bitdust.storage import backup_tar
 
-from storage import restore_worker
-from storage import backup_fs
-from storage import backup_matrix
-from storage import backup_tar
-
-from userid import global_id
-from userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
+
 class ArchiveReader(automat.Automat):
     """
     This class implements all the functionality of ``archive_reader()`` state machine.
     """
-
-    def __init__(self, debug_level=0, log_events=False, log_transitions=False, publish_events=False, **kwargs):
+    def __init__(self, debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, publish_events=False, **kwargs):
         """
         Builds `archive_reader()` state machine.
         """
-        super(ArchiveReader, self).__init__(
-            name="archive_reader",
-            state="AT_STARTUP",
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            publish_events=publish_events,
-            **kwargs
-        )
+        super(ArchiveReader, self).__init__(name='archive_reader', state='AT_STARTUP', debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, publish_events=publish_events, **kwargs)
 
     def A(self, event, *args, **kwargs):
         """
@@ -287,8 +274,7 @@ class ArchiveReader(automat.Automat):
             outpacket = p2p_service.SendListFiles(
                 target_supplier=supplier_idurl,
                 key_id=self.group_key_id,
-                query_items=[self.queue_alias, ],
-                timeout=30,
+                query_items=[self.queue_alias],
                 callbacks={
                     commands.Fail(): lambda resp, info: self._on_list_files_failed(supplier_pos),
                     None: lambda pkt_out: self._on_list_files_failed(supplier_pos),
@@ -296,7 +282,7 @@ class ArchiveReader(automat.Automat):
             )
             self.requested_list_files[supplier_pos] = None if outpacket else False
         if _Debug:
-            lg.args(_DebugLevel, requested=self.requested_list_files)
+            lg.args(_DebugLevel, queue_alias=self.queue_alias, requested=self.requested_list_files)
         self.request_list_files_timer = reactor.callLater(30, self._on_request_list_files_timeout)  # @UndefinedVariable
 
     def _do_select_archive_snapshots(self):
@@ -334,7 +320,10 @@ class ArchiveReader(automat.Automat):
                 continue
             if self.end_sequence_id is not None and self.end_sequence_id < snapshot_sequence_id:
                 continue
-            snapshot_sequence_ids.append((snapshot_sequence_id, backup_id, ))
+            snapshot_sequence_ids.append((
+                snapshot_sequence_id,
+                backup_id,
+            ))
         snapshot_sequence_ids.sort(key=lambda item: int(item[0]))
         if _Debug:
             lg.args(_DebugLevel, snapshot_sequence_ids=snapshot_sequence_ids)
@@ -362,8 +351,7 @@ class ArchiveReader(automat.Automat):
         )
         rw = restore_worker.RestoreWorker(backup_id, outfd, KeyID=self.group_key_id)
         rw.MyDeferred.addCallback(self._on_restore_done, backup_id, outfd, outfilename, backup_index)
-        if _Debug:
-            rw.MyDeferred.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='archive_reader.doStartRestoreWorker')
+        rw.MyDeferred.addErrback(lg.errback, debug=_Debug, debug_level=_DebugLevel, method='archive_reader.doStartRestoreWorker')
         rw.MyDeferred.addErrback(self._on_restore_failed, backup_id, outfd, outfilename, backup_index)
         rw.automat('init')
 
@@ -398,8 +386,7 @@ class ArchiveReader(automat.Automat):
             lg.warn('skip ListFiles() response, requested_list_files object is empty')
             return
         if self.requested_list_files.get(supplier_num) is not None:
-            lg.warn('skip ListFiles() response, supplier record at position %d already set to %r' % (
-                supplier_num, self.requested_list_files.get(supplier_num)))
+            lg.warn('skip ListFiles() response, supplier record at position %d already set to %r' % (supplier_num, self.requested_list_files.get(supplier_num)))
             return
         self.requested_list_files[supplier_num] = True
         lst = list(self.requested_list_files.values())
@@ -426,8 +413,7 @@ class ArchiveReader(automat.Automat):
             lg.warn('skip ListFiles() response, requested_list_files object is empty')
             return
         if self.requested_list_files.get(supplier_num) is not None:
-            lg.warn('skip ListFiles() response, supplier record at position %d already set to %r' % (
-                supplier_num, self.requested_list_files.get(supplier_num)))
+            lg.warn('skip ListFiles() response, supplier record at position %d already set to %r' % (supplier_num, self.requested_list_files.get(supplier_num)))
             return
         self.requested_list_files[supplier_num] = False
         lst = list(self.requested_list_files.values())
@@ -474,9 +460,9 @@ class ArchiveReader(automat.Automat):
         except:
             lg.exc()
         if result == 'done':
-            lg.info('archive %r restore success from %r' % (backup_id, tarfilename, ))
+            lg.info('archive %r restore success from %r' % (backup_id, tarfilename))
         else:
-            lg.err('archive %r restore failed from %r with : %r' % (backup_id, tarfilename, result, ))
+            lg.err('archive %r restore failed from %r with : %r' % (backup_id, tarfilename, result))
         if result != 'done':
             tmpfile.throw_out(tarfilename, 'restore ' + result)
             self.automat('restore-failed', backup_id=backup_id, tarfilename=tarfilename)
@@ -485,7 +471,7 @@ class ArchiveReader(automat.Automat):
         return
 
     def _on_restore_failed(self, err, backupID, outfd, tarfilename, backup_index):
-        lg.err('archive %r restore failed with : %r' % (backupID, err, ))
+        lg.err('archive %r restore failed with : %r' % (backupID, err))
         try:
             os.close(outfd)
         except:
@@ -513,7 +499,6 @@ class ArchiveReader(automat.Automat):
                         continue
                 self.extracted_messages.append(archive_message)
         if _Debug:
-            lg.dbg(_DebugLevel, 'archive snapshot %r extracted successfully to %r, extracted %d archive messages so far' % (
-                source_filename, output_location, len(self.extracted_messages), ))
-        self._do_restore_next_backup(backup_index+1)
+            lg.dbg(_DebugLevel, 'archive snapshot %r extracted successfully to %r, extracted %d archive messages so far' % (source_filename, output_location, len(self.extracted_messages)))
+        self._do_restore_next_backup(backup_index + 1)
         return retcode
