@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: index_synchronizer.
 
@@ -87,7 +86,7 @@ from __future__ import absolute_import
 #------------------------------------------------------------------------------
 
 _Debug = False
-_DebugLevel = 8
+_DebugLevel = 16
 
 #------------------------------------------------------------------------------
 
@@ -97,36 +96,36 @@ from twisted.internet import reactor  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import nameurl
+from bitdust.lib import nameurl
 
-from p2p import commands
-from p2p import online_status
-from p2p import p2p_service
-from p2p import propagate
+from bitdust.p2p import commands
+from bitdust.p2p import online_status
+from bitdust.p2p import p2p_service
+from bitdust.p2p import propagate
 
-from system import bpio
+from bitdust.system import bpio
 
-from userid import my_id
-from userid import global_id
+from bitdust.userid import my_id
+from bitdust.userid import global_id
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from crypt import encrypted
-from crypt import signed
-from crypt import key
+from bitdust.crypt import encrypted
+from bitdust.crypt import signed
+from bitdust.crypt import key
 
-from transport import packet_out
+from bitdust.transport import packet_out
 
-from services import driver
+from bitdust.services import driver
 
-from customer import supplier_connector
+from bitdust.customer import supplier_connector
 
 #------------------------------------------------------------------------------
 
@@ -134,12 +133,13 @@ _IndexSynchronizer = None
 
 #------------------------------------------------------------------------------
 
+
 def is_synchronized():
     if not A():
         return False
     if A().state == 'IN_SYNC!':
         return True
-    if A().state in ['REQUEST?', 'SENDING', ]:
+    if A().state in ['REQUEST?', 'SENDING']:
         if A().last_time_in_sync > 0 and time.time() - A().last_time_in_sync < 30:
             return True
     return False
@@ -148,10 +148,12 @@ def is_synchronized():
 def is_synchronizing():
     if not A():
         return False
-    return A().state in ['REQUEST?', 'SENDING', ]
+    return A().state in ['REQUEST?', 'SENDING']
+
 
 #------------------------------------------------------------------------------
 
+
 def A(event=None, *args, **kwargs):
     """
     Access method to interact with the state machine.
@@ -171,8 +173,10 @@ def A(event=None, *args, **kwargs):
         _IndexSynchronizer.automat(event, *args, **kwargs)
     return _IndexSynchronizer
 
+
 #------------------------------------------------------------------------------
 
+
 class IndexSynchronizer(automat.Automat):
     """
     This class implements all the functionality of the ``index_synchronizer()``
@@ -220,7 +224,10 @@ class IndexSynchronizer(automat.Automat):
             self.last_time_in_sync = time.time()
             if self.PushAgain:
                 reactor.callLater(0, self.automat, 'instant')  # @UndefinedVariable
-        if newstate == 'NO_INFO' and oldstate in ['REQUEST?', 'SENDING', ]:
+        if newstate == 'NO_INFO' and oldstate in [
+            'REQUEST?',
+            'SENDING',
+        ]:
             events.send('my-backup-index-out-of-sync', data={})
         if newstate == 'NO_INFO':
             self.last_time_in_sync = -1
@@ -243,26 +250,26 @@ class IndexSynchronizer(automat.Automat):
             elif event == 'pull' or event == 'timer-5min':
                 self.state = 'REQUEST?'
                 self.doSuppliersRequestIndexFile(*args, **kwargs)
-            elif event == 'push' or ( event == 'instant' and self.PushAgain ):
+            elif event == 'push' or (event == 'instant' and self.PushAgain):
                 self.state = 'SENDING'
                 self.doSuppliersSendIndexFile(*args, **kwargs)
-                self.PushAgain=False
-                self.PullAgain=False
+                self.PushAgain = False
+                self.PullAgain = False
         #---REQUEST?---
         elif self.state == 'REQUEST?':
             if event == 'shutdown':
                 self.state = 'CLOSED'
                 self.doCancelRequests(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'all-responded' or ( event == 'timer-15sec' and self.isSomeResponded(*args, **kwargs) ) ) and self.isVersionChanged(*args, **kwargs):
+            elif (event == 'all-responded' or (event == 'timer-15sec' and self.isSomeResponded(*args, **kwargs))) and self.isVersionChanged(*args, **kwargs):
                 self.state = 'SENDING'
                 self.doCancelRequests(*args, **kwargs)
                 self.doSuppliersSendIndexFile(*args, **kwargs)
-                self.PushAgain=False
-                self.PullAgain=False
+                self.PushAgain = False
+                self.PullAgain = False
             elif event == 'index-file-received':
                 self.doCheckVersion(*args, **kwargs)
-            elif ( event == 'all-responded' or ( event == 'timer-15sec' and self.isSomeResponded(*args, **kwargs) ) ) and not self.isVersionChanged(*args, **kwargs):
+            elif (event == 'all-responded' or (event == 'timer-15sec' and self.isSomeResponded(*args, **kwargs))) and not self.isVersionChanged(*args, **kwargs):
                 self.state = 'IN_SYNC!'
                 self.doCancelRequests(*args, **kwargs)
             elif event == 'timer-10sec' and not self.isSomeResponded(*args, **kwargs) and self.isAllTimedOut(*args, **kwargs):
@@ -275,20 +282,20 @@ class IndexSynchronizer(automat.Automat):
                 self.doCancelSendings(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
             elif event == 'push':
-                self.PushAgain=True
+                self.PushAgain = True
             elif event == 'timer-15sec' and not self.isSomeAcked(*args, **kwargs) and not self.PullAgain:
                 self.state = 'NO_INFO'
                 self.doCancelSendings(*args, **kwargs)
-            elif ( event == 'all-acked' or ( event == 'timer-15sec' and self.isSomeAcked(*args, **kwargs) ) ) and not self.PullAgain:
+            elif (event == 'all-acked' or (event == 'timer-15sec' and self.isSomeAcked(*args, **kwargs))) and not self.PullAgain:
                 self.state = 'IN_SYNC!'
                 self.doCancelSendings(*args, **kwargs)
             elif event == 'pull':
-                self.PullAgain=True
-            elif ( event == 'all-acked' or event == 'timer-15sec' ) and self.PullAgain:
+                self.PullAgain = True
+            elif (event == 'all-acked' or event == 'timer-15sec') and self.PullAgain:
                 self.state = 'REQUEST?'
                 self.doCancelSendings(*args, **kwargs)
                 self.doSuppliersRequestIndexFile(*args, **kwargs)
-                self.PullAgain=False
+                self.PullAgain = False
         #---NO_INFO---
         elif self.state == 'NO_INFO':
             if event == 'shutdown':
@@ -297,8 +304,8 @@ class IndexSynchronizer(automat.Automat):
             elif event == 'push' or event == 'pull' or event == 'timer-1min':
                 self.state = 'REQUEST?'
                 self.doSuppliersRequestIndexFile(*args, **kwargs)
-                self.PushAgain=False
-                self.PullAgain=False
+                self.PushAgain = False
+                self.PullAgain = False
         #---CLOSED---
         elif self.state == 'CLOSED':
             pass
@@ -344,7 +351,6 @@ class IndexSynchronizer(automat.Automat):
         Action method.
         """
         self.ping_required = False
-        data = bpio.ReadBinaryFile(settings.BackupIndexFilePath())
 
     def doSuppliersRequestIndexFile(self, *args, **kwargs):
         """
@@ -353,7 +359,7 @@ class IndexSynchronizer(automat.Automat):
         if _Debug:
             lg.out(_DebugLevel, 'index_synchronizer.doSuppliersRequestIndexFile')
         if driver.is_on('service_backups'):
-            from storage import backup_fs
+            from bitdust.storage import backup_fs
             self.current_local_revision = backup_fs.revision()
         else:
             self.current_local_revision = -1
@@ -417,8 +423,7 @@ class IndexSynchronizer(automat.Automat):
                 if newpacket.PacketID not in self.outgoing_packets_ids:
                     self.outgoing_packets_ids.append(newpacket.PacketID)
             if _Debug:
-                lg.out(_DebugLevel, '    %s sending to %s' %
-                       (newpacket, nameurl.GetName(supplier_idurl)))
+                lg.out(_DebugLevel, '    %s sending to %s' % (newpacket, nameurl.GetName(supplier_idurl)))
 
     def doCancelSendings(self, *args, **kwargs):
         """
@@ -434,11 +439,13 @@ class IndexSynchronizer(automat.Automat):
         """
         Action method.
         """
+
+
 #         packetID = global_id.MakeGlobalID(
 #             customer=my_id.getGlobalID(key_alias='master'),
 #             path=settings.BackupIndexFileName(),
 #         )
-#         from transport import packet_out
+#         from bitdust.transport import packet_out
 #         packetsToCancel = packet_out.search_by_packet_id(packetID)
 #         for pkt_out in packetsToCancel:
 #             if pkt_out.outpacket.Command == commands.Retrieve():
@@ -471,14 +478,13 @@ class IndexSynchronizer(automat.Automat):
             lg.err('incoming Data() is not valid')
             return
         supplier_idurl = wrapped_packet.RemoteID
-        from storage import backup_control
+        from bitdust.storage import backup_control
         supplier_revision = backup_control.IncomingSupplierBackupIndex(wrapped_packet)
         self.requesting_suppliers.discard(supplier_idurl)
         if supplier_revision is not None:
-            reactor.callLater(0, self.automat, 'index-file-received', (newpacket, supplier_revision, ))  # @UndefinedVariable
+            reactor.callLater(0, self.automat, 'index-file-received', (newpacket, supplier_revision))  # @UndefinedVariable
         if _Debug:
-            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_response %s from %r, rev:%s, pending: %d, total: %d' % (
-                newpacket, supplier_idurl, supplier_revision, len(self.requesting_suppliers), self.requested_suppliers_number))
+            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_response %s from %r, rev:%s, pending: %d, total: %d' % (newpacket, supplier_idurl, supplier_revision, len(self.requesting_suppliers), self.requested_suppliers_number))
         if len(self.requesting_suppliers) == 0:
             reactor.callLater(0, self.automat, 'all-responded')  # @UndefinedVariable
 
@@ -488,8 +494,7 @@ class IndexSynchronizer(automat.Automat):
         supplier_idurl = newpacket.CreatorID
         self.requesting_suppliers.discard(supplier_idurl)
         if _Debug:
-            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_fail %s from %r, pending: %d, total: %d' % (
-                newpacket, supplier_idurl, len(self.requesting_suppliers), self.requested_suppliers_number))
+            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_fail %s from %r, pending: %d, total: %d' % (newpacket, supplier_idurl, len(self.requesting_suppliers), self.requested_suppliers_number))
         if len(self.requesting_suppliers) == 0:
             reactor.callLater(0, self.automat, 'all-responded')  # @UndefinedVariable
 
@@ -503,8 +508,7 @@ class IndexSynchronizer(automat.Automat):
         else:
             lg.warn('did not found supplier connector for %r' % newpacket.OwnerID)
         if _Debug:
-            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_acked %s, pending: %d, total: %d' % (
-                newpacket, len(self.sending_suppliers), self.sent_suppliers_number))
+            lg.out(_DebugLevel, 'index_synchronizer._on_supplier_acked %s, pending: %d, total: %d' % (newpacket, len(self.sending_suppliers), self.sent_suppliers_number))
         if len(self.sending_suppliers) == 0:
             reactor.callLater(0, self.automat, 'all-acked')  # @UndefinedVariable
 
@@ -527,16 +531,15 @@ class IndexSynchronizer(automat.Automat):
                 creatorID=localID,
                 packetID=packetID,
                 remoteID=supplier_idurl,
-                response_timeout=60*2,
+                response_timeout=settings.P2PTimeOut(),
                 callbacks={
                     commands.Data(): self._on_supplier_response,
                     commands.Fail(): self._on_supplier_fail,
-                }
+                },
             )
             if pkt_out:
                 self.requesting_suppliers.add(supplier_idurl)
                 self.requested_suppliers_number += 1
                 self.requests_packets_sent.append((packetID, supplier_idurl))
             if _Debug:
-                lg.out(_DebugLevel, '    %s sending to %s' %
-                       (pkt_out, nameurl.GetName(supplier_idurl)))
+                lg.out(_DebugLevel, '    %s sending to %s' % (pkt_out, nameurl.GetName(supplier_idurl)))
