@@ -19,7 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
 """
 .. module:: restore_worker
 .. role:: red
@@ -71,7 +70,6 @@ The other thing we need is the backupIDs which we can get from our suppliers wit
 
 """
 
-
 #------------------------------------------------------------------------------
 
 from __future__ import absolute_import
@@ -80,7 +78,7 @@ from six.moves import range
 #------------------------------------------------------------------------------
 
 _Debug = False
-_DebugLevel = 10
+_DebugLevel = 12
 
 #------------------------------------------------------------------------------
 
@@ -99,40 +97,41 @@ from twisted.internet.defer import Deferred
 
 #------------------------------------------------------------------------------
 
-from automats import automat
+from bitdust.automats import automat
 
-from logs import lg
+from bitdust.logs import lg
 
-from system import bpio
-from system import tmpfile
+from bitdust.system import bpio
+from bitdust.system import tmpfile
 
-from main import settings
-from main import events
+from bitdust.main import settings
+from bitdust.main import events
 
-from lib import packetid
-from lib import strng
+from bitdust.lib import packetid
+from bitdust.lib import strng
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from crypt import encrypted
+from bitdust.crypt import encrypted
 
-from p2p import online_status
-from p2p import propagate
+from bitdust.p2p import online_status
+from bitdust.p2p import propagate
 
-from stream import data_receiver
-from stream import io_throttle
+from bitdust.stream import data_receiver
+from bitdust.stream import io_throttle
 
-from raid import raid_worker
-from raid import eccmap
+from bitdust.raid import raid_worker
+from bitdust.raid import eccmap
 
-from services import driver
+from bitdust.services import driver
 
-from userid import global_id
-from userid import id_url
-from userid import my_id
+from bitdust.userid import global_id
+from bitdust.userid import id_url
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
+
 class RestoreWorker(automat.Automat):
     """
     This class implements all the functionality of ``restore_worker()`` state machine.
@@ -142,16 +141,7 @@ class RestoreWorker(automat.Automat):
         'timer-5sec': (5.0, ['REQUESTED']),
     }
 
-    def __init__(self,
-                 BackupID,
-                 OutputFile,
-                 KeyID=None,
-                 ecc_map=None,
-                 debug_level=_DebugLevel,
-                 log_events=False,
-                 log_transitions=_Debug,
-                 publish_events=False,
-                 **kwargs):
+    def __init__(self, BackupID, OutputFile, KeyID=None, ecc_map=None, debug_level=_DebugLevel, log_events=False, log_transitions=_Debug, publish_events=False, **kwargs):
         """
         Builds `restore_worker()` state machine.
         """
@@ -185,15 +175,7 @@ class RestoreWorker(automat.Automat):
         self.blockRestoredCallback = None
         self.Attempts = 0
 
-        super(RestoreWorker, self).__init__(
-            name='restore_worker_%s' % self.version,
-            state="AT_STARTUP",
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            publish_events=publish_events,
-            **kwargs
-        )
+        super(RestoreWorker, self).__init__(name='restore_worker_%s' % self.version, state='AT_STARTUP', debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, publish_events=publish_events, **kwargs)
         events.send('restore-started', data=dict(backup_id=self.backup_id))
 
     def set_packet_in_callback(self, cb):
@@ -207,11 +189,11 @@ class RestoreWorker(automat.Automat):
         Method to catch the moment when `restore_worker()` state were changed.
         """
         if event != 'instant':
-            if newstate in ['REQUESTED', 'RECEIVING', ] and oldstate not in ['REQUESTED', 'RECEIVING', ]:
+            if newstate in ['REQUESTED', 'RECEIVING'] and oldstate not in ['REQUESTED', 'RECEIVING']:
                 reactor.callLater(0.01, self.automat, 'instant')  # @UndefinedVariable
 
     def state_not_changed(self, curstate, event, *args, **kwargs):
-        if event == 'data-received' and curstate in ['REQUESTED', 'RECEIVING', ]:
+        if event == 'data-received' and curstate in ['REQUESTED', 'RECEIVING']:
             reactor.callLater(0.01, self.automat, 'instant')  # @UndefinedVariable
 
     def A(self, event, *args, **kwargs):
@@ -226,26 +208,28 @@ class RestoreWorker(automat.Automat):
                 self.doStartNewBlock(*args, **kwargs)
                 self.doScanExistingPackets(*args, **kwargs)
                 self.doRequestPackets(*args, **kwargs)
-                self.Attempts=1
+                self.Attempts = 1
         #---REQUESTED---
         elif self.state == 'REQUESTED':
             if event == 'data-receiving-started':
                 self.state = 'RECEIVING'
-            elif event == 'timer-5sec' and self.Attempts==2:
+            elif event == 'timer-5sec' and self.Attempts == 2:
                 self.doPingOfflineSuppliers(*args, **kwargs)
             elif event == 'data-received':
                 self.doSavePacket(*args, **kwargs)
-            elif event == 'request-failed' and self.isStillCorrectable(*args, **kwargs) and self.Attempts<3:
+            elif event == 'request-failed' and self.isStillCorrectable(*args, **kwargs) and self.Attempts < 3:
                 self.doScanExistingPackets(*args, **kwargs)
                 self.doRequestPackets(*args, **kwargs)
-                self.Attempts+=1
-            elif ( event == 'abort' or ( event == 'request-failed' and ( not self.isStillCorrectable(*args, **kwargs) or self.Attempts>=3 ) ) ) or ( ( event == 'instant' or event == 'request-finished' ) and not self.isBlockReceiving(*args, **kwargs) and not self.isBlockFixable(*args, **kwargs) ):
+                self.Attempts += 1
+            elif (event == 'abort' or
+                  (event == 'request-failed' and
+                   (not self.isStillCorrectable(*args, **kwargs) or self.Attempts >= 3))) or ((event == 'instant' or event == 'request-finished') and not self.isBlockReceiving(*args, **kwargs) and not self.isBlockFixable(*args, **kwargs)):
                 self.state = 'FAILED'
                 self.doDeleteAllRequests(*args, **kwargs)
                 self.doRemoveTempFile(*args, **kwargs)
                 self.doReportFailed(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'instant' or event == 'request-finished' ) and self.isBlockFixable(*args, **kwargs):
+            elif (event == 'instant' or event == 'request-finished') and self.isBlockFixable(*args, **kwargs):
                 self.state = 'RAID'
                 self.doReadRaid(*args, **kwargs)
         #---RECEIVING---
@@ -256,13 +240,14 @@ class RestoreWorker(automat.Automat):
                 self.doRequestPackets(*args, **kwargs)
             elif event == 'data-received':
                 self.doSavePacket(*args, **kwargs)
-            elif ( event == 'abort' or ( ( event == 'request-failed' or event == 'data-receiving-stopped' ) and not self.isStillCorrectable(*args, **kwargs) ) ) or ( ( event == 'instant' or event == 'request-finished' ) and not self.isBlockReceiving(*args, **kwargs) and not self.isBlockFixable(*args, **kwargs) ):
+            elif (event == 'abort' or ((event == 'request-failed' or event == 'data-receiving-stopped') and
+                                       not self.isStillCorrectable(*args, **kwargs))) or ((event == 'instant' or event == 'request-finished') and not self.isBlockReceiving(*args, **kwargs) and not self.isBlockFixable(*args, **kwargs)):
                 self.state = 'FAILED'
                 self.doDeleteAllRequests(*args, **kwargs)
                 self.doRemoveTempFile(*args, **kwargs)
                 self.doReportFailed(*args, **kwargs)
                 self.doDestroyMe(*args, **kwargs)
-            elif ( event == 'instant' or event == 'request-finished' ) and self.isBlockFixable(*args, **kwargs):
+            elif (event == 'instant' or event == 'request-finished') and self.isBlockFixable(*args, **kwargs):
                 self.state = 'RAID'
                 self.doReadRaid(*args, **kwargs)
         #---RAID---
@@ -287,7 +272,7 @@ class RestoreWorker(automat.Automat):
                 self.doStartNewBlock(*args, **kwargs)
                 self.doScanExistingPackets(*args, **kwargs)
                 self.doRequestPackets(*args, **kwargs)
-                self.Attempts=1
+                self.Attempts = 1
             elif event == 'block-restored' and self.isLastBlock(*args, **kwargs):
                 self.state = 'DONE'
                 self.doWriteRestoredData(*args, **kwargs)
@@ -326,7 +311,7 @@ class RestoreWorker(automat.Automat):
             return False
         result = bool(len(self.RequestFails) <= self.max_errors)
         if _Debug:
-            lg.out(_DebugLevel, 'restore_worker.isStillCorrectable max_errors=%d, fails=%d' % (self.max_errors, len(self.RequestFails), ))
+            lg.out(_DebugLevel, 'restore_worker.isStillCorrectable max_errors=%d, fails=%d' % (self.max_errors, len(self.RequestFails)))
         return result
 
     def isBlockFixable(self, *args, **kwargs):
@@ -363,7 +348,8 @@ class RestoreWorker(automat.Automat):
             known_eccmap_dict = {}
             for supplier_idurl in self.known_suppliers:
                 known_ecc_map = contactsdb.get_supplier_meta_info(
-                    supplier_idurl=supplier_idurl, customer_idurl=self.customer_idurl,
+                    supplier_idurl=supplier_idurl,
+                    customer_idurl=self.customer_idurl,
                 ).get('ecc_map', None)
                 if known_ecc_map:
                     if known_ecc_map not in known_eccmap_dict:
@@ -377,20 +363,19 @@ class RestoreWorker(automat.Automat):
             else:
                 known_ecc_map = None
                 if driver.is_on('service_shared_data'):
-                    from access import shared_access_coordinator
+                    from bitdust.access import shared_access_coordinator
                     active_share = shared_access_coordinator.get_active_share(self.key_id)
                     if active_share:
                         known_ecc_map = active_share.known_ecc_map
                 if known_ecc_map:
                     self.EccMap = eccmap.eccmap(known_ecc_map)
-                    lg.info('ECC map %r recognized from active share %r' % (self.EccMap, active_share, ))
+                    lg.info('ECC map %r recognized from active share %r' % (self.EccMap, active_share))
                 else:
                     num_suppliers = len(self.known_suppliers)
                     if num_suppliers not in eccmap.GetPossibleSuppliersCount():
                         num_suppliers = settings.DefaultDesiredSuppliers()
                     self.EccMap = eccmap.eccmap(eccmap.GetEccMapName(num_suppliers))
-                    lg.warn('no meta info found, guessed ECC map %r from %d known suppliers' % (
-                        self.EccMap, len(self.known_suppliers)))
+                    lg.warn('no meta info found, guessed ECC map %r from %d known suppliers' % (self.EccMap, len(self.known_suppliers)))
         self.max_errors = eccmap.GetCorrectableErrors(self.EccMap.NumSuppliers())
         if data_receiver.A():
             data_receiver.A().addStateChangedCallback(self._on_data_receiver_state_changed)
@@ -402,9 +387,9 @@ class RestoreWorker(automat.Automat):
         self.LastAction = time.time()
         self.block_number += 1
         if _Debug:
-            lg.out(_DebugLevel, "restore_worker.doStartNewBlock " + str(self.block_number))
-        self.OnHandData = [False, ] * self.EccMap.datasegments
-        self.OnHandParity = [False, ] * self.EccMap.paritysegments
+            lg.out(_DebugLevel, 'restore_worker.doStartNewBlock ' + str(self.block_number))
+        self.OnHandData = [False]*self.EccMap.datasegments
+        self.OnHandParity = [False]*self.EccMap.paritysegments
         self.RequestFails = []
         self.block_requests = {}
         self.AlreadyRequestedCounts = {}
@@ -427,13 +412,11 @@ class RestoreWorker(automat.Automat):
         for SupplierNumber in range(self.EccMap.datasegments):
             PacketID = packetid.MakePacketID(self.backup_id, self.block_number, SupplierNumber, 'Data')
             customerID, remotePath = packetid.SplitPacketID(PacketID)
-            self.OnHandData[SupplierNumber] = bool(os.path.exists(os.path.join(
-                settings.getLocalBackupsDir(), customerID, remotePath)))
+            self.OnHandData[SupplierNumber] = bool(os.path.exists(os.path.join(settings.getLocalBackupsDir(), customerID, remotePath)))
         for SupplierNumber in range(self.EccMap.paritysegments):
             PacketID = packetid.MakePacketID(self.backup_id, self.block_number, SupplierNumber, 'Parity')
             customerID, remotePath = packetid.SplitPacketID(PacketID)
-            self.OnHandParity[SupplierNumber] = bool(os.path.exists(os.path.join(
-                settings.getLocalBackupsDir(), customerID, remotePath)))
+            self.OnHandParity[SupplierNumber] = bool(os.path.exists(os.path.join(settings.getLocalBackupsDir(), customerID, remotePath)))
 
     def doRestoreBlock(self, *args, **kwargs):
         """
@@ -446,10 +429,10 @@ class RestoreWorker(automat.Automat):
             self.automat('block-failed')
             return
         try:
-            splitindex = blockbits.index(b":")
+            splitindex = blockbits.index(b':')
             lengthstring = blockbits[0:splitindex]
-            datalength = int(lengthstring)                                        # real length before raidmake/ECC
-            blockdata = blockbits[splitindex + 1:splitindex + 1 + datalength]     # remove padding from raidmake/ECC
+            datalength = int(lengthstring)  # real length before raidmake/ECC
+            blockdata = blockbits[splitindex + 1:splitindex + 1 + datalength]  # remove padding from raidmake/ECC
             newblock = encrypted.Unserialize(blockdata, decrypt_key=self.key_id)  # convert to object
         except:
             if _Debug:
@@ -462,7 +445,7 @@ class RestoreWorker(automat.Automat):
             lg.warn('block read/unserialize failed from %d bytes of data' % len(blockbits))
             self.automat('block-failed')
             return
-        self.automat('block-restored', (newblock, filename, ))
+        self.automat('block-restored', (newblock, filename))
 
     def doRequestPackets(self, *args, **kwargs):
         """
@@ -496,12 +479,12 @@ class RestoreWorker(automat.Automat):
                 lg.exc()
         # either way the payload of packet is saved
         if not bpio.WriteBinaryFile(filename, NewPacket.Payload):
-            lg.err("unable to write to %s" % filename)
+            lg.err('unable to write to %s' % filename)
             return
         if self.packetInCallback is not None:
             self.packetInCallback(self.backup_id, NewPacket)
         if _Debug:
-            lg.out(_DebugLevel, "restore_worker.doSavePacket %s saved to %s" % (packetID, filename))
+            lg.out(_DebugLevel, 'restore_worker.doSavePacket %s saved to %s' % (packetID, filename))
 
     def doReadRaid(self, *args, **kwargs):
         """
@@ -528,8 +511,8 @@ class RestoreWorker(automat.Automat):
             tmpfile.throw_out(filename, 'block restored')
         if settings.getBackupsKeepLocalCopies():
             return
-        from storage import backup_matrix
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_matrix
+        from bitdust.storage import backup_rebuilder
         if not backup_rebuilder.ReadStoppedFlag():
             if backup_rebuilder.A().currentBackupID is not None:
                 if backup_rebuilder.A().currentBackupID == self.backup_id:
@@ -541,9 +524,8 @@ class RestoreWorker(automat.Automat):
             supplierIDURL = contactsdb.supplier(supplierNum, customer_idurl=self.customer_idurl)
             if not supplierIDURL:
                 continue
-            for dataORparity in ['Data', 'Parity', ]:
-                packetID = packetid.MakePacketID(self.backup_id, self.block_number,
-                                                 supplierNum, dataORparity)
+            for dataORparity in ['Data', 'Parity']:
+                packetID = packetid.MakePacketID(self.backup_id, self.block_number, supplierNum, dataORparity)
                 customer, remotePath = packetid.SplitPacketID(packetID)
                 filename = os.path.join(settings.getLocalBackupsDir(), customer, remotePath)
                 if os.path.isfile(filename):
@@ -628,17 +610,17 @@ class RestoreWorker(automat.Automat):
         self.destroy()
 
     def _do_block_rebuilding(self):
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_rebuilder
         backup_rebuilder.BlockBackup(self.backup_id)
         io_throttle.DeleteBackupRequests(self.backup_id)
 
     def _do_unblock_rebuilding(self):
-        from storage import backup_rebuilder
+        from bitdust.storage import backup_rebuilder
         backup_rebuilder.UnBlockBackup(self.backup_id)
 
     def _do_check_run_requests(self):
         if _Debug:
-            lg.out(_DebugLevel, 'restore_worker._do_check_run_requests for %s at block %d' % (self.backup_id, self.block_number, ))
+            lg.out(_DebugLevel, 'restore_worker._do_check_run_requests for %s at block %d' % (self.backup_id, self.block_number))
         packetsToRequest = []
         for SupplierNumber in range(self.EccMap.datasegments):
             request_packet_id = packetid.MakePacketID(self.backup_id, self.block_number, SupplierNumber, 'Data')
@@ -650,7 +632,7 @@ class RestoreWorker(automat.Automat):
                 continue
             if request_packet_id in self.block_requests:
                 if _Debug:
-                    lg.out(_DebugLevel, '        SKIP, request for packet %r already sent to IO queue for supplier %d' % (request_packet_id, SupplierNumber, ))
+                    lg.out(_DebugLevel, '        SKIP, request for packet %r already sent to IO queue for supplier %d' % (request_packet_id, SupplierNumber))
                 continue
             SupplierID = contactsdb.supplier(SupplierNumber, customer_idurl=self.customer_idurl)
             if not SupplierID:
@@ -660,7 +642,7 @@ class RestoreWorker(automat.Automat):
                 if _Debug:
                     lg.out(_DebugLevel, '        SKIP, offline supplier: %s' % SupplierID)
                 continue
-            packetsToRequest.append((SupplierID, request_packet_id, ))
+            packetsToRequest.append((SupplierID, request_packet_id))
         for SupplierNumber in range(self.EccMap.paritysegments):
             request_packet_id = packetid.MakePacketID(self.backup_id, self.block_number, SupplierNumber, 'Parity')
             if self.OnHandParity[SupplierNumber]:
@@ -671,7 +653,7 @@ class RestoreWorker(automat.Automat):
                 continue
             if request_packet_id in self.block_requests:
                 if _Debug:
-                    lg.out(_DebugLevel, '        SKIP, request for packet %r already sent to IO queue for supplier %d' % (request_packet_id, SupplierNumber, ))
+                    lg.out(_DebugLevel, '        SKIP, request for packet %r already sent to IO queue for supplier %d' % (request_packet_id, SupplierNumber))
                 continue
             SupplierID = contactsdb.supplier(SupplierNumber, customer_idurl=self.customer_idurl)
             if not SupplierID:
@@ -681,7 +663,7 @@ class RestoreWorker(automat.Automat):
                 if _Debug:
                     lg.out(_DebugLevel, '        SKIP, offline supplier: %s' % SupplierID)
                 continue
-            packetsToRequest.append((SupplierID, request_packet_id, ))
+            packetsToRequest.append((SupplierID, request_packet_id))
         requests_made = 0
         # already_requested = 0
         for SupplierID, packetID in packetsToRequest:
@@ -690,7 +672,7 @@ class RestoreWorker(automat.Automat):
                 # if packetID not in self.AlreadyRequestedCounts:
                 #     self.AlreadyRequestedCounts[packetID] = 0
                 # self.AlreadyRequestedCounts[packetID] += 1
-                lg.warn('packet already in IO queue for supplier %s : %s' % (SupplierID, packetID, ))
+                lg.warn('packet already in IO queue for supplier %s : %s' % (SupplierID, packetID))
                 continue
             self.block_requests[packetID] = None
             if io_throttle.QueueRequestFile(
@@ -704,12 +686,11 @@ class RestoreWorker(automat.Automat):
             else:
                 self.block_requests[packetID] = False
             if _Debug:
-                lg.dbg(_DebugLevel, 'sent request %r to %r, other requests: %r' % (
-                    packetID, SupplierID, list(self.block_requests.values())))
+                lg.dbg(_DebugLevel, 'sent request %r to %r, other requests: %r' % (packetID, SupplierID, list(self.block_requests.values())))
         del packetsToRequest
         if requests_made:
             if _Debug:
-                lg.out(_DebugLevel, "        requested %d packets for block %d" % (requests_made, self.block_number, ))
+                lg.out(_DebugLevel, '        requested %d packets for block %d' % (requests_made, self.block_number))
             return
         current_block_requests_results = list(self.block_requests.values())
         if _Debug:
@@ -717,15 +698,15 @@ class RestoreWorker(automat.Automat):
         pending_count = current_block_requests_results.count(None)
         if pending_count > 0:
             if _Debug:
-                lg.out(_DebugLevel, "        nothing for request, currently %d pending packets for block %d" % (pending_count, self.block_number, ))
+                lg.out(_DebugLevel, '        nothing for request, currently %d pending packets for block %d' % (pending_count, self.block_number))
             return
         failed_count = current_block_requests_results.count(False)
         if failed_count > self.max_errors:
-            lg.err('all requests finished and %d packets failed, not possible to read data for block %d' % (failed_count, self.block_number, ))
+            lg.err('all requests finished and %d packets failed, not possible to read data for block %d' % (failed_count, self.block_number))
             reactor.callLater(0, self.automat, 'request-failed', None)  # @UndefinedVariable
             return
         if _Debug:
-            lg.out(_DebugLevel, "        all requests finished for block %d : %r" % (self.block_number, current_block_requests_results, ))
+            lg.out(_DebugLevel, '        all requests finished for block %d : %r' % (self.block_number, current_block_requests_results))
         reactor.callLater(0, self.automat, 'request-finished', None)  # @UndefinedVariable
 
     def _on_block_restored(self, restored_blocks, filename):
@@ -756,7 +737,7 @@ class RestoreWorker(automat.Automat):
                     if resp['key_alias'] == req['key_alias'] and resp['user'] == req['user']:
                         if id_url.is_the_same(resp['idurl'], req['idurl']):
                             packet_id = req_packet_id
-                            lg.warn('found matching packet request %r for rotated idurl %r' % (packet_id, resp['idurl'], ))
+                            lg.warn('found matching packet request %r for rotated idurl %r' % (packet_id, resp['idurl']))
                             break
         if packet_id not in self.block_requests:
             if _Debug:
@@ -767,14 +748,14 @@ class RestoreWorker(automat.Automat):
                 raise Exception('packet is still in IO queue, but already unregistered')
             lg.warn('packet already in the request queue: %r' % packet_id)
             return
-        if result in ['received', 'exist', ]:
+        if result in ['received', 'exist']:
             self.block_requests[packet_id] = True
             if result == 'exist':
                 # reactor.callLater(0, self.automat, 'data-received', (None, packet_id, ))  # @UndefinedVariable
-                self.event('data-received', (None, packet_id, ))
+                self.event('data-received', (None, packet_id))
             else:
                 # reactor.callLater(0, self.automat, 'data-received', (NewPacketOrPacketID, packet_id, ))  # @UndefinedVariable
-                self.event('data-received', (NewPacketOrPacketID, packet_id, ))
+                self.event('data-received', (NewPacketOrPacketID, packet_id))
         else:
             self.block_requests[packet_id] = False
             self.RequestFails.append(packet_id)
