@@ -19,7 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
 """
 .. module:: customer_assistant
 .. role:: red
@@ -54,24 +53,23 @@ _DebugLevel = 10
 
 #------------------------------------------------------------------------------
 
-from automats import automat
+from bitdust.automats import automat
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import nameurl
-from lib import packetid
-from lib import diskspace
+from bitdust.lib import packetid
+from bitdust.lib import diskspace
 
-from main import settings
+from bitdust.main import settings
 
-from crypt import my_keys
+from bitdust.crypt import my_keys
 
-from p2p import p2p_service
-from p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import commands
 
-from supplier import list_files
+from bitdust.supplier import list_files
 
-from storage import accounting
+from bitdust.storage import accounting
 
 #------------------------------------------------------------------------------
 
@@ -79,6 +77,7 @@ _CustomerAssistants = {}
 
 #------------------------------------------------------------------------------
 
+
 def assistants():
     global _CustomerAssistants
     return _CustomerAssistants
@@ -94,8 +93,10 @@ def create(customer_idurl):
 def by_idurl(customer_idurl):
     return assistants().get(customer_idurl, None)
 
+
 #------------------------------------------------------------------------------
 
+
 class CustomerAssistant(automat.Automat):
     """
     This class implements all the functionality of the ``customer_assistant()`` state machine.
@@ -112,7 +113,7 @@ class CustomerAssistant(automat.Automat):
         """
         self.customer_idurl = customer_idurl
         self.donated_bytes = accounting.get_customer_quota(self.customer_idurl) or 0
-        name = "customer_%s_%s" % (
+        name = 'customer_%s_%s' % (
             self.customer_idurl.to_id(),
             diskspace.MakeStringFromBytes(self.donated_bytes).replace(' ', ''),
         )
@@ -179,40 +180,47 @@ class CustomerAssistant(automat.Automat):
         """
         Action method.
         """
-        p2p_service.SendIdentity(self.customer_idurl, wide=True, callbacks={
-            commands.Ack(): self._customer_acked,
-            commands.Fail(): self._customer_failed,
-        })
+        p2p_service.SendIdentity(
+            self.customer_idurl,
+            wide=True,
+            callbacks={
+                commands.Ack(): self._customer_acked,
+                commands.Fail(): self._customer_failed,
+            },
+        )
 
     def doSendHisFiles(self, *args, **kwargs):
         """
         Action method.
         """
-        customer_key_id = my_keys.make_key_id(alias='customer', creator_idurl=self.customer_idurl)
-        customer_key_id = my_keys.latest_key_id(customer_key_id)
+        #         customer_key_id = my_keys.make_key_id(alias='customer', creator_idurl=self.customer_idurl)
+        #         customer_key_id = my_keys.latest_key_id(customer_key_id)
         # if my_keys.is_key_registered(customer_key_id):
         # TODO: re-think again about the customer key, do we really need it?
-        if False:
+        #         if False:
+        #             list_files.send(
+        #                 customer_idurl=self.customer_idurl,
+        #                 packet_id='%s:%s' % (
+        #                     customer_key_id,
+        #                     packetid.UniqueID()
+        #                 ),
+        #                 format_type=settings.ListFilesFormat(),
+        #                 key_id=customer_key_id,
+        #                 remote_idurl=self.customer_idurl,  # send to the customer
+        #             )
+        #         else:
+        #             # if "customer" key is not delivered to me yet, use his "master" key
+        customer_master_key_id = my_keys.latest_key_id(my_keys.make_key_id(alias='master', creator_idurl=self.customer_idurl))
+        if my_keys.is_key_registered(customer_master_key_id):
             list_files.send(
                 customer_idurl=self.customer_idurl,
-                packet_id='%s:%s' % (customer_key_id, packetid.UniqueID(), ),
+                packet_id='%s:%s' % (customer_master_key_id, packetid.UniqueID()),
                 format_type=settings.ListFilesFormat(),
-                key_id=customer_key_id,
-                remote_idurl=self.customer_idurl,  # send to the customer
+                key_id=customer_master_key_id,
+                remote_idurl=self.customer_idurl,
             )
         else:
-            # if "customer" key is not delivered to me yet, use his "master" key
-            customer_master_key_id = my_keys.latest_key_id(my_keys.make_key_id(alias='master', creator_idurl=self.customer_idurl))
-            if my_keys.is_key_registered(customer_master_key_id):
-                list_files.send(
-                    customer_idurl=self.customer_idurl,
-                    packet_id='%s:%s' % (customer_master_key_id, packetid.UniqueID(), ),
-                    format_type=settings.ListFilesFormat(),
-                    key_id=customer_master_key_id,
-                    remote_idurl=self.customer_idurl,  # send to the customer
-                )
-            else:
-                lg.err('key %s (and also %s) is not registered, not able to send customer files' % (customer_key_id, customer_master_key_id, ))
+            lg.err('key %s is not registered, not able to send customer files' % customer_master_key_id)
 
     def doDestroyMe(self, *args, **kwargs):
         """
