@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 # family_member.py
 #
-
-
 """
 .. module:: family_member
 .. role:: red
@@ -41,40 +39,45 @@ from twisted.internet.task import LoopingCall
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from main import settings
+from bitdust.main import settings
 
-from lib import serialization
-from lib import strng
-from lib import nameurl
+from bitdust.lib import serialization
+from bitdust.lib import strng
+from bitdust.lib import nameurl
 
-from contacts import contactsdb
+from bitdust.contacts import contactsdb
 
-from dht import dht_relations
+from bitdust.dht import dht_relations
 
-from userid import my_id
-from userid import id_url
+from bitdust.userid import my_id
+from bitdust.userid import id_url
 
-from raid import eccmap
+from bitdust.raid import eccmap
 
-from p2p import p2p_service
-from p2p import commands
+from bitdust.p2p import p2p_service
+from bitdust.p2p import commands
 
 #------------------------------------------------------------------------------
 
 _CustomersFamilies = {}
 
-_ValidRequests = ['family-refresh', 'family-join', 'family-leave', ]
+_ValidRequests = [
+    'family-refresh',
+    'family-join',
+    'family-leave',
+]
 
 #------------------------------------------------------------------------------
 
-DHT_RECORD_REFRESH_INTERVAL = 5 * 60
+DHT_RECORD_REFRESH_INTERVAL = 5*60
 
 #------------------------------------------------------------------------------
 
+
 def families():
     global _CustomersFamilies
     return _CustomersFamilies
@@ -113,38 +116,27 @@ class FamilyMember(automat.Automat):
         'timer-10sec': (10.0, ['SUPPLIERS']),
     }
 
-    def __init__(
-            self,
-            customer_idurl,
-            debug_level=_DebugLevel,
-            log_events=_Debug,
-            log_transitions=_Debug,
-            publish_events=False,
-            **kwargs
-        ):
+    def __init__(self, customer_idurl, debug_level=_DebugLevel, log_events=_Debug, log_transitions=_Debug, publish_events=False, **kwargs):
         """
         Builds `family_member()` state machine.
         """
         self.customer_idurl = id_url.field(customer_idurl)
         self.supplier_idurl = my_id.getIDURL().to_bin()
         super(FamilyMember, self).__init__(
-            name="family_%s_member_%s" % (
+            name='family_%s_member_%s' % (
                 nameurl.GetName(self.customer_idurl),
                 nameurl.GetName(self.supplier_idurl),
-            ),
-            state="AT_STARTUP",
-            debug_level=debug_level,
-            log_events=log_events,
-            log_transitions=log_transitions,
-            publish_events=publish_events,
-            **kwargs
+            ), state='AT_STARTUP', debug_level=debug_level, log_events=log_events, log_transitions=log_transitions, publish_events=publish_events, **kwargs
         )
 
     def state_changed(self, oldstate, newstate, event, *args, **kwargs):
         """
         Method to catch the moment when `family_member()` state were changed.
         """
-        if event != 'instant' and newstate in ['CONNECTED', 'DISCONNECTED', ]:
+        if event != 'instant' and newstate in [
+            'CONNECTED',
+            'DISCONNECTED',
+        ]:
             self.automat('instant')
 
     def state_not_changed(self, curstate, event, *args, **kwargs):
@@ -152,7 +144,10 @@ class FamilyMember(automat.Automat):
         This method intended to catch the moment when some event was fired in the `family_member()`
         but automat state was not changed.
         """
-        if event != 'instant' and curstate in ['CONNECTED', 'DISCONNECTED', ]:
+        if event != 'instant' and curstate in [
+            'CONNECTED',
+            'DISCONNECTED',
+        ]:
             self.automat('instant')
 
     def A(self, event, *args, **kwargs):
@@ -171,7 +166,7 @@ class FamilyMember(automat.Automat):
                 self.doDestroyMe(*args, **kwargs)
             elif event == 'instant' and self.isAnyRequests(*args, **kwargs):
                 self.state = 'DHT_READ'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doPull(*args, **kwargs)
                 self.doDHTRead(*args, **kwargs)
             elif event == 'family-refresh' or event == 'family-join' or event == 'family-leave':
@@ -186,15 +181,15 @@ class FamilyMember(automat.Automat):
                 self.doCheckReply(*args, **kwargs)
             elif event == 'dht-read-fail':
                 self.state = 'DISCONNECTED'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doNotifyDisconnected(*args, **kwargs)
             elif event == 'dht-value-exist' and self.isMyPositionOK(*args, **kwargs) and not self.isLeaving(*args, **kwargs):
                 self.state = 'CONNECTED'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doNotifyConnected(*args, **kwargs)
-            elif event == 'dht-value-not-exist' or ( event == 'dht-value-exist' and not self.isMyPositionOK(*args, **kwargs) ):
+            elif event == 'dht-value-not-exist' or (event == 'dht-value-exist' and not self.isMyPositionOK(*args, **kwargs)):
                 self.state = 'SUPPLIERS'
-                self.Attempts+=1
+                self.Attempts += 1
                 self.doRebuildFamily(*args, **kwargs)
                 self.doRequestSuppliersReview(*args, **kwargs)
             elif event == 'shutdown':
@@ -213,11 +208,11 @@ class FamilyMember(automat.Automat):
                 self.doPush(event, *args, **kwargs)
             elif event == 'contacts-received':
                 self.doCheckReply(*args, **kwargs)
-            elif ( event == 'all-suppliers-agree' or event == 'timer-10sec' ) and not self.isFamilyModified(*args, **kwargs):
+            elif (event == 'all-suppliers-agree' or event == 'timer-10sec') and not self.isFamilyModified(*args, **kwargs):
                 self.state = 'CONNECTED'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doNotifyConnected(*args, **kwargs)
-            elif ( event == 'timer-10sec' or event == 'all-suppliers-agree' ) and self.isFamilyModified(*args, **kwargs):
+            elif (event == 'timer-10sec' or event == 'all-suppliers-agree') and self.isFamilyModified(*args, **kwargs):
                 self.state = 'DHT_WRITE'
                 self.doDHTWrite(*args, **kwargs)
             elif event == 'one-supplier-not-agree':
@@ -229,19 +224,19 @@ class FamilyMember(automat.Automat):
                 self.doPush(event, *args, **kwargs)
             elif event == 'contacts-received':
                 self.doCheckReply(*args, **kwargs)
-            elif event == 'dht-write-fail' and not self.isLeaving(*args, **kwargs) and self.Attempts>3:
+            elif event == 'dht-write-fail' and not self.isLeaving(*args, **kwargs) and self.Attempts > 3:
                 self.state = 'DISCONNECTED'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doNotifyDisconnected(*args, **kwargs)
-            elif event == 'dht-write-fail' and not self.isLeaving(*args, **kwargs) and self.Attempts<=3:
+            elif event == 'dht-write-fail' and not self.isLeaving(*args, **kwargs) and self.Attempts <= 3:
                 self.state = 'DHT_READ'
                 self.doDHTRead(*args, **kwargs)
-            elif event == 'shutdown' or ( ( event == 'dht-write-fail' or event == 'dht-write-ok' ) and self.isLeaving(*args, **kwargs) ):
+            elif event == 'shutdown' or ((event == 'dht-write-fail' or event == 'dht-write-ok') and self.isLeaving(*args, **kwargs)):
                 self.state = 'CLOSED'
                 self.doDestroyMe(*args, **kwargs)
             elif event == 'dht-write-ok' and not self.isLeaving(*args, **kwargs):
                 self.state = 'CONNECTED'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doNotifyConnected(*args, **kwargs)
         #---CLOSED---
         elif self.state == 'CLOSED':
@@ -256,7 +251,7 @@ class FamilyMember(automat.Automat):
                 self.doNotifyDisconnected(*args, **kwargs)
             elif event == 'instant' and self.isAnyRequests(*args, **kwargs):
                 self.state = 'DHT_READ'
-                self.Attempts=0
+                self.Attempts = 0
                 self.doPull(*args, **kwargs)
                 self.doDHTRead(*args, **kwargs)
             elif event == 'family-refresh' or event == 'family-join' or event == 'family-leave':
@@ -322,7 +317,7 @@ class FamilyMember(automat.Automat):
         self.transaction = None
         self.dht_value_exists = False
         self.dht_read_use_cache = True
-        self.refresh_period = DHT_RECORD_REFRESH_INTERVAL * settings.DefaultDesiredSuppliers()
+        self.refresh_period = DHT_RECORD_REFRESH_INTERVAL*settings.DefaultDesiredSuppliers()
         self.refresh_task = LoopingCall(self._on_family_refresh_task)
 
     def doPush(self, event, *args, **kwargs):
@@ -353,11 +348,13 @@ class FamilyMember(automat.Automat):
             merged_info = self._do_merge_revisions(dht_info_valid, my_info_valid, latest_revision)
         if not merged_info:
             merged_info = self._do_create_first_revision(self.current_request)
+
+
 #         if not merged_info:
 #             lg.err('failed to merge customer family info after reading from DHT, skip transaction')
 #             self.transaction = None
 #             return
-        possible_transaction = self._do_process_request(merged_info, self.current_request) 
+        possible_transaction = self._do_process_request(merged_info, self.current_request)
         if not possible_transaction:
             lg.warn('failed to process customer family change request, skip transaction')
             return
@@ -368,7 +365,7 @@ class FamilyMember(automat.Automat):
             known_ecc_map = self.transaction.get('ecc_map')
             if known_ecc_map:
                 expected_suppliers_count = eccmap.GetEccMapSuppliersNumber(known_ecc_map)
-                self.refresh_period = DHT_RECORD_REFRESH_INTERVAL * expected_suppliers_count
+                self.refresh_period = DHT_RECORD_REFRESH_INTERVAL*expected_suppliers_count
 
     def doRequestSuppliersReview(self, *args, **kwargs):
         """
@@ -433,8 +430,7 @@ class FamilyMember(automat.Automat):
                     self.transaction = None
                 else:
                     self.transaction['suppliers'][another_supplier_position] = another_supplier_idurl
-                    lg.info('found desired position %d in the family and solved conflict with supplier %s' % (
-                        another_supplier_position, another_supplier_idurl, ))
+                    lg.info('found desired position %d in the family and solved conflict with supplier %s' % (another_supplier_position, another_supplier_idurl))
 
     def doDHTRead(self, *args, **kwargs):
         """
@@ -455,8 +451,7 @@ class FamilyMember(automat.Automat):
         Action method.
         """
         if _Debug:
-            lg.out(_DebugLevel, 'family_member.doNotifyConnected\n            my_info=%r\n            dht_info=%r\n            requests=%r' % (
-                self.my_info, self.dht_info, self.requests, ))
+            lg.out(_DebugLevel, 'family_member.doNotifyConnected\n            my_info=%r\n            dht_info=%r\n            requests=%r' % (self.my_info, self.dht_info, self.requests))
         to_be_closed = False
         if self.current_request['command'] == 'family-leave':
             to_be_closed = True
@@ -613,11 +608,14 @@ class FamilyMember(automat.Automat):
                 another_suppliers[possible_position] = my_id.getIDURL().to_bin()
             except:
                 lg.exc()
-            contactsdb.add_customer_meta_info(self.customer_idurl, {
-                'ecc_map': another_ecc_map,
-                'position': possible_position,
-                'family_snapshot': id_url.to_bin_list(another_suppliers),
-            })
+            contactsdb.add_customer_meta_info(
+                self.customer_idurl,
+                {
+                    'ecc_map': another_ecc_map,
+                    'position': possible_position,
+                    'family_snapshot': id_url.to_bin_list(another_suppliers),
+                },
+            )
         return {
             'revision': int(another_revision),
             'publisher_idurl': my_id.getIDURL(),  # I will be a publisher of that revision
@@ -642,7 +640,7 @@ class FamilyMember(automat.Automat):
         if my_revision > dht_revision:
             # TODO: SECURITY need to find a solution to prevent cheating here
             # another supplier could publish a record where he is only alone present and with a correct revision
-            # that means he actually brutally dropped all other suppliers from the family 
+            # that means he actually brutally dropped all other suppliers from the family
             lg.info('known DHT info for customer %s is more fresh, will rewrite DHT record' % self.customer_idurl)
             if my_revision > dht_revision + 1:
                 lg.warn('switching revision too far, normally always increase by one on every change')
@@ -665,7 +663,7 @@ class FamilyMember(automat.Automat):
                             # here my revision is higher, so I have some changes that needs to be published already
                             merged_info = my_info
                         else:
-                            # here my revision is lower, I need to take info from DHT 
+                            # here my revision is lower, I need to take info from DHT
                             merged_info = dht_info
                 else:
                     merged_info = dht_info
@@ -682,11 +680,13 @@ class FamilyMember(automat.Automat):
         if merged_info['ecc_map']:
             expected_suppliers_count = eccmap.GetEccMapSuppliersNumber(merged_info['ecc_map'])
             if len(merged_info['suppliers']) < expected_suppliers_count:
-                merged_info['suppliers'] += [b'', ] * (expected_suppliers_count - len(merged_info['suppliers']))
+                merged_info['suppliers'] += [
+                    b'',
+                ]*(expected_suppliers_count - len(merged_info['suppliers']))
             elif len(merged_info['suppliers']) > expected_suppliers_count:
                 merged_info['suppliers'] = merged_info['suppliers'][:expected_suppliers_count]
         if merged_info['revision'] != latest_revision:
-            lg.info('will switch known revision %d to the latest: %d' % (merged_info['revision'], latest_revision, )) 
+            lg.info('will switch known revision %d to the latest: %d' % (merged_info['revision'], latest_revision))
         merged_info['revision'] = latest_revision
         if _Debug:
             lg.out(_DebugLevel, '    merged_info=%r' % merged_info)
@@ -697,8 +697,7 @@ class FamilyMember(automat.Automat):
             possible_transaction['customer_idurl'] = self.customer_idurl
             possible_transaction['revision'] += 1
             possible_transaction['publisher_idurl'] = my_id.getIDURL()
-            lg.info('incremented family revision after customer %r identity rotated: %r' % (
-                self.customer_idurl, possible_transaction['revision'], ))
+            lg.info('incremented family revision after customer %r identity rotated: %r' % (self.customer_idurl, possible_transaction['revision']))
             return possible_transaction
         if self.dht_info:
             if self.dht_info['suppliers'] == possible_transaction['suppliers']:
@@ -721,17 +720,14 @@ class FamilyMember(automat.Automat):
         if current_request['ecc_map']:
             current_request_expected_suppliers_count = eccmap.GetEccMapSuppliersNumber(current_request['ecc_map'])
         if current_request_expected_suppliers_count and current_request.get('position') and current_request['position'] >= current_request_expected_suppliers_count:
-            lg.warn('"family-join" request is not valid, supplier position %d greater than expected suppliers count %d for %s' % (
-                current_request['position'], current_request_expected_suppliers_count, current_request['ecc_map']))
+            lg.warn('"family-join" request is not valid, supplier position %d greater than expected suppliers count %d for %s' % (current_request['position'], current_request_expected_suppliers_count, current_request['ecc_map']))
             return None
 
         if merged_info['ecc_map'] and current_request['ecc_map'] and current_request['ecc_map'] != merged_info['ecc_map']:
-            lg.info('from "family-join" request, detected ecc_map change %s -> %s for customer %s' % (
-                merged_info['ecc_map'], current_request['ecc_map'], self.customer_idurl))
+            lg.info('from "family-join" request, detected ecc_map change %s -> %s for customer %s' % (merged_info['ecc_map'], current_request['ecc_map'], self.customer_idurl))
             merged_info['ecc_map'] = current_request['ecc_map']
         if not merged_info['ecc_map'] and current_request['ecc_map']:
-            lg.info('from "family-join" request, detected ecc_map was set to %s for the first time for customer %s' % (
-                current_request['ecc_map'], self.customer_idurl))
+            lg.info('from "family-join" request, detected ecc_map was set to %s for the first time for customer %s' % (current_request['ecc_map'], self.customer_idurl))
             merged_info['ecc_map'] = current_request['ecc_map']
         if not merged_info['ecc_map']:
             known_ecc_map = contactsdb.get_customer_meta_info(self.customer_idurl).get('ecc_map', None)
@@ -744,10 +740,14 @@ class FamilyMember(automat.Automat):
 
         expected_suppliers_count = eccmap.GetEccMapSuppliersNumber(merged_info['ecc_map'])
         if not merged_info['suppliers']:
-            merged_info['suppliers'] = [b'', ] * expected_suppliers_count
+            merged_info['suppliers'] = [
+                b'',
+            ]*expected_suppliers_count
 
         if len(merged_info['suppliers']) < expected_suppliers_count:
-            merged_info['suppliers'] += [b'', ] * (expected_suppliers_count - len(merged_info['suppliers']))
+            merged_info['suppliers'] += [
+                b'',
+            ]*(expected_suppliers_count - len(merged_info['suppliers']))
         else:
             merged_info['suppliers'] = merged_info['suppliers'][:expected_suppliers_count]
 
@@ -764,31 +764,26 @@ class FamilyMember(automat.Automat):
                 merged_info['suppliers'][existing_position] = b''
                 merged_info['suppliers'][current_request['position']] = current_request['supplier_idurl']
                 if _Debug:
-                    lg.out(_DebugLevel, '    found my IDURL on %d position and will move it on %d position in the family of customer %s' % (
-                        existing_position, current_request['position'], self.customer_idurl))
+                    lg.out(_DebugLevel, '    found my IDURL on %d position and will move it on %d position in the family of customer %s' % (existing_position, current_request['position'], self.customer_idurl))
             if merged_info['suppliers'][current_request['position']] != current_request['supplier_idurl']:
                 if merged_info['suppliers'][current_request['position']]:
                     # TODO: SECURITY need to implement a signature verification and
                     # also build solution to validate that change was approved by customer
-                    lg.warn('overwriting another supplier %s with my IDURL at position %d in family of customer %s' % (
-                        merged_info['suppliers'][current_request['position']], current_request['position'], self.customer_idurl, ))
+                    lg.warn('overwriting another supplier %s with my IDURL at position %d in family of customer %s' % (merged_info['suppliers'][current_request['position']], current_request['position'], self.customer_idurl))
                 merged_info['suppliers'][current_request['position']] = current_request['supplier_idurl']
                 if _Debug:
-                    lg.out(_DebugLevel, '    placed supplier %s at known position %d in the family of customer %s' % (
-                        current_request['supplier_idurl'], current_request['position'], self.customer_idurl))
+                    lg.out(_DebugLevel, '    placed supplier %s at known position %d in the family of customer %s' % (current_request['supplier_idurl'], current_request['position'], self.customer_idurl))
 
         if current_request['supplier_idurl'] not in merged_info['suppliers']:
             if b'' in merged_info['suppliers']:
                 first_empty_position = merged_info['suppliers'].index(b'')
                 merged_info['suppliers'][first_empty_position] = current_request['supplier_idurl']
                 if _Debug:
-                    lg.out(_DebugLevel, '    placed supplier %s at first empty position %d in family of customer %s' % (
-                        current_request['supplier_idurl'], first_empty_position, self.customer_idurl))
+                    lg.out(_DebugLevel, '    placed supplier %s at first empty position %d in family of customer %s' % (current_request['supplier_idurl'], first_empty_position, self.customer_idurl))
             else:
                 merged_info['suppliers'].append(current_request['supplier_idurl'])
                 if _Debug:
-                    lg.out(_DebugLevel, '    added supplier %s to family of customer %s' % (
-                        current_request['supplier_idurl'], self.customer_idurl))
+                    lg.out(_DebugLevel, '    added supplier %s to family of customer %s' % (current_request['supplier_idurl'], self.customer_idurl))
 
         if current_request.get('family_snapshot'):
             for supplier_position in range(len(merged_info['suppliers'])):
@@ -796,8 +791,7 @@ class FamilyMember(automat.Automat):
                     if not merged_info['suppliers'][supplier_position] and current_request['family_snapshot'][supplier_position]:
                         merged_info['suppliers'][supplier_position] = current_request['family_snapshot'][supplier_position]
                         if _Debug:
-                            lg.out(_DebugLevel, '    found empty supplier at position %d and populated from current request: %s' % (
-                                supplier_position, merged_info['suppliers'][supplier_position]))
+                            lg.out(_DebugLevel, '    found empty supplier at position %d and populated from current request: %s' % (supplier_position, merged_info['suppliers'][supplier_position]))
 
         return merged_info
 
@@ -811,12 +805,10 @@ class FamilyMember(automat.Automat):
 
         if current_request.get('ecc_map'):
             if merged_info['ecc_map'] and current_request.get('ecc_map') and current_request.get('ecc_map') != merged_info['ecc_map']:
-                lg.info('from "family-leave" request, detected ecc_map change %s -> %s for customer %s' % (
-                    merged_info['ecc_map'], current_request['ecc_map'], self.customer_idurl))
+                lg.info('from "family-leave" request, detected ecc_map change %s -> %s for customer %s' % (merged_info['ecc_map'], current_request['ecc_map'], self.customer_idurl))
                 merged_info['ecc_map'] = current_request['ecc_map']
             if not merged_info['ecc_map'] and current_request['ecc_map']:
-                lg.info('from "family-leave" request, detected ecc_map was set to %s for the first time for customer %s' % (
-                    current_request['ecc_map'], self.customer_idurl))
+                lg.info('from "family-leave" request, detected ecc_map was set to %s for the first time for customer %s' % (current_request['ecc_map'], self.customer_idurl))
                 merged_info['ecc_map'] = current_request['ecc_map']
 
         if not merged_info['ecc_map']:
@@ -825,23 +817,25 @@ class FamilyMember(automat.Automat):
 
         expected_suppliers_count = eccmap.GetEccMapSuppliersNumber(merged_info['ecc_map'])
         if not merged_info['suppliers']:
-            merged_info['suppliers'] = [b'', ] * expected_suppliers_count
+            merged_info['suppliers'] = [
+                b'',
+            ]*expected_suppliers_count
 
         if len(merged_info['suppliers']) < expected_suppliers_count:
-            merged_info['suppliers'] += [b'', ] * (expected_suppliers_count - len(merged_info['suppliers']))
+            merged_info['suppliers'] += [
+                b'',
+            ]*(expected_suppliers_count - len(merged_info['suppliers']))
         else:
             merged_info['suppliers'] = merged_info['suppliers'][:expected_suppliers_count]
 
         if existing_position < 0:
             if _Debug:
-                lg.dbg(_DebugLevel, 'supplier %r not found in customer family %r, probably already left' % (
-                       current_request['supplier_idurl'], self.customer_idurl, ))
+                lg.dbg(_DebugLevel, 'supplier %r not found in customer family %r, probably already left' % (current_request['supplier_idurl'], self.customer_idurl))
         else:
             if existing_position < expected_suppliers_count:
                 merged_info['suppliers'][existing_position] = b''
                 if _Debug:
-                    lg.info('erasing supplier %r from customer family %r' % (
-                        current_request['supplier_idurl'], self.customer_idurl, ))
+                    lg.info('erasing supplier %r from customer family %r' % (current_request['supplier_idurl'], self.customer_idurl))
         return merged_info
 
     def _do_process_family_refresh_request(self, merged_info):
@@ -873,7 +867,9 @@ class FamilyMember(automat.Automat):
         if my_expected_suppliers_count and len(merged_info['suppliers']) != my_expected_suppliers_count:
             lg.warn('number of suppliers not expected during processing of "family-refresh" request')
             if len(merged_info['suppliers']) < my_expected_suppliers_count:
-                merged_info['suppliers'] += [b'', ] * (my_expected_suppliers_count - len(merged_info['suppliers']))
+                merged_info['suppliers'] += [
+                    b'',
+                ]*(my_expected_suppliers_count - len(merged_info['suppliers']))
             else:
                 merged_info['suppliers'] = merged_info['suppliers'][:my_expected_suppliers_count]
 
@@ -885,20 +881,17 @@ class FamilyMember(automat.Automat):
             if merged_info['suppliers'][my_position]:
                 # TODO: SECURITY need to implement a signature verification and
                 # also build solution to validate that change was approved by customer
-                lg.warn('overwriting another supplier %s with my IDURL at position %d in family of customer %s' % (
-                    merged_info['suppliers'][my_position], my_position, self.customer_idurl, ))
+                lg.warn('overwriting another supplier %s with my IDURL at position %d in family of customer %s' % (merged_info['suppliers'][my_position], my_position, self.customer_idurl))
             merged_info['suppliers'][my_position] = my_id.getIDURL().to_bin()
             if _Debug:
-                lg.out(_DebugLevel, '    placed supplier %s at known position %d in the family of customer %s' % (
-                    my_id.getIDURL(), my_position, self.customer_idurl))
+                lg.out(_DebugLevel, '    placed supplier %s at known position %d in the family of customer %s' % (my_id.getIDURL(), my_position, self.customer_idurl))
             existing_position = my_position
 
         if existing_position != my_position:
             merged_info['suppliers'][existing_position] = b''
             merged_info['suppliers'][my_position] = my_id.getIDURL().to_bin()
             if _Debug:
-                lg.out(_DebugLevel, '    found my IDURL on %d position and will move it on %d position in the family of customer %s' % (
-                existing_position, my_position, self.customer_idurl))
+                lg.out(_DebugLevel, '    found my IDURL on %d position and will move it on %d position in the family of customer %s' % (existing_position, my_position, self.customer_idurl))
         return merged_info
 
     def _do_process_request(self, merged_info, current_request):
@@ -913,7 +906,7 @@ class FamilyMember(automat.Automat):
 
     def _do_write_transaction(self, retries):
         if _Debug:
-            lg.out(_DebugLevel, 'family_member._do_write_transaction  suppliers=%d  retries=%d' % (len(self.transaction['suppliers']), retries, ))
+            lg.out(_DebugLevel, 'family_member._do_write_transaction  suppliers=%d  retries=%d' % (len(self.transaction['suppliers']), retries))
         d = dht_relations.write_customer_suppliers(
             customer_idurl=self.customer_idurl,
             suppliers_list=self.transaction['suppliers'],
@@ -976,7 +969,7 @@ class FamilyMember(automat.Automat):
         lg.err('failed to write family info for %s : %s' % (self.customer_idurl, err_msg))
         if err_msg.count('current revision is') and retries < 3:
             try:
-                current_revision = re.search("current revision is (\d+)", err_msg).group(1)
+                current_revision = re.search('current revision is (\d+)', err_msg).group(1)
                 current_revision = int(current_revision)
             except:
                 lg.exc()
@@ -1061,7 +1054,7 @@ class FamilyMember(automat.Automat):
         })
         if _Debug:
             lg.out(_DebugLevel, 'family_member._on_incoming_supplier_position stored new meta info for customer %s:\n' % self.customer_idurl)
-            lg.out(_DebugLevel, '    ecc_map=%s position=%s family_snapshot=%s' % (ecc_map, supplier_position, family_snapshot, ))
+            lg.out(_DebugLevel, '    ecc_map=%s position=%s family_snapshot=%s' % (ecc_map, supplier_position, family_snapshot))
         return p2p_service.SendAck(incoming_packet)
 
     def _on_incoming_contacts_packet(self, inp):
@@ -1105,5 +1098,4 @@ class FamilyMember(automat.Automat):
             return None
         if _Debug:
             lg.args(_DebugLevel, ecc_map=ecc_map, suppliers_list=suppliers_list, supplier_idurl=response.OwnerID.to_bin())
-        self.automat('one-supplier-not-agree',
-                     ecc_map=ecc_map, suppliers_list=suppliers_list, supplier_idurl=response.OwnerID.to_bin())
+        self.automat('one-supplier-not-agree', ecc_map=ecc_map, suppliers_list=suppliers_list, supplier_idurl=response.OwnerID.to_bin())
