@@ -82,6 +82,8 @@ def init():
     if Linux() or Mac():
         lg.setup_unbuffered_stdout()
         lg.setup_unbuffered_stderr()
+    if Windows():
+        import encodings.idna  # nopycln: import  # @UnusedImport
 
 
 def shutdown():
@@ -236,6 +238,8 @@ def isConsoled():
     """
     if getExecutableFilename().count('pythonw.exe'):
         return False
+    if getExecutableFilename().count('bitdust-node.exe'):
+        return False
     if not sys.stdout:
         return False
     return True
@@ -1270,6 +1274,8 @@ def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file
     if Android():
         return []
     q = [
+        'bitdust-node.exe',
+        'bitdust-console.exe',
         'bitdustnode.exe',
         'BitDustNode.exe',
         'BitDustConsole.exe',  # 'bitdust.py',
@@ -1292,14 +1298,18 @@ def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file
     try:
         if not pid_file_path:
             from bitdust.main import settings
-            pid_file_path = os.path.join(settings.MetaDataDir(), 'processid')
+            pid_file_path = os.path.join(settings.AppDataDir(), 'processid')
         processid = int(ReadTextFile(pid_file_path))
     except:
         processid = None
     if not processid:
         return appList
     if processid not in appList:
-        return []
+        try:
+            os.remove(pid_file_path)
+        except:
+            pass
+        return appList
     return [
         processid,
     ]
@@ -1307,6 +1317,8 @@ def find_main_process(pid_file_path=None, extra_lookups=[], check_processid_file
 
 def lookup_main_process():
     q = [
+        'bitdust-node.exe',
+        'bitdust-console.exe',
         'bitdustnode.exe',
         'BitDustNode.exe',
         'BitDustConsole.exe',
