@@ -19,7 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
 """
 .. module:: proxy_receiver.
 
@@ -78,40 +77,41 @@ from twisted.internet import reactor  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from lib import packetid
-from lib import strng
-from lib import serialization
-from lib import net_misc
+from bitdust.lib import packetid
+from bitdust.lib import strng
+from bitdust.lib import serialization
+from bitdust.lib import net_misc
 
-from automats import automat
+from bitdust.automats import automat
 
-from main import config
+from bitdust.main import config
+from bitdust.main import settings
 
-from crypt import key
-from crypt import signed
-from crypt import encrypted
+from bitdust.crypt import key
+from bitdust.crypt import signed
+from bitdust.crypt import encrypted
 
-from p2p import commands
-from p2p import lookup
-from p2p import online_status
+from bitdust.p2p import commands
+from bitdust.p2p import lookup
+from bitdust.p2p import online_status
 
-from contacts import identitycache
+from bitdust.contacts import identitycache
 
-from services import driver
+from bitdust.services import driver
 
-from transport import callback
-from transport import packet_in
-from transport import packet_out
+from bitdust.transport import callback
+from bitdust.transport import packet_in
+from bitdust.transport import packet_out
 
-from transport import gateway
-from transport.proxy import proxy_interface
+from bitdust.transport import gateway
+from bitdust.transport.proxy import proxy_interface
 
-from userid import identity
-from userid import global_id
-from userid import id_url
-from userid import my_id
+from bitdust.userid import identity
+from bitdust.userid import global_id
+from bitdust.userid import id_url
+from bitdust.userid import my_id
 
 #------------------------------------------------------------------------------
 
@@ -119,6 +119,7 @@ _ProxyReceiver = None
 
 #------------------------------------------------------------------------------
 
+
 def GetRouterIDURL():
     global _ProxyReceiver
     if not _ProxyReceiver:
@@ -175,6 +176,7 @@ def LatestPacketReceived():
         return 0
     return _ProxyReceiver.latest_packet_received
 
+
 #------------------------------------------------------------------------------
 
 
@@ -192,6 +194,7 @@ def A(event=None, *args, **kwargs):
         _ProxyReceiver.automat(event, *args, **kwargs)
     return _ProxyReceiver
 
+
 #------------------------------------------------------------------------------
 
 
@@ -234,22 +237,24 @@ class ProxyReceiver(automat.Automat):
 
     def to_json(self):
         j = super().to_json()
-        j.update({
-            'proto': self.router_proto_host[0] if self.router_proto_host else '',
-            'host': net_misc.pack_address(self.router_proto_host[1]) if self.router_proto_host else '',
-            'idurl': self.router_idurl,
-            'bytes_received': self.traffic_in,
-            'bytes_sent': 0,
-            'connection_info': self.router_connection_info,
-            'idle_seconds': int(time.time() - self.latest_packet_received),
-        })
+        j.update(
+            {
+                'proto': self.router_proto_host[0] if self.router_proto_host else '',
+                'host': net_misc.pack_address(self.router_proto_host[1]) if self.router_proto_host else '',
+                'idurl': self.router_idurl,
+                'bytes_received': self.traffic_in,
+                'bytes_sent': 0,
+                'connection_info': self.router_connection_info,
+                'idle_seconds': int(time.time() - self.latest_packet_received),
+            }
+        )
         return j
 
     def state_changed(self, oldstate, newstate, event, *args, **kwargs):
         """
         Method to catch the moment when proxy_receiver() state were changed.
         """
-        from transport.proxy import proxy_sender
+        from bitdust.transport.proxy import proxy_sender
         proxy_sender.A('proxy_receiver.state', newstate)
 
     def A(self, event, *args, **kwargs):
@@ -277,9 +282,9 @@ class ProxyReceiver(automat.Automat):
                 self.state = 'OFFLINE'
                 self.doNotifyFailed(*args, **kwargs)
             elif event == 'sending-failed':
-                self.Retries+=1
+                self.Retries += 1
                 self.doSendMyIdentity(*args, **kwargs)
-            elif ( event == 'sending-failed' and self.Retries>3 ) or event == 'ack-timeout' or event == 'fail-received' or event == 'timer-15sec':
+            elif (event == 'sending-failed' and self.Retries > 3) or event == 'ack-timeout' or event == 'fail-received' or event == 'timer-15sec':
                 self.state = 'FIND_NODE?'
                 self.doLookupRandomNode(*args, **kwargs)
         #---LISTEN---
@@ -309,7 +314,7 @@ class ProxyReceiver(automat.Automat):
             if event == 'found-one-node':
                 self.state = 'ACK?'
                 self.doRememberNode(*args, **kwargs)
-                self.Retries=0
+                self.Retries = 0
                 self.doSendMyIdentity(*args, **kwargs)
             elif event == 'shutdown':
                 self.state = 'CLOSED'
@@ -338,7 +343,7 @@ class ProxyReceiver(automat.Automat):
             if event == 'start' and self.isCurrentRouterExist(*args, **kwargs):
                 self.state = 'ACK?'
                 self.doLoadRouterInfo(*args, **kwargs)
-                self.Retries=0
+                self.Retries = 0
                 self.doSendMyIdentity(*args, **kwargs)
             elif event == 'start' and not self.isCurrentRouterExist(*args, **kwargs):
                 self.state = 'FIND_NODE?'
@@ -423,13 +428,21 @@ class ProxyReceiver(automat.Automat):
             my_id.getIDURL(),
             my_id.getIDURL(),
             packetid.UniqueID(),
-            serialization.DictToBytes({'name': 'service_proxy_server', }),
+            serialization.DictToBytes({
+                'name': 'service_proxy_server',
+            }),
             self.router_idurl,
         )
-        packet_out.create(newpacket, wide=True, callbacks={
-            commands.Ack(): self._on_request_service_ack,
-            commands.Fail(): self._on_request_service_fail,
-        })
+        packet_out.create(
+            newpacket,
+            wide=True,
+            callbacks={},
+            # callbacks={
+            #     commands.Ack(): self._on_request_service_ack,
+            #     commands.Fail(): self._on_request_service_fail,
+            # },
+            response_timeout=settings.P2PTimeOut(),
+        )
 
     def doProcessInboxPacket(self, *args, **kwargs):
         """
@@ -449,7 +462,7 @@ class ProxyReceiver(automat.Automat):
                 # TODO: move that setting to separate file
                 s = config.conf().getString('services/proxy-transport/current-router').strip()
                 _, router_proto, router_host = s.split(' ')
-                self.router_proto_host = (router_proto, strng.to_bin(router_host), )
+                self.router_proto_host = (router_proto, strng.to_bin(router_host))
             except:
                 lg.exc()
         self.router_identity = identitycache.FromCache(self.router_idurl)
@@ -482,7 +495,7 @@ class ProxyReceiver(automat.Automat):
                 newstate='OFFLINE',
             )
         active_router_session_machine.addStateChangedCallback(self._on_router_session_disconnected, oldstate='CONNECTED')
-        lg.info('router %s is connected at %s://%s' % (self.router_idurl, self.router_proto_host[0], self.router_proto_host[1], ))
+        lg.info('router %s is connected at %s://%s' % (self.router_idurl, self.router_proto_host[0], self.router_proto_host[1]))
         my_id.rebuildLocalIdentity()
 
     def doStopListening(self, *args, **kwargs):
@@ -543,7 +556,7 @@ class ProxyReceiver(automat.Automat):
         newidentity = identity.identity(xmlsrc=newxml)
         cachedidentity = identitycache.FromCache(self.router_idurl)
         if self.router_idurl != newidentity.getIDURL():
-            lg.warn('router idurl is unrecognized from response %r != %r' % (self.router_idurl, newidentity.getIDURL(), ))
+            lg.warn('router idurl is unrecognized from response %r != %r' % (self.router_idurl, newidentity.getIDURL()))
             return
         if newidentity.serialize() != cachedidentity.serialize():
             lg.warn('cached identity is not same, router identity changed')
@@ -576,8 +589,9 @@ class ProxyReceiver(automat.Automat):
         """
         Action method.
         """
-        proxy_interface.interface_receiving_started(
-            self.router_idurl, {'router_idurl': self.router_idurl, },)
+        proxy_interface.interface_receiving_started(self.router_idurl, {
+            'router_idurl': self.router_idurl,
+        })
 
     def doNotifyDisconnected(self, *args, **kwargs):
         """
@@ -640,14 +654,13 @@ class ProxyReceiver(automat.Automat):
                 lg.exc()
                 return
             if _Debug:
-                lg.out(_DebugLevel, '<<<Relay-ACK %s:%s from %s://%s with %d bytes %s' % (
-                    ack_info['command'], ack_info['packet_id'], info.proto, info.host, len(data), ack_info['error'], ))
+                lg.out(_DebugLevel, '<<<Relay-ACK %s:%s from %s://%s with %d bytes %s' % (ack_info['command'], ack_info['packet_id'], info.proto, info.host, len(data), ack_info['error']))
             if _PacketLogFileEnabled:
-                lg.out(0, '                \033[0;49;33mRELAY ACK %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
-                    ack_info['command'], ack_info['packet_id'], info.bytes_received,
-                    global_id.UrlToGlobalID(ack_info['from']), global_id.UrlToGlobalID(ack_info['to']),
-                    info.transfer_id), log_name='packet', showtime=True)
-            from transport.proxy import proxy_sender
+                lg.out(
+                    0, '                \033[0;49;33mRELAY ACK %s(%s) with %d bytes from %s to %s TID:%s\033[0m' %
+                    (ack_info['command'], ack_info['packet_id'], info.bytes_received, global_id.UrlToGlobalID(ack_info['from']), global_id.UrlToGlobalID(ack_info['to']), info.transfer_id), log_name='packet', showtime=True
+                )
+            from bitdust.transport.proxy import proxy_sender
             if proxy_sender.A():
                 proxy_sender.A('relay-ack', ack_info, info)
             return True
@@ -659,14 +672,13 @@ class ProxyReceiver(automat.Automat):
                 lg.exc()
                 return
             if _Debug:
-                lg.out(_DebugLevel, '<<<Relay-FAIL %s:%s from %s://%s with %d bytes %s' % (
-                    fail_info['command'], fail_info['packet_id'], info.proto, info.host, len(data), fail_info['error'], ))
+                lg.out(_DebugLevel, '<<<Relay-FAIL %s:%s from %s://%s with %d bytes %s' % (fail_info['command'], fail_info['packet_id'], info.proto, info.host, len(data), fail_info['error']))
             if _PacketLogFileEnabled:
-                lg.out(0, '                \033[0;49;33mRELAY FAIL %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
-                    fail_info['command'], fail_info['packet_id'], info.bytes_received,
-                    global_id.UrlToGlobalID(fail_info['from']), global_id.UrlToGlobalID(fail_info['to']),
-                    info.transfer_id), log_name='packet', showtime=True)
-            from transport.proxy import proxy_sender
+                lg.out(
+                    0, '                \033[0;49;33mRELAY FAIL %s(%s) with %d bytes from %s to %s TID:%s\033[0m' %
+                    (fail_info['command'], fail_info['packet_id'], info.bytes_received, global_id.UrlToGlobalID(fail_info['from']), global_id.UrlToGlobalID(fail_info['to']), info.transfer_id), log_name='packet', showtime=True
+                )
+            from bitdust.transport.proxy import proxy_sender
             if proxy_sender.A():
                 proxy_sender.A('relay-failed', fail_info, info)
             return True
@@ -677,13 +689,12 @@ class ProxyReceiver(automat.Automat):
             return
 
         if _Debug:
-            lg.out(_DebugLevel, '<<<Relay-IN %s from %s://%s with %d bytes' % (
-                str(routed_packet), info.proto, info.host, len(data)))
+            lg.out(_DebugLevel, '<<<Relay-IN %s from %s://%s with %d bytes' % (str(routed_packet), info.proto, info.host, len(data)))
         if _PacketLogFileEnabled:
-            lg.out(0, '                \033[0;49;33mRELAY IN %s(%s) with %d bytes from %s to %s TID:%s\033[0m' % (
-                routed_packet.Command, routed_packet.PacketID, info.bytes_received,
-                global_id.UrlToGlobalID(info.sender_idurl), global_id.UrlToGlobalID(routed_packet.RemoteID),
-                info.transfer_id), log_name='packet', showtime=True)
+            lg.out(
+                0, '                \033[0;49;33mRELAY IN %s(%s) with %d bytes from %s to %s TID:%s\033[0m' %
+                (routed_packet.Command, routed_packet.PacketID, info.bytes_received, global_id.UrlToGlobalID(info.sender_idurl), global_id.UrlToGlobalID(routed_packet.RemoteID), info.transfer_id), log_name='packet', showtime=True
+            )
 
         if routed_packet.Command == commands.Identity():
             if _Debug:
@@ -691,12 +702,15 @@ class ProxyReceiver(automat.Automat):
             newidentity = identity.identity(xmlsrc=routed_packet.Payload)
             idurl = newidentity.getIDURL()
             if not identitycache.HasKey(idurl):
-                lg.info('received new identity %s rev %r' % (idurl.original(), newidentity.getRevisionValue(), ))
+                lg.info('received new identity %s rev %r' % (idurl.original(), newidentity.getRevisionValue()))
             if not identitycache.UpdateAfterChecking(idurl, routed_packet.Payload):
-                lg.warn("ERROR has non-Valid identity")
+                lg.warn('ERROR has non-Valid identity')
                 return
 
-        if routed_packet.Command in [commands.Relay(), commands.RelayIn(), ] and routed_packet.PacketID.lower().startswith('identity:'):
+        if routed_packet.Command in [
+            commands.Relay(),
+            commands.RelayIn(),
+        ] and routed_packet.PacketID.lower().startswith('identity:'):
             if _Debug:
                 lg.out(_DebugLevel, '    found routed identity in relay packet %s' % routed_packet)
             try:
@@ -706,7 +720,7 @@ class ProxyReceiver(automat.Automat):
                 if not identitycache.HasKey(idurl):
                     lg.warn('received new "routed" identity: %s' % idurl)
                 if not identitycache.UpdateAfterChecking(idurl, routed_identity.Payload):
-                    lg.warn("ERROR has non-Valid identity")
+                    lg.warn('ERROR has non-Valid identity')
                     return
             except:
                 lg.exc()
@@ -714,7 +728,7 @@ class ProxyReceiver(automat.Automat):
         if newpacket.Command == commands.RelayIn() and routed_packet.Command == commands.Fail():
             if routed_packet.Payload == b'route not exist' or routed_packet.Payload == b'route already closed':
                 for pout in packet_out.search_by_packet_id(routed_packet.PacketID):
-                    lg.warn('received %r from %r, outgoing packet is failed: %r' % (routed_packet.Payload, newpacket.CreatorID, pout, ))
+                    lg.warn('received %r from %r, outgoing packet is failed: %r' % (routed_packet.Payload, newpacket.CreatorID, pout))
                     pout.automat('request-failed')
                 return
 
@@ -735,8 +749,7 @@ class ProxyReceiver(automat.Automat):
             return
         if _Debug:
             lg.out(_DebugLevel, 'proxy_receiver._do_send_identity_to_router to %s' % self.router_idurl)
-            lg.out(_DebugLevel, '        contacts=%r, sources=%r' % (
-                identity_obj.contacts, identity_obj.getSources(as_originals=True)))
+            lg.out(_DebugLevel, '        contacts=%r, sources=%r' % (identity_obj.contacts, identity_obj.getSources(as_originals=True)))
         newpacket = signed.Packet(
             Command=commands.Identity(),
             OwnerID=my_id.getIDURL(),
@@ -755,7 +768,7 @@ class ProxyReceiver(automat.Automat):
                 'failed': lambda pkt_out, error_message: self.automat('sending-failed', (pkt_out, error_message)),
             },
             keep_alive=True,
-            response_timeout=30,
+            response_timeout=settings.P2PTimeOut(),
         )
 
     def _do_send_request_service(self, *args, **kwargs):
@@ -787,9 +800,10 @@ class ProxyReceiver(automat.Automat):
             callbacks={
                 commands.Ack(): self._on_request_service_ack,
                 commands.Fail(): self._on_request_service_fail,
+                # 'timeout': lambda pkt_out, err: self.automat('request-timeout', pkt_out),
                 None: lambda pkt_out: self.automat('request-timeout', pkt_out),
             },
-            response_timeout=30,
+            response_timeout=settings.P2PTimeOut(),
         )
         self.request_service_packet_id.append(newpacket.PacketID)
 
@@ -807,7 +821,7 @@ class ProxyReceiver(automat.Automat):
                 self.automat('found-one-node', self.possible_router_idurl)
                 return
         if attempts > 0:
-            self._find_random_node(attempts-1)
+            self._find_random_node(attempts - 1)
         else:
             self.automat('nodes-not-found')
 
@@ -837,8 +851,7 @@ class ProxyReceiver(automat.Automat):
     def _on_request_service_ack(self, response, info):
         self.router_connection_info = None
         if response.PacketID not in self.request_service_packet_id:
-            lg.warn('wrong PacketID in response: %s, but outgoing was : %s' % (
-                response.PacketID, str(self.request_service_packet_id)))
+            lg.warn('wrong PacketID in response: %s, but outgoing was : %s' % (response.PacketID, str(self.request_service_packet_id)))
             self.automat('service-refused', (response, info))
             return
         if response.PacketID in self.request_service_packet_id:
@@ -848,7 +861,7 @@ class ProxyReceiver(automat.Automat):
         if _Debug:
             lg.out(_DebugLevel, 'proxy_receiver._on_request_service_ack : %s' % str(response.Payload))
         if self.router_idurl != response.CreatorID:
-            lg.err('received unexpected response from another node: %r ~ %r' % (self.router_idurl, response.CreatorID, ))
+            lg.err('received unexpected response from another node: %r ~ %r' % (self.router_idurl, response.CreatorID))
             self.automat('service-refused', (response, info))
             return
         service_ack_info = strng.to_text(response.Payload)
@@ -859,7 +872,7 @@ class ProxyReceiver(automat.Automat):
         if not active_router_sessions:
             active_router_sessions = gateway.find_active_session(info.proto, idurl=id_url.to_bin(response.CreatorID))
         if not active_router_sessions:
-            lg.err('active connection with proxy router at %s:%s was not found' % (info.proto, info.host, ))
+            lg.err('active connection with proxy router at %s:%s was not found' % (info.proto, info.host))
             if _Debug:
                 lg.args(_DebugLevel, router_idurl=self.router_idurl, ack_packet=info, active_sessions=gateway.list_active_sessions(info.proto))
             self.automat('service-refused', (response, info))
@@ -886,8 +899,7 @@ class ProxyReceiver(automat.Automat):
 
     def _on_request_service_fail(self, response, info):
         if response.PacketID not in self.request_service_packet_id:
-            lg.warn('wrong PacketID in response: %s, but outgoing was : %s' % (
-                response.PacketID, str(self.request_service_packet_id)))
+            lg.warn('wrong PacketID in response: %s, but outgoing was : %s' % (response.PacketID, str(self.request_service_packet_id)))
         else:
             self.request_service_packet_id.remove(response.PacketID)
         self.automat('service-refused', (response, info))
@@ -901,7 +913,12 @@ class ProxyReceiver(automat.Automat):
             return True
         if newpacket.CreatorID == self.router_idurl:
             self.latest_packet_received = time.time()
-        if newpacket.Command in [commands.Relay(), commands.RelayIn(), commands.RelayAck(), commands.RelayFail(), ]:
+        if newpacket.Command in [
+            commands.Relay(),
+            commands.RelayIn(),
+            commands.RelayAck(),
+            commands.RelayFail(),
+        ]:
             if driver.is_enabled('service_proxy_server'):
                 # TODO:
                 # in case this node already running proxy router service this will not work
@@ -913,10 +930,10 @@ class ProxyReceiver(automat.Automat):
         return False
 
     def _on_router_contact_status_connected(self, oldstate, newstate, event_string, *args, **kwargs):
-        lg.info('router %r contact status online: %s->%s after "%s"' % (self.router_idurl, oldstate, newstate, event_string, ))
+        lg.info('router %r contact status online: %s->%s after "%s"' % (self.router_idurl, oldstate, newstate, event_string))
 
     def _on_router_contact_status_offline(self, oldstate, newstate, event_string, *args, **kwargs):
-        lg.warn('router %r contact status offline: %s->%s after "%s"' % (self.router_idurl, oldstate, newstate, event_string, ))
+        lg.warn('router %r contact status offline: %s->%s after "%s"' % (self.router_idurl, oldstate, newstate, event_string))
         # self.automat('router-disconnected')
 
     def _on_router_session_disconnected(self, oldstate, newstate, event_string, *args, **kwargs):
@@ -924,7 +941,7 @@ class ProxyReceiver(automat.Automat):
         self.automat('router-disconnected')
 
     def _on_queue_item_status_changed(self, pkt_out, status, error=''):
-        from transport.proxy import proxy_receiver
+        from bitdust.transport.proxy import proxy_receiver
         if status == 'finished':
             return False
         if error != 'connection failed':
@@ -937,17 +954,19 @@ class ProxyReceiver(automat.Automat):
             return False
         if pkt_out.remote_idurl != proxy_receiver.GetRouterIDURL():
             return False
-        lg.err('connection failed with current proxy router, must reconnect to another router: %r %r %r' % (pkt_out, status, error, ))
+        lg.err('connection failed with current proxy router, must reconnect to another router: %r %r %r' % (pkt_out, status, error))
         self.automat('router-disconnected')
         return True
 
+
 #------------------------------------------------------------------------------
 
+
 def main():
     from twisted.internet import reactor  # @UnresolvedImport
     reactor.callWhenRunning(A, 'init')  # @UndefinedVariable
     reactor.run()  # @UndefinedVariable
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
