@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: tcp_connection.
 
@@ -54,23 +52,29 @@ from twisted.protocols import basic  # @UnresolvedImport
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from lib import strng
-from lib import net_misc
+from bitdust.lib import strng
+from bitdust.lib import net_misc
 
 #------------------------------------------------------------------------------
 
-FIRST_PRIORITY_SHORT_FILE_SIZE = 64 * 1024
+FIRST_PRIORITY_SHORT_FILE_SIZE = 64*1024
 
 CMD_HELLO = b'h'
 CMD_WAZAP = b'w'
 CMD_DATA = b'd'
 CMD_OK = b'o'
 CMD_ABORT = b'a'
-CMD_LIST = [CMD_HELLO, CMD_WAZAP, CMD_DATA, CMD_OK, CMD_ABORT, ]
+CMD_LIST = [
+    CMD_HELLO,
+    CMD_WAZAP,
+    CMD_DATA,
+    CMD_OK,
+    CMD_ABORT,
+]
 
 #------------------------------------------------------------------------------
 
@@ -94,7 +98,9 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         self.last_wazap_received = 0
 
     def is_connected(self):
-        return self.state in ['CONNECTED', ]
+        return self.state in [
+            'CONNECTED',
+        ]
 
     def get_proto(self):
         return 'tcp'
@@ -169,7 +175,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
                 self.doReadWazap(*args, **kwargs)
                 self.doOpenStream(*args, **kwargs)
                 self.doStartPendingFiles(*args, **kwargs)
-            elif event == 'timer-10sec' or event == 'disconnect' or ( event == 'data-received' and not ( self.isWazap(*args, **kwargs) and self.isSomePendingFiles(*args, **kwargs) ) ):
+            elif event == 'timer-10sec' or event == 'disconnect' or (event == 'data-received' and not (self.isWazap(*args, **kwargs) and self.isSomePendingFiles(*args, **kwargs))):
                 self.state = 'DISCONNECT'
                 self.doDisconnect(*args, **kwargs)
         #---SERVER?---
@@ -183,7 +189,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
                 self.doSendWazap(*args, **kwargs)
                 self.doOpenStream(*args, **kwargs)
                 self.doStartPendingFiles(*args, **kwargs)
-            elif event == 'timer-10sec' or event == 'disconnect' or ( event == 'data-received' and not self.isHello(*args, **kwargs) ):
+            elif event == 'timer-10sec' or event == 'disconnect' or (event == 'data-received' and not self.isHello(*args, **kwargs)):
                 self.state = 'DISCONNECT'
                 self.doDisconnect(*args, **kwargs)
         #---CLOSED---
@@ -224,7 +230,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Condition method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         if self.getConnectionAddress() is not None:
             if self.getConnectionAddress() in list(tcp_node.started_connections().keys()):
                 return True
@@ -240,7 +246,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         self.peer_address = self.getTransportAddress()
         self.peer_external_address = self.peer_address
         self.connected = time.time()
@@ -249,14 +255,13 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         tcp_node.opened_connections()[self.peer_address].append(self)
         tcp_node.increase_connections_counter()
         if _Debug:
-            lg.out(_DebugLevel, 'tcp_connection.doInit with %s, total connections to that address : %d' % (
-                self.peer_address, len(tcp_node.opened_connections()[self.peer_address]), ))
+            lg.out(_DebugLevel, 'tcp_connection.doInit with %s, total connections to that address : %d' % (self.peer_address, len(tcp_node.opened_connections()[self.peer_address])))
 
     def doCloseOutgoing(self, *args, **kwargs):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         conn = tcp_node.started_connections().pop(self.getConnectionAddress())
         conn.connector = None
         # lg.out(18, 'tcp_connection.doCloseOutgoing    %s closed, %d more started' % (
@@ -266,7 +271,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         try:
             command, payload = args[0]
             peeraddress, peeridurl = payload.split(b' ')
@@ -292,8 +297,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
                 tcp_node.opened_connections()[self.peer_address] = []
             tcp_node.opened_connections()[self.peer_address].append(self)
             if _Debug:
-                lg.out(_DebugLevel, '%s : external peer address changed from %s to %s' % (
-                    self, old_address, self.peer_address))
+                lg.out(_DebugLevel, '%s : external peer address changed from %s to %s' % (self, old_address, self.peer_address))
         # lg.out(18, 'tcp_connection.doReadHello from %s' % (self.peer_idurl))
 
     def doReadWazap(self, *args, **kwargs):
@@ -330,7 +334,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         host = strng.to_bin(tcp_node.my_host() or '127.0.0.1:7771')
         idurl = strng.to_bin(tcp_node.my_idurl() or 'None')
         payload = host + b' ' + idurl
@@ -342,7 +346,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         payload = strng.to_bin(tcp_node.my_idurl() or 'None')
         self.sendData(CMD_WAZAP, payload)
 
@@ -367,7 +371,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_stream
+        from bitdust.transport.tcp import tcp_stream
         self.stream = tcp_stream.TCPFileStream(self)
 
     def doCloseStream(self, *args, **kwargs):
@@ -386,7 +390,11 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
             lg.out(_DebugLevel, 'tcp_connection.doDisconnect with %s %s' % (str(self.peer_address), self.peer_idurl))
         if self.factory:
             for filename, description, result_defer, keep_alive in self.factory.pendingoutboxfiles:
-                result_defer.callback((None, 'failed', 'disconnected', ))
+                result_defer.callback((
+                    None,
+                    'failed',
+                    'disconnected',
+                ))
             self.factory.pendingoutboxfiles = []
         try:
             self.transport.stopListening()
@@ -400,7 +408,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         """
         Action method.
         """
-        from transport.tcp import tcp_node
+        from bitdust.transport.tcp import tcp_node
         self.destroy()
         if self.peer_address in tcp_node.opened_connections():
             tcp_node.opened_connections()[self.peer_address].remove(self)
@@ -419,7 +427,10 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
 
     def getTransportAddress(self):
         peer = self.transport.getPeer()
-        return net_misc.normalize_address((peer.host, int(peer.port), ))
+        return net_misc.normalize_address((
+            peer.host,
+            int(peer.port),
+        ))
 
     def getConnectionAddress(self):
         return net_misc.normalize_address(self.factory.connection_address)
@@ -469,7 +480,7 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
             return False
         if self.stream is None:
             return False
-        from transport.tcp import tcp_stream
+        from bitdust.transport.tcp import tcp_stream
         has_reads = False
         while len(self.outboxQueue) > 0 and len(self.stream.outboxFiles) < tcp_stream.MAX_SIMULTANEOUS_OUTGOING_FILES:
             filename, description, result_defer, keep_alive = self.outboxQueue.pop(0)
@@ -493,11 +504,10 @@ class TCPConnection(automat.Automat, basic.Int32StringReceiver):
         return has_reads
 
     def failed_outbox_queue_item(self, filename, description='', error_message=''):
-        from transport.tcp import tcp_interface
+        from bitdust.transport.tcp import tcp_interface
         if _Debug:
             lg.out(_DebugLevel, 'tcp_connection.failed_outbox_queue_item %s because %s' % (filename, error_message))
         try:
-            tcp_interface.interface_cancelled_file_sending(
-                self.getAddress(), filename, 0, description, error_message).addErrback(lambda err: lg.exc(err))
+            tcp_interface.interface_cancelled_file_sending(self.getAddress(), filename, 0, description, error_message).addErrback(lambda err: lg.exc(err))
         except Exception as exc:
             lg.warn(str(exc))
