@@ -23,7 +23,6 @@
 #
 #
 #
-
 """
 .. module:: global_id.
 
@@ -36,7 +35,7 @@ import re
 
 #------------------------------------------------------------------------------
 
-from lib import strng
+from bitdust.lib import strng
 
 #------------------------------------------------------------------------------
 
@@ -58,6 +57,7 @@ _REGEX_OBJ_GLOBAL_ID_QUEUE_ID = None
 
 #------------------------------------------------------------------------------
 
+
 def idurl2glob(idurl):
     """
     Alias.
@@ -71,16 +71,20 @@ def glob2idurl(glob_id, as_field=True):
     """
     return GlobalUserToIDURL(glob_id, as_field=as_field)
 
+
 #------------------------------------------------------------------------------
 
+
 def MakeGlobalKeyID(key_alias, user_id):
     return _FORMAT_GLOBAL_ID_KEY_USER.format(
         key_alias=key_alias,
         user=user_id,
     )
 
+
 #------------------------------------------------------------------------------
 
+
 def MakeGlobalID(
     idurl=None,
     user=None,
@@ -111,7 +115,7 @@ def MakeGlobalID(
                 user_and_key, _, _ = customer.rpartition('@')
                 _, _, key_alias = user_and_key.rpartition('!')
         if idurl:
-            from lib import nameurl
+            from bitdust.lib import nameurl
             _, idhost, port, filename = nameurl.UrlParse(idurl)
             if port:
                 idhost += '_' + str(port)
@@ -171,18 +175,18 @@ def ParseGlobalID(inp, detect_version=False, as_field=True, fast=True):
         }
     """
     result = {
-        "user": "",
-        "key_alias": "",
-        "key_id": "",
-        "idhost": "",
-        "customer": "",
-        "idurl": b'',
-        "path": "",
-        "version": "",
+        'user': '',
+        'key_alias': '',
+        'key_id': '',
+        'idhost': '',
+        'customer': '',
+        'idurl': b'',
+        'path': '',
+        'version': '',
     }
     if not inp:
         if as_field:
-            from userid import id_url
+            from bitdust.userid import id_url
             result['idurl'] = id_url.field(result['idurl'])
         return result
     inp = strng.to_text(inp)
@@ -229,7 +233,7 @@ def ParseGlobalID(inp, detect_version=False, as_field=True, fast=True):
             except:
                 port = -1
             if port >= 0:
-                result['idhost'] = "%s:%d" % (result['idhost'][:_pos], port)
+                result['idhost'] = '%s:%d' % (result['idhost'][:_pos], port)
         if result['user'] and result['idhost']:
             result['idurl'] = strng.to_bin('http://{}/{}.xml'.format(result['idhost'], result['user']))
             result['customer'] = '{}@{}'.format(result['user'], result['idhost'].replace(':', '_'))
@@ -240,7 +244,7 @@ def ParseGlobalID(inp, detect_version=False, as_field=True, fast=True):
         result['path'] = path
         if detect_version:
             try:
-                from lib import packetid
+                from bitdust.lib import packetid
                 backupID, _, fileName = path.rpartition('/')
                 if packetid.IsPacketNameCorrect(fileName):
                     _, _, versionName = backupID.rpartition('/')
@@ -252,7 +256,7 @@ def ParseGlobalID(inp, detect_version=False, as_field=True, fast=True):
     if result['customer']:
         result['key_id'] = MakeGlobalKeyID(result['key_alias'], result['customer'])
     if as_field:
-        from userid import id_url
+        from bitdust.userid import id_url
         result['idurl'] = id_url.field(result['idurl'])
     return result
 
@@ -268,7 +272,7 @@ def NormalizeGlobalID(inp, detect_version=False, as_field=True):
         4. if no key alias : use "master"
         5. if no idhost : use idurl
     """
-    from userid import my_id
+    from bitdust.userid import my_id
     if isinstance(inp, dict):
         g = inp
     else:
@@ -276,7 +280,7 @@ def NormalizeGlobalID(inp, detect_version=False, as_field=True):
     if not g['idurl']:
         g['idurl'] = my_id.getIDURL().to_bin()
     if as_field:
-        from userid import id_url
+        from bitdust.userid import id_url
         g['idurl'] = id_url.field(g['idurl'])
     if not g['customer']:
         g['customer'] = UrlToGlobalID(g['idurl'])
@@ -285,7 +289,7 @@ def NormalizeGlobalID(inp, detect_version=False, as_field=True):
     if not g['key_alias']:
         g['key_alias'] = 'master'
     if not g['idhost']:
-        from lib import nameurl
+        from bitdust.lib import nameurl
         g['idhost'] = nameurl.GetHost(g['idurl'])
     if not g['key_id']:
         g['key_id'] = MakeGlobalKeyID(g['key_alias'], g['customer'])
@@ -302,7 +306,7 @@ def CanonicalID(inp, include_key=True):
 
 
 def SubstitutePacketID(packet_id, idurl=None, customer=None, key_id=None, path=None, key_alias=None):
-    from lib import nameurl
+    from bitdust.lib import nameurl
     g = ParseGlobalID(packet_id, as_field=False)
     if key_id is not None:
         g['key_id'] = key_id
@@ -331,13 +335,15 @@ def SubstitutePacketID(packet_id, idurl=None, customer=None, key_id=None, path=N
             g['key_id'] = MakeGlobalKeyID(g['key_alias'], g['customer'])
     return MakeGlobalID(**g)
 
+
 #------------------------------------------------------------------------------
 
+
 def UrlToGlobalID(url, include_key=False):
     if not url:
         return url
-    from lib import nameurl
-    from userid import id_url
+    from bitdust.lib import nameurl
+    from bitdust.userid import id_url
     if isinstance(url, id_url.ID_URL_FIELD):
         # small optimization
         return url.to_id()
@@ -370,14 +376,16 @@ def GlobalUserToIDURL(inp, as_field=True):
         except:
             port = -1
         if port >= 0:
-            idhost = "%s:%d" % (idhost[:_pos], port)
+            idhost = '%s:%d' % (idhost[:_pos], port)
     if not as_field:
         return strng.to_bin('http://{}/{}.xml'.format(idhost, user))
-    from userid import id_url
+    from bitdust.userid import id_url
     return id_url.field('http://{}/{}.xml'.format(idhost, user))
 
+
 #------------------------------------------------------------------------------
 
+
 def IsValidGlobalUser(inp):
     if not inp:
         return False
@@ -404,8 +412,10 @@ def IsFullGlobalID(inp):
         return False
     return True
 
+
 #------------------------------------------------------------------------------
 
+
 def MakeGlobalQueueID(queue_alias, owner_id, supplier_id):
     global _FORMAT_GLOBAL_ID_QUEUE_ID
     return _FORMAT_GLOBAL_ID_QUEUE_ID.format(
@@ -414,6 +424,7 @@ def MakeGlobalQueueID(queue_alias, owner_id, supplier_id):
         supplier_id=strng.to_text(supplier_id),
     )
 
+
 def ParseGlobalQueueID(queue_id):
     global _REGEX_GLOBAL_ID_QUEUE_ID
     global _REGEX_OBJ_GLOBAL_ID_QUEUE_ID
@@ -454,7 +465,9 @@ def GetGlobalQueueKeyID(queue_id):
     key_id = MakeGlobalKeyID(queue_alias, owner_id)
     return key_id
 
+
 #------------------------------------------------------------------------------
 
+
 def latest_glob_id(glob_id):
-    return  glob2idurl(glob_id, as_field=True).to_id()
+    return glob2idurl(glob_id, as_field=True).to_id()
