@@ -19,8 +19,6 @@
 # along with BitDust Software.  If not, see <http://www.gnu.org/licenses/>.
 #
 # Please contact us if you have any questions at bitdust.io@gmail.com
-
-
 """
 .. module:: id_registrator.
 
@@ -110,28 +108,28 @@ if __name__ == '__main__':
 
 #------------------------------------------------------------------------------
 
-from logs import lg
+from bitdust.logs import lg
 
-from automats import automat
+from bitdust.automats import automat
 
-from system import bpio
+from bitdust.system import bpio
 
-from lib import nameurl
-from lib import net_misc
-from lib import misc
-from lib import strng
+from bitdust.lib import nameurl
+from bitdust.lib import net_misc
+from bitdust.lib import misc
+from bitdust.lib import strng
 
-from main import settings
-from main import config
+from bitdust.main import settings
+from bitdust.main import config
 
-from stun import stun_client
+from bitdust.stun import stun_client
 
-from crypt import key
+from bitdust.crypt import key
 
-from userid import my_id
-from userid import identity
-from userid import id_url
-from userid import known_servers
+from bitdust.userid import my_id
+from bitdust.userid import identity
+from bitdust.userid import id_url
+from bitdust.userid import known_servers
 
 #------------------------------------------------------------------------------
 
@@ -223,7 +221,7 @@ class IdRegistrator(automat.Automat):
         """
         This method intended to catch the moment when automat's state was changed.
         """
-        from main import installer
+        from bitdust.main import installer
         installer.A('id_registrator.state', newstate)
 
     def A(self, event, *args, **kwargs):
@@ -373,12 +371,8 @@ class IdRegistrator(automat.Automat):
                         self.preferred_servers.append(srv.strip())
             except:
                 pass
-        self.min_servers = max(
-            settings.MinimumIdentitySources(),
-            config.conf().getInt('services/identity-propagate/min-servers') or settings.MinimumIdentitySources())
-        self.max_servers = min(
-            settings.MaximumIdentitySources(),
-            config.conf().getInt('services/identity-propagate/max-servers') or settings.MaximumIdentitySources())
+        self.min_servers = max(settings.MinimumIdentitySources(), config.conf().getInt('services/identity-propagate/min-servers') or settings.MinimumIdentitySources())
+        self.max_servers = min(settings.MaximumIdentitySources(), config.conf().getInt('services/identity-propagate/max-servers') or settings.MaximumIdentitySources())
         lg.out(4, 'id_registrator.doSaveMyName [%s]' % login)
         lg.out(4, '    known_servers=%s' % self.known_servers)
         lg.out(4, '    preferred_servers=%s' % self.preferred_servers)
@@ -421,7 +415,7 @@ class IdRegistrator(automat.Automat):
             self.automat('id-server-response', (id_server_host, htmlsrc))
 
         def _eb(err, id_server_host):
-            lg.out(4, '               FAILED: %s : %s' % (id_server_host, err.getErrorMessage(), ))
+            lg.out(4, '               FAILED: %s : %s' % (id_server_host, err.getErrorMessage()))
             self.discovered_servers.remove(id_server_host)
             self.automat('id-server-failed', (id_server_host, err))
 
@@ -473,13 +467,12 @@ class IdRegistrator(automat.Automat):
             self.automat('id-not-exist', idurl)
 
         for host in self.good_servers:
-            webport, tcpport = known_servers.by_host().get(
-                host, (settings.IdentityWebPort(), settings.IdentityServerPort()))
+            webport, tcpport = known_servers.by_host().get(host, (settings.IdentityWebPort(), settings.IdentityServerPort()))
             if webport == 80:
                 webport = ''
             idurl = nameurl.UrlMake('http', strng.to_text(host), webport, login + '.xml')
             lg.out(4, '    %s' % idurl)
-            d = net_misc.getPageTwisted(idurl, timeout=7)
+            d = net_misc.getPageTwisted(idurl, timeout=10)
             d.addCallback(_cb, idurl, host)
             d.addErrback(_eb, idurl, host)
             self.registrations.append(idurl)
@@ -574,7 +567,7 @@ class IdRegistrator(automat.Automat):
 
         for idurl in self.new_identity.getSources(as_originals=True):
             lg.out(8, '        %s' % idurl)
-            d = net_misc.getPageTwisted(idurl, timeout=7)
+            d = net_misc.getPageTwisted(idurl, timeout=15)
             d.addCallback(_cb)
             d.addErrback(_eb)
 
@@ -599,7 +592,7 @@ class IdRegistrator(automat.Automat):
         """
         Action method.
         """
-        from main import installer
+        from bitdust.main import installer
         installer.A().event('print', *args, **kwargs)
         self.last_message = args[0][0]
         lg.out(6, 'id_registrator.doPrint: %s' % str(*args, **kwargs))
@@ -622,8 +615,7 @@ class IdRegistrator(automat.Automat):
         if not key.isMyKeyReady():
             key.GenerateNewKey()
         lg.out(4, '    my key is ready')
-        ident = my_id.buildDefaultIdentity(
-            name=login, ip=externalIP, idurls=self.free_idurls)
+        ident = my_id.buildDefaultIdentity(name=login, ip=externalIP, idurls=self.free_idurls)
         my_identity_xmlsrc = ident.serialize(as_text=True)
         newfilename = settings.LocalIdentityFilename() + '.new'
         bpio.WriteTextFile(newfilename, my_identity_xmlsrc)
@@ -645,7 +637,13 @@ class IdRegistrator(automat.Automat):
         for idurl in self.new_identity.getSources(as_originals=True):
             self.free_idurls.remove(strng.to_bin(idurl))
             _, host, webport, filename = nameurl.UrlParse(idurl)
-            url = net_misc.pack_address((host, webport, ), proto='http')
+            url = net_misc.pack_address(
+                (
+                    host,
+                    webport,
+                ),
+                proto='http',
+            )
             dlist.append(net_misc.http_post_data(
                 url=url,
                 data=payload,
@@ -655,6 +653,7 @@ class IdRegistrator(automat.Automat):
                 lg.args(_DebugLevel, url=url, filename=filename, size=len(payload))
         return DeferredList(dlist, fireOnOneCallback=True)
 
+
 #------------------------------------------------------------------------------
 
 
@@ -673,8 +672,8 @@ def main():
     reactor.run()  # @UndefinedVariable
     settings.shutdown()
 
+
 #------------------------------------------------------------------------------
 
-
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
